@@ -10,71 +10,38 @@
 
 #include "cia6526.h"
 
-#ifdef RUNTIME_LOADER
-# ifdef __cplusplus
-	extern "C" void cbmb_runtime_loader_init(void);
-# else
-	extern void cbmb_runtime_loader_init(void);
-# endif
-#endif
-
 #define C64_DIPS \
      PORT_START \
      PORT_BIT( 0x800, IP_ACTIVE_HIGH, IPT_BUTTON1) \
      PORT_BIT( 0x400, IP_ACTIVE_HIGH, IPT_BUTTON2) \
-     PORT_BIT( 0x8000, IP_ACTIVE_HIGH, IPT_JOYSTICK_LEFT | IPF_8WAY )\
-     PORT_BIT( 0x4000, IP_ACTIVE_HIGH, IPT_JOYSTICK_RIGHT | IPF_8WAY )\
-	PORT_BIT( 0x2000, IP_ACTIVE_HIGH, IPT_JOYSTICK_UP | IPF_8WAY ) \
-	PORT_BIT( 0x1000, IP_ACTIVE_HIGH, IPT_JOYSTICK_DOWN | IPF_8WAY )\
-	PORT_BITX( 8, IP_ACTIVE_HIGH, IPT_BUTTON1|IPF_PLAYER2, \
-		   "P2 Button", KEYCODE_LALT,JOYCODE_2_BUTTON1 )\
-	PORT_BITX( 4, IP_ACTIVE_HIGH, IPT_BUTTON2|IPF_PLAYER2, \
-		   "P2 Button 2", KEYCODE_LCONTROL,JOYCODE_2_BUTTON2 )\
-	PORT_BITX( 0x80, IP_ACTIVE_HIGH, \
-		   IPT_JOYSTICK_LEFT|IPF_PLAYER2 | IPF_8WAY,\
-		   "P2 Left",KEYCODE_DEL,JOYCODE_2_LEFT )\
-	PORT_BITX( 0x40, IP_ACTIVE_HIGH, \
-		   IPT_JOYSTICK_RIGHT|IPF_PLAYER2 | IPF_8WAY,\
-		   "P2 Right",KEYCODE_PGDN,JOYCODE_2_RIGHT )\
-	PORT_BITX( 0x20, IP_ACTIVE_HIGH, \
-		   IPT_JOYSTICK_UP|IPF_PLAYER2 | IPF_8WAY,\
-		   "P2 Up", KEYCODE_HOME, JOYCODE_2_UP)\
-	PORT_BITX( 0x10, IP_ACTIVE_HIGH, \
-		   IPT_JOYSTICK_DOWN|IPF_PLAYER2 | IPF_8WAY,\
-		   "P2 Down", KEYCODE_END, JOYCODE_2_DOWN)\
+     PORT_BIT( 0x8000, IP_ACTIVE_HIGH, IPT_JOYSTICK_LEFT) PORT_8WAY\
+     PORT_BIT( 0x4000, IP_ACTIVE_HIGH, IPT_JOYSTICK_RIGHT) PORT_8WAY\
+	PORT_BIT( 0x2000, IP_ACTIVE_HIGH, IPT_JOYSTICK_UP)  PORT_8WAY\
+	PORT_BIT( 0x1000, IP_ACTIVE_HIGH, IPT_JOYSTICK_DOWN) PORT_8WAY\
+	PORT_BIT( 8, IP_ACTIVE_HIGH, IPT_BUTTON1) PORT_NAME("P2 Button") PORT_CODE(KEYCODE_LALT) PORT_CODE(JOYCODE_2_BUTTON1 ) PORT_PLAYER(2)\
+	PORT_BIT( 4, IP_ACTIVE_HIGH, IPT_BUTTON2) PORT_NAME("P2 Button 2") PORT_CODE(KEYCODE_LCONTROL) PORT_CODE(JOYCODE_2_BUTTON2 ) PORT_PLAYER(2)\
+	PORT_BIT( 0x80, IP_ACTIVE_HIGH, IPT_JOYSTICK_LEFT) PORT_NAME("P2 Left") PORT_CODE(KEYCODE_DEL) PORT_CODE(JOYCODE_2_LEFT) PORT_PLAYER(2) PORT_8WAY\
+	PORT_BIT( 0x40, IP_ACTIVE_HIGH, IPT_JOYSTICK_RIGHT) PORT_NAME("P2 Right") PORT_CODE(KEYCODE_PGDN) PORT_CODE(JOYCODE_2_RIGHT) PORT_PLAYER(2) PORT_8WAY\
+	PORT_BIT( 0x20, IP_ACTIVE_HIGH, IPT_JOYSTICK_UP) PORT_NAME("P2 Up") PORT_CODE(KEYCODE_HOME) PORT_CODE(JOYCODE_2_UP) PORT_PLAYER(2) PORT_8WAY\
+	PORT_BIT( 0x10, IP_ACTIVE_HIGH, IPT_JOYSTICK_DOWN) PORT_NAME("P2 Down") PORT_CODE(KEYCODE_END) PORT_CODE(JOYCODE_2_DOWN) PORT_PLAYER(2) PORT_8WAY\
 	PORT_BIT ( 0x7, 0x0,	 IPT_UNUSED )\
 	PORT_START \
-	PORT_BITX( 0x100, IP_ACTIVE_HIGH, IPT_BUTTON1, \
-		   "Paddle 1 Button", KEYCODE_LCONTROL, 0)\
-	PORT_ANALOGX(0xff,128,IPT_PADDLE|IPF_REVERSE,\
-		     30,20,0,0,255,KEYCODE_LEFT,KEYCODE_RIGHT,\
-		     JOYCODE_1_LEFT,JOYCODE_1_RIGHT)\
+	PORT_BIT( 0x100, IP_ACTIVE_HIGH, IPT_BUTTON1) PORT_NAME("Paddle 1 Button") PORT_CODE(KEYCODE_LCONTROL) \
+	PORT_BIT(0xff,128,IPT_PADDLE, 30) PORT_SENSITIVITY(20) PORT_KEYDELTA(0) PORT_MINMAX(0,255) PORT_CODE_DEC(KEYCODE_LEFT) PORT_CODE_INC(KEYCODE_RIGHT) PORT_CODE_DEC(JOYCODE_1_LEFT) PORT_CODE_INC(JOYCODE_1_RIGHT) PORT_REVERSE\
 	PORT_START \
-	PORT_BITX( 0x100, IP_ACTIVE_HIGH, IPT_BUTTON2, \
-		   "Paddle 2 Button", KEYCODE_LALT, 0)\
-	PORT_ANALOGX(0xff,128,IPT_PADDLE|IPF_PLAYER2|IPF_REVERSE,\
-		     30,20,0,0,255,KEYCODE_DOWN,KEYCODE_UP,0,0)\
+	PORT_BIT( 0x100, IP_ACTIVE_HIGH, IPT_BUTTON2) PORT_NAME("Paddle 2 Button") PORT_CODE(KEYCODE_LALT) \
+	PORT_BIT(0xff,128,IPT_PADDLE, 30) PORT_SENSITIVITY(20) PORT_KEYDELTA(0) PORT_MINMAX(0,255) PORT_CODE_DEC(KEYCODE_DOWN) PORT_CODE_INC(KEYCODE_UP) PORT_CODE_DEC(0) PORT_CODE_INC(0) PORT_PLAYER(2) PORT_REVERSE\
 	PORT_START \
-	PORT_BITX( 0x100, IP_ACTIVE_HIGH, IPT_BUTTON3, \
-		   "Paddle 3 Button", KEYCODE_INSERT, 0)\
-	PORT_ANALOGX(0xff,128,IPT_PADDLE|IPF_PLAYER3|IPF_REVERSE,\
-		     30,20,0,0,255,KEYCODE_HOME,KEYCODE_PGUP,0,0)\
-     PORT_START \
-	PORT_BITX( 0x100, IP_ACTIVE_HIGH, IPT_BUTTON4, \
-		   "Paddle 4 Button", KEYCODE_DEL, 0)\
-	PORT_ANALOGX(0xff,128,IPT_PADDLE|IPF_PLAYER4|IPF_REVERSE,\
-		     30,20,0,0,255,KEYCODE_END,KEYCODE_PGDN,\
-		     JOYCODE_1_UP,JOYCODE_1_DOWN)\
+	PORT_BIT( 0x100, IP_ACTIVE_HIGH, IPT_BUTTON3) PORT_NAME("Paddle 3 Button") PORT_CODE(KEYCODE_INSERT) \
+	PORT_BIT(0xff,128,IPT_PADDLE, 30) PORT_SENSITIVITY(20) PORT_KEYDELTA(0) PORT_MINMAX(0,255) PORT_CODE_DEC(KEYCODE_HOME) PORT_CODE_INC(KEYCODE_PGUP) PORT_CODE_DEC(0) PORT_CODE_INC(0) PORT_PLAYER(3) PORT_REVERSE\
 	PORT_START \
-	PORT_BITX( 0x8000, IP_ACTIVE_HIGH, IPT_BUTTON2, \
-		   "Lightpen Signal", KEYCODE_LCONTROL, 0)\
-     PORT_ANALOGX(0x1ff,0,IPT_PADDLE|IPF_PLAYER1,\
-		  30,2,0,0,320-1,KEYCODE_LEFT,KEYCODE_RIGHT,\
-		  JOYCODE_1_LEFT,JOYCODE_1_RIGHT)\
-     PORT_START \
-     PORT_ANALOGX(0xff,0,IPT_PADDLE|IPF_PLAYER2,\
-		  30,2,0,0,200-1,KEYCODE_UP,KEYCODE_DOWN,\
-		  JOYCODE_1_UP,JOYCODE_1_DOWN)\
+	PORT_BIT( 0x100, IP_ACTIVE_HIGH, IPT_BUTTON4) PORT_NAME("Paddle 4 Button") PORT_CODE(KEYCODE_DEL) \
+	PORT_BIT(0xff,128,IPT_PADDLE, 30) PORT_SENSITIVITY(20) PORT_KEYDELTA(0) PORT_MINMAX(0,255) PORT_CODE_DEC(KEYCODE_END) PORT_CODE_INC(KEYCODE_PGDN) PORT_CODE_DEC(JOYCODE_1_UP) PORT_CODE_INC(JOYCODE_1_DOWN) PORT_PLAYER(4) PORT_REVERSE\
+	PORT_START \
+	PORT_BIT( 0x8000, IP_ACTIVE_HIGH, IPT_BUTTON2) PORT_NAME("Lightpen Signal") PORT_CODE(KEYCODE_LCONTROL) \
+	PORT_BIT(0x1ff,0,IPT_PADDLE, 30) PORT_SENSITIVITY(2) PORT_KEYDELTA(0) PORT_MINMAX(0,320-1) PORT_CODE_DEC(KEYCODE_LEFT) PORT_CODE_INC(KEYCODE_RIGHT) PORT_CODE_DEC(JOYCODE_1_LEFT) PORT_CODE_INC(JOYCODE_1_RIGHT) PORT_PLAYER(1)\
+	PORT_START \
+	PORT_BIT(0xff,0,IPT_PADDLE, 30) PORT_SENSITIVITY(2) PORT_KEYDELTA(0) PORT_MINMAX(0,200-1) PORT_CODE_DEC(KEYCODE_UP) PORT_CODE_INC(KEYCODE_DOWN) PORT_CODE_DEC(JOYCODE_1_UP) PORT_CODE_INC(JOYCODE_1_DOWN) PORT_PLAYER(2)\
 	PORT_START \
 	PORT_DIPNAME ( 0xe000, 0x2000, "Gameport A")\
 	PORT_DIPSETTING(  0, "None" )\
@@ -92,8 +59,7 @@
 	PORT_DIPSETTING(	0x0400, "Paddles 3, 4" )\
 	PORT_DIPSETTING(	0x0600, "Mouse Joystick Emulation/2 Button Joystick" )\
 	PORT_DIPSETTING(	0x0800, "Mouse" )\
-    PORT_BITX( 0x100, IP_ACTIVE_HIGH, IPF_TOGGLE,\
-		   "Swap Gameport 1 and 2", KEYCODE_NUMLOCK, IP_JOY_NONE)
+	PORT_BIT( 0x100, IP_ACTIVE_HIGH, 0) PORT_NAME("Swap Gameport 1 and 2") PORT_CODE(KEYCODE_NUMLOCK) PORT_TOGGLE
 
 #define LIGHTPEN ((input_port_7_word_r(0,0)&0xe000)==0xa000)
 #define MOUSE1 ((input_port_7_word_r(0,0)&0xe000)==0x8000)
@@ -256,26 +222,24 @@ extern UINT8 *cbmb_memory;
 extern UINT8 *cbmb_videoram;
 extern UINT8 *cbmb_colorram;
 
-WRITE_HANDLER ( cbmb_colorram_w );
+WRITE8_HANDLER ( cbmb_colorram_w );
 
-extern void cbm500_driver_init (void);
-extern void cbm600_driver_init (void);
-extern void cbm600pal_driver_init (void);
-extern void cbm600hu_driver_init (void);
-extern void cbm700_driver_init (void);
-extern void cbmb_driver_shutdown (void);
-extern void cbmb_init_machine (void);
-extern void cbmb_common_init_machine (void);
-extern void cbmb_shutdown_machine (void);
-extern void cbmb_frame_interrupt (int param);
+void cbm500_driver_init (void);
+void cbm600_driver_init (void);
+void cbm600pal_driver_init (void);
+void cbm600hu_driver_init (void);
+void cbm700_driver_init (void);
+void cbmb_common_init_machine (void);
+void cbmb_frame_interrupt (int param);
+MACHINE_RESET( cbmb );
 
 void cbmb_rom_load(void);
 
 void cbm600_vh_init(void);
 void cbm700_vh_init(void);
-int cbm700_vh_start(void);
-void cbmb_vh_cursor(CRTC6845_CURSOR *cursor);
-void cbmb_vh_screenrefresh (struct mame_bitmap *bitmap, int full_refresh);
+void cbmb_vh_cursor(struct crtc6845_cursor *cursor);
+extern VIDEO_START( cbm700 );
+extern VIDEO_UPDATE( cbmb );
 
 void cbmb_vh_set_font(int font);
 
