@@ -6,6 +6,7 @@
 #include <ctype.h>
 #include "driver.h"
 #include "cpu/m6502/m6509.h"
+#include "sound/sid6581.h"
 
 #define VERBOSE_DBG 1
 #include "includes/cbm.h"
@@ -17,18 +18,15 @@
 #include "includes/cbmieeeb.h"
 #include "includes/vic6567.h"
 #include "includes/crtc6845.h"
-#include "includes/sid6581.h"
-#include "includes/state.h"
+#include "mscommon.h"
 
 #include "includes/cbmb.h"
 
 /* keyboard lines */
 static UINT8 cbmb_keyline[12] = { 0 };
 static int cbmb_keyline_a, cbmb_keyline_b, cbmb_keyline_c;
-static void *cbmb_clock;
 
 static int cbm500=0;
-UINT8 *cbmb_memory;
 UINT8 *cbmb_basic;
 UINT8 *cbmb_kernal;
 static UINT8 *cbmb_chargen;
@@ -163,7 +161,7 @@ static void cbmb_irq (int level)
 	if (level != old_level)
 	{
 		DBG_LOG (3, "mos6509", ("irq %s\n", level ? "start" : "end"));
-		cpu_set_irq_line (0, M6502_IRQ_LINE, level);
+		cpunum_set_input_line (0, M6502_IRQ_LINE, level);
 		old_level = level;
 	}
 }
@@ -202,7 +200,7 @@ struct cia6526_interface cbmb_cia =
 	0xff, 0xff, 0
 };
 
-WRITE_HANDLER ( cbmb_colorram_w )
+WRITE8_HANDLER ( cbmb_colorram_w )
 {
 	cbmb_colorram[offset]=data|0xf0;
 }
@@ -230,6 +228,8 @@ static void cbmb_common_driver_init (void)
 	cbmb_chargen=memory_region(REGION_CPU1)+0x100000;
 	/*    memset(c64_memory, 0, 0xfd00); */
 
+	cia6526_init();
+
 	cbmb_cia.todin50hz = 0;
 	cia6526_config (0, &cbmb_cia);
 
@@ -243,64 +243,52 @@ static void cbmb_common_driver_init (void)
 	tpi6525[1].a.output=cbmb_keyboard_line_select_a;
 	tpi6525[1].b.output=cbmb_keyboard_line_select_b;
 	tpi6525[1].c.output=cbmb_keyboard_line_select_c;
-	cbmb_clock=timer_pulse(0.01, 0, cbmb_frame_interrupt);
-
-	cbm_drive_open ();
-
-	cbm_drive_attach_fs (0);
-	cbm_drive_attach_fs (1);
+	timer_pulse(0.01, 0, cbmb_frame_interrupt);
 
 	cbm_ieee_open();
 }
 
-static CRTC6845_CONFIG cbm600_crtc= { 1600000 /*?*/, cbmb_vh_cursor };
+static struct crtc6845_config cbm600_crtc= { 1600000 /*?*/, cbmb_vh_cursor };
+
 void cbm600_driver_init (void)
 {
 	cbmb_common_driver_init ();
-	state_add_function(cbmb_state);
 	cbm600_vh_init();
-	crtc6845_init(crtc6845, &cbm600_crtc);
+	crtc6845_init(&cbm600_crtc);
 }
 
 void cbm600pal_driver_init (void)
 {
 	cbmb_common_driver_init ();
-	state_add_function(cbmb_state);
 	cbm600_vh_init();
-	crtc6845_init(crtc6845, &cbm600_crtc);
+	crtc6845_init(&cbm600_crtc);
 }
 
 void cbm600hu_driver_init (void)
 {
 	cbmb_common_driver_init ();
-	state_add_function(cbmb_state);
-	crtc6845_init(crtc6845, &cbm600_crtc);
+	crtc6845_init(&cbm600_crtc);
 }
 
-static CRTC6845_CONFIG cbm700_crtc= { 2000000 /*?*/, cbmb_vh_cursor };
+static struct crtc6845_config cbm700_crtc= { 2000000 /*?*/, cbmb_vh_cursor };
+
 void cbm700_driver_init (void)
 {
 	cbmb_common_driver_init ();
-	state_add_function(cbmb_state);
 	cbm700_vh_init();
-	crtc6845_init(crtc6845, &cbm700_crtc);
+	crtc6845_init(&cbm700_crtc);
 }
 
 void cbm500_driver_init (void)
 {
 	cbmb_common_driver_init ();
 	cbm500=1;
-	state_add_function(cbmb_state);
 	vic6567_init (0, 0, cbmb_dma_read, cbmb_dma_read_color, NULL);
 }
 
-void cbmb_driver_shutdown (void)
+MACHINE_RESET( cbmb )
 {
-}
-
-void cbmb_init_machine (void)
-{
-	sid6581_reset(0);
+	sndti_reset(SOUND_SID6581, 0);
 	cia6526_reset ();
 	tpi6525_0_reset();
 	tpi6525_1_reset();
@@ -310,10 +298,6 @@ void cbmb_init_machine (void)
 	cbmb_rom_load();
 }
 
-void cbmb_shutdown_machine (void)
-{
-}
-
 void cbmb_rom_load(void)
 {
 	int i;
@@ -326,21 +310,13 @@ void cbmb_rom_load(void)
 
 void cbmb_frame_interrupt (int param)
 {
-	static int level=0;
-	static int quickload = 0;
+	static int level = 0;
 	int value;
 
 	tpi6525_0_irq0_level(level);
 	level=!level;
 	if (level) return ;
 
-	sid6581_update();
-	if (!quickload && QUICKLOAD) {
-		if (cbm500) cbm500_quick_open(0, 0, cbmb_memory);
-		else cbmb_quick_open (0, 0, cbmb_memory);
-	}
-	quickload = QUICKLOAD;
-
 	value = 0;
 	if (KEY_STOP)
 		value |= 0x80;
@@ -620,20 +596,3 @@ void cbmb_frame_interrupt (int param)
 	set_led_status (0 /*KB_NUMLOCK_FLAG */ , JOYSTICK_SWAP ? 1 : 0);
 #endif
 }
-
-void cbmb_state(void)
-{
-#if VERBOSE_DBG
-	char text[70];
-
-	snprintf(text, sizeof(text),
-			 "%.2x %.2x",
-			 MODELL_700, VIDEO_NTSC);
-	state_display_text (text);
-
-#if 0
-	cia6526_status (text, sizeof (text));
-	state_display_text (text);
-#endif
-#endif
-}
