@@ -13,7 +13,7 @@
 #include "cpu/z80/z80.h"
 #include "vidhrdw/generic.h"
 #include "includes/cgenie.h"
-#include "includes/wd179x.h"
+#include "machine/wd17xx.h"
 #include "devices/basicdsk.h"
 #include "devices/cartslot.h"
 #include "sound/ay8910.h"
@@ -220,24 +220,9 @@ static OPBASE_HANDLER (opbaseoverride)
 	return address;
 }
 
-void init_cgenie(void)
-{
-	UINT8 *gfx = memory_region(REGION_GFX2);
-	int i;
-	/*
-	 * Every fitfth cycle is a wait cycle, so I reduced
-	 * the overlocking by one fitfth
-	 */
-	cpunum_set_clockscale(0, 0.80);
-
-	/* Initialize some patterns to be displayed in graphics mode */
-	for( i = 0; i < 256; i++ )
-		memset(gfx + i * 8, i, 8);
-}
-
 static void cgenie_fdc_callback(int);
 
-MACHINE_INIT( cgenie )
+static void cgenie_machine_reset(void)
 {
 	UINT8 *ROM = memory_region(REGION_CPU1);
 
@@ -327,13 +312,29 @@ MACHINE_INIT( cgenie )
 
 	cgenie_load_cas = 1;
 	memory_set_opbase_handler(0, opbaseoverride);
+
 }
 
-MACHINE_STOP( cgenie )
+MACHINE_START( cgenie )
 {
-	tape_put_close();
+	UINT8 *gfx = memory_region(REGION_GFX2);
+	int i;
+	/*
+	 * Every fitfth cycle is a wait cycle, so I reduced
+	 * the overlocking by one fitfth
+	 */
+	cpunum_set_clockscale(0, 0.80);
+
+	/* Initialize some patterns to be displayed in graphics mode */
+	for( i = 0; i < 256; i++ )
+		memset(gfx + i * 8, i, 8);
+
+	add_reset_callback(cgenie_machine_reset);
+	add_exit_callback(tape_put_close);
+	return 0;
 }
 
+
 DEVICE_LOAD( cgenie_cassette )
 {
 	return INIT_PASS;
