@@ -810,7 +810,7 @@ static MACHINE_DRIVER_START( a400 )
 	MDRV_CPU_PROGRAM_MAP(a400_mem, 0)
 	MDRV_CPU_VBLANK_INT(a400_interrupt, TOTAL_LINES_60HZ)
 
-	MDRV_MACHINE_INIT( a400 )
+	MDRV_MACHINE_RESET( a400 )
 	MDRV_FRAMES_PER_SECOND(FRAME_RATE_60HZ)
 	MDRV_SCREEN_SIZE(HWIDTH*8, TOTAL_LINES_60HZ)
 MACHINE_DRIVER_END
@@ -823,7 +823,7 @@ static MACHINE_DRIVER_START( a400pal )
 	MDRV_CPU_PROGRAM_MAP(a400_mem, 0)
 	MDRV_CPU_VBLANK_INT(a400_interrupt, TOTAL_LINES_50HZ)
 
-	MDRV_MACHINE_INIT( a400 )
+	MDRV_MACHINE_RESET( a400 )
 	MDRV_FRAMES_PER_SECOND(FRAME_RATE_50HZ)
 	MDRV_SCREEN_SIZE(HWIDTH*8, TOTAL_LINES_50HZ)
 MACHINE_DRIVER_END
@@ -836,7 +836,7 @@ static MACHINE_DRIVER_START( a800 )
 	MDRV_CPU_PROGRAM_MAP(a800_mem, 0)
 	MDRV_CPU_VBLANK_INT(a800_interrupt, TOTAL_LINES_60HZ)
 
-	MDRV_MACHINE_INIT( a800 )
+	MDRV_MACHINE_RESET( a800 )
 	MDRV_FRAMES_PER_SECOND(FRAME_RATE_60HZ)
 	MDRV_SCREEN_SIZE(HWIDTH*8, TOTAL_LINES_60HZ)
 MACHINE_DRIVER_END
@@ -849,7 +849,7 @@ static MACHINE_DRIVER_START( a800pal )
 	MDRV_CPU_PROGRAM_MAP(a800_mem, 0)
 	MDRV_CPU_VBLANK_INT(a800_interrupt, TOTAL_LINES_50HZ)
 
-	MDRV_MACHINE_INIT( a800 )
+	MDRV_MACHINE_RESET( a800 )
 	MDRV_FRAMES_PER_SECOND(FRAME_RATE_50HZ)
 	MDRV_SCREEN_SIZE(HWIDTH*8, TOTAL_LINES_50HZ)
 MACHINE_DRIVER_END
@@ -862,7 +862,7 @@ static MACHINE_DRIVER_START( a800xl )
 	MDRV_CPU_PROGRAM_MAP(a800xl_mem, 0)
 	MDRV_CPU_VBLANK_INT(a800xl_interrupt, TOTAL_LINES_60HZ)
 
-	MDRV_MACHINE_INIT( a800xl )
+	MDRV_MACHINE_RESET( a800xl )
 	MDRV_FRAMES_PER_SECOND(FRAME_RATE_60HZ)
 	MDRV_SCREEN_SIZE(HWIDTH*8, TOTAL_LINES_60HZ)
 MACHINE_DRIVER_END
@@ -875,7 +875,7 @@ static MACHINE_DRIVER_START( a5200 )
 	MDRV_CPU_PROGRAM_MAP(a5200_mem, 0)
 	MDRV_CPU_VBLANK_INT(a5200_interrupt, TOTAL_LINES_60HZ)
 
-	MDRV_MACHINE_INIT( a5200 )
+	MDRV_MACHINE_RESET( a5200 )
 	MDRV_FRAMES_PER_SECOND(FRAME_RATE_60HZ)
 	MDRV_SCREEN_SIZE(HWIDTH*8, TOTAL_LINES_60HZ)
 MACHINE_DRIVER_END
