@@ -423,12 +423,6 @@ ADDRESS_MAP_END
 	 /*PORT_DIPSETTING (0x10, "C64 CBM Supergames")*/\
 	 /*PORT_DIPSETTING (0x14, "C64 Ocean Robocop2")*/\
 	 /*PORT_DIPSETTING (0x1c, "C128")*/\
-	 PORT_DIPNAME (0x02, 0x02, "Serial Bus/Device 8")\
-	 PORT_DIPSETTING (0, DEF_STR( None ))\
-	 PORT_DIPSETTING (2, "VC1541 Floppy Drive")\
-	 PORT_DIPNAME (0x01, 0x01, "Serial Bus/Device 9")\
-	 PORT_DIPSETTING (0, DEF_STR( None ))\
-	 PORT_DIPSETTING (1, "VC1541 Floppy Drive")
 
 #define DIPS_KEYS_BOTH \
 	PORT_START \
@@ -1112,8 +1106,8 @@ ROM_END
 
 ROM_START (c128d)
 	ROM_REGION (0x132800, REGION_CPU1, 0)
-	ROM_LOAD ("318022.02", 0x100000, 0x8000, CRC(af1ae1e8))
-	ROM_LOAD ("318023.02", 0x108000, 0x8000, CRC(eedc120a))
+	ROM_LOAD ("318022.02", 0x100000, 0x8000, CRC(af1ae1e8) SHA1(953dcdf5784a6b39ef84dd6fd968c7a03d8d6816))
+	ROM_LOAD ("318023.02", 0x108000, 0x8000, CRC(eedc120a) SHA1(f98c5a986b532c78bb68df9ec6dbcf876913b99f))
 	ROM_LOAD ("390059.01", 0x120000, 0x2000, CRC(6aaaafe6) SHA1(29ed066d513f2d5c09ff26d9166ba23c2afb2b3f))
 	ROM_REGION (0x10000, REGION_CPU2, 0)
 	C1571_ROM(REGION_CPU3)
@@ -1124,7 +1118,7 @@ ROM_END
 /* submitted as cost reduced set! */
 ROM_START (c128dita)
 	ROM_REGION (0x132800, REGION_CPU1, 0)
-	ROM_LOAD ("318022.02", 0x100000, 0x8000, CRC(af1ae1e8))
+	ROM_LOAD ("318022.02", 0x100000, 0x8000, CRC(af1ae1e8) SHA1(953dcdf5784a6b39ef84dd6fd968c7a03d8d6816))
 
     /* in a cost reduced set this should be 1 rom */
 	ROM_LOAD ("251913.01", 0x108000, 0x4000, CRC(0010ec31))
@@ -1233,7 +1227,7 @@ static MACHINE_DRIVER_START( c128 )
 	MDRV_VBLANK_DURATION(DEFAULT_REAL_60HZ_VBLANK_DURATION)
 	MDRV_INTERLEAVE(0)
 
-	MDRV_MACHINE_INIT( c128 )
+	MDRV_MACHINE_RESET( c128 )
 
     /* video hardware */
 	/*MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)	//when it is supported in vic6567 */
