@@ -336,7 +336,7 @@ static MACHINE_DRIVER_START( c65 )
 	MDRV_VBLANK_DURATION(DEFAULT_REAL_60HZ_VBLANK_DURATION)
 	MDRV_INTERLEAVE(0)
 
-	MDRV_MACHINE_INIT( c65 )
+	MDRV_MACHINE_START( c65 )
 
 	/* video hardware */
 	MDRV_IMPORT_FROM( vh_vic2 )
