@@ -874,7 +874,7 @@ static MACHINE_DRIVER_START( cbm600 )
 	MDRV_VBLANK_DURATION(DEFAULT_REAL_60HZ_VBLANK_DURATION)
 	MDRV_INTERLEAVE(0)
 
-	MDRV_MACHINE_INIT( cbmb )
+	MDRV_MACHINE_RESET( cbmb )
 
     /* video hardware */
 #ifdef PET_TEST_CODE
@@ -924,7 +924,7 @@ static MACHINE_DRIVER_START( cbm500 )
 	MDRV_VBLANK_DURATION(DEFAULT_REAL_60HZ_VBLANK_DURATION)
 	MDRV_INTERLEAVE(0)
 
-	MDRV_MACHINE_INIT( cbmb )
+	MDRV_MACHINE_RESET( cbmb )
 
 	MDRV_IMPORT_FROM( vh_vic2 )
 
