@@ -385,9 +385,8 @@ static MACHINE_DRIVER_START( cgenie )
 	MDRV_VBLANK_DURATION(DEFAULT_REAL_60HZ_VBLANK_DURATION)
 	MDRV_INTERLEAVE(4)
 
-	MDRV_MACHINE_INIT( cgenie )
-	MDRV_MACHINE_STOP( cgenie )
-
+	MDRV_MACHINE_START( cgenie )
+	
     /* video hardware */
 	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
 	MDRV_SCREEN_SIZE(48*8, (32)*8)
@@ -474,4 +473,4 @@ SYSTEM_CONFIG_START(cgenie)
 SYSTEM_CONFIG_END
 
 /*	  YEAR	NAME	  PARENT	COMPAT	MACHINE   INPUT 	INIT	  CONFIG     COMPANY	FULLNAME */
-COMP( 1982, cgenie,   0,		0,		cgenie,   cgenie,	cgenie,   cgenie,    "EACA Computers Ltd.",  "Colour Genie EG2000" , 0)
+COMP( 1982, cgenie,   0,		0,		cgenie,   cgenie,	0,        cgenie,    "EACA Computers Ltd.",  "Colour Genie EG2000" , 0)
