@@ -19,7 +19,7 @@
 #include "sndhrdw/dave.h"
 #include "includes/enterp.h"
 #include "vidhrdw/epnick.h"
-#include "includes/wd179x.h"
+#include "machine/wd17xx.h"
 #include "cpuintrf.h"
 #include "devices/basicdsk.h"
 /* for CPCEMU style disk images */
@@ -537,7 +537,7 @@ static MACHINE_DRIVER_START( ep128 )
 	MDRV_VBLANK_DURATION(DEFAULT_REAL_60HZ_VBLANK_DURATION)
 	MDRV_INTERLEAVE(1)
 
-	MDRV_MACHINE_INIT( enterprise )
+	MDRV_MACHINE_RESET( enterprise )
 
     /* video hardware */
 	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER | VIDEO_PIXEL_ASPECT_RATIO_1_2)
