@@ -615,7 +615,7 @@ static MACHINE_DRIVER_START( pc1350 )
 	MDRV_CPU_PROGRAM_MAP( pc1350_mem, 0 )
 	MDRV_CPU_CONFIG( pc1350_config )
 
-	MDRV_MACHINE_INIT( pc1350 )
+	MDRV_MACHINE_RESET( pc1350 )
 	MDRV_NVRAM_HANDLER( pc1350 )
 
 	/*
@@ -667,10 +667,10 @@ MACHINE_DRIVER_END
 ROM_START(pc1401)
 	ROM_REGION(0x10000,REGION_CPU1,0)
 	/* SC61860A08 5H 13LD cpu with integrated rom*/
-	ROM_LOAD("sc61860.a08", 0x0000, 0x2000, CRC(44bee438))
+	ROM_LOAD("sc61860.a08", 0x0000, 0x2000, CRC(44bee438) SHA1(c5106bc8d848be1b49494ace30a26eeb1cc5e504))
 /* 5S1 SC613256 D30
    or SC43536LD 5G 13 (LCD chip?) */
-	ROM_LOAD("sc613256.d30", 0x8000, 0x8000, CRC(69b9d587))
+	ROM_LOAD("sc613256.d30", 0x8000, 0x8000, CRC(69b9d587) SHA1(fa0602e7dfee548546f801fb4cca7d73da2d8f18))
 	ROM_REGION(0x80,REGION_GFX1,0)
 ROM_END
 
@@ -679,8 +679,8 @@ ROM_END
 ROM_START(pc1251)
 	ROM_REGION(0x10000,REGION_CPU1,0)
 	/* sc61860a13 6c 13 ld */
-	ROM_LOAD("cpu1251.rom", 0x0000, 0x2000, CRC(f7287aca))
-	ROM_LOAD("bas1251.rom", 0x4000, 0x4000, CRC(93ecb629))
+	ROM_LOAD("cpu1251.rom", 0x0000, 0x2000, CRC(f7287aca) SHA1(19bfa778e3e05ea06bdca15cd9dfbba9b971340e))
+	ROM_LOAD("bas1251.rom", 0x4000, 0x4000, CRC(93ecb629) SHA1(0fe0ad419053ee7814600b0be320dd2e8eb2ec92))
 	ROM_REGION(0x80,REGION_GFX1,0)
 ROM_END
 
@@ -689,19 +689,19 @@ ROM_END
 ROM_START(pc1350)
 	ROM_REGION(0x10000,REGION_CPU1,0)
 	/* sc61860a13 6c 13 ld */
-	ROM_LOAD("cpu.rom", 0x0000, 0x2000, CRC(79a924bc))
-	ROM_LOAD("basic.rom", 0x8000, 0x8000, CRC(158b28e2))
+	ROM_LOAD("cpu.rom", 0x0000, 0x2000, CRC(79a924bc) SHA1(2eaef0d53d85863ca70a41c8e1eddc5915136b99))
+	ROM_LOAD("basic.rom", 0x8000, 0x8000, CRC(158b28e2) SHA1(b63b37dd510b3c4d9f16d224f87ae2efb3bcc51f))
 	ROM_REGION(0x100,REGION_GFX1,0)
 ROM_END
 
 ROM_START(pc1403)
 	ROM_REGION(0x10000,REGION_CPU1,0)
-    ROM_LOAD("introm.bin", 0x0000, 0x2000, CRC(588c500b ))
+    ROM_LOAD("introm.bin", 0x0000, 0x2000, CRC(588c500b) SHA1(2fed9ebede27e20a8ee4b4b03b9f8cd7808ada5c))
 	ROM_REGION(0x10000,REGION_USER1,0)
-    ROM_LOAD("extrom08.bin", 0x0000, 0x4000, CRC(1fa65140 ))
-    ROM_LOAD("extrom09.bin", 0x4000, 0x4000, CRC(4a7da6ab ))
-    ROM_LOAD("extrom0a.bin", 0x8000, 0x4000, CRC(9925174f ))
-    ROM_LOAD("extrom0b.bin", 0xc000, 0x4000, CRC(fa5df9ec ))
+    ROM_LOAD("extrom08.bin", 0x0000, 0x4000, CRC(1fa65140) SHA1(f22a9f114486f69733fc43dfec26fb210643aeff))
+    ROM_LOAD("extrom09.bin", 0x4000, 0x4000, CRC(4a7da6ab) SHA1(b50fe8a4ca821244c119147b3ff04cee0fd6ad5c))
+    ROM_LOAD("extrom0a.bin", 0x8000, 0x4000, CRC(9925174f) SHA1(793a79142cd170ed7ac3f7ecb1b6e6f92c8fa4e0))
+    ROM_LOAD("extrom0b.bin", 0xc000, 0x4000, CRC(fa5df9ec) SHA1(6ff62c215f510a3a652d61823f54cd4018d6a771))
 	ROM_REGION(0x100,REGION_GFX1,0)
 ROM_END
 
