@@ -144,7 +144,7 @@ static MACHINE_DRIVER_START(sms)
 	MDRV_VBLANK_DURATION(DEFAULT_REAL_60HZ_VBLANK_DURATION)
 	MDRV_INTERLEAVE(1)
 
-	MDRV_MACHINE_INIT(sms)
+	MDRV_MACHINE_RESET(sms)
 	MDRV_NVRAM_HANDLER(sms)
 
 	/* video hardware */
@@ -175,7 +175,7 @@ static MACHINE_DRIVER_START(smspal)
 	MDRV_VBLANK_DURATION(DEFAULT_REAL_60HZ_VBLANK_DURATION)
 	MDRV_INTERLEAVE(1)
         
-	MDRV_MACHINE_INIT(sms)
+	MDRV_MACHINE_RESET(sms)
 	MDRV_NVRAM_HANDLER(sms)
 
 	/* video hardware */
@@ -217,7 +217,7 @@ static MACHINE_DRIVER_START(gamegear)
 	MDRV_VBLANK_DURATION(DEFAULT_REAL_60HZ_VBLANK_DURATION)
 	MDRV_INTERLEAVE(1)
 
-	MDRV_MACHINE_INIT(sms)
+	MDRV_MACHINE_RESET(sms)
 	MDRV_NVRAM_HANDLER(sms)
 
 	/* video hardware */
@@ -327,7 +327,7 @@ ROM_END
 ROM_START(gamg)
 	ROM_REGION(CPU_ADDRESSABLE_SIZE, REGION_CPU1,0)
 	ROM_REGION(0x4000, REGION_USER1, 0)
-	ROM_LOAD("majbios.rom", 0x0000, 0x0400, CRC(0EBEA9D4))
+	ROM_LOAD("majbios.rom", 0x0000, 0x0400, CRC(0EBEA9D4) SHA1(914aa165e3d879f060be77870d345b60cfeb4ede))
 ROM_END
 
 #define rom_gamgj rom_gamg
