@@ -211,7 +211,12 @@ static int cmd_dir(const struct command *c, int argc, char *argv[])
 
 	while (((err = img_nextenum(imgenum, &ent)) == 0) && !ent.eof)
 	{
-		fprintf(stdout, "%-20s\t%8u %15s\n", ent.filename, (unsigned int) ent.filesize, ent.attr);
+		if (ent.directory)
+			snprintf(buf, sizeof(buf), "<DIR>");
+		else
+			snprintf(buf, sizeof(buf), "%u", (unsigned int) ent.filesize);
+
+		fprintf(stdout, "%-20s\t%8s %15s\n", ent.filename, buf, ent.attr);
 		total_count++;
 		total_size += ent.filesize;
 	}
@@ -669,7 +674,7 @@ static int cmd_listfilters(const struct command *c, int argc, char *argv[])
 
 	for (i = 0; filters[i]; i++)
 	{
-		fprintf(stdout, "  %-10s%s\n",
+		fprintf(stdout, "  %-11s%s\n",
 			filter_get_info_string(filters[i], FILTINFO_STR_NAME),
 			filter_get_info_string(filters[i], FILTINFO_STR_NAME));
 	}
@@ -928,4 +933,3 @@ done:
 		imgtool_library_close(library);
 	return result;
 }
-
