@@ -9,9 +9,9 @@
 
 ***************************************************************************/
 
-#include "driver.h"
 #include <stdarg.h>
-#include <string.h>
+#include "driver.h"
+#include "hash.h"
 #include "audit.h"
 #include "harddisk.h"
 #include "sound/samples.h"
