@@ -32,11 +32,8 @@
  *  implement the ARM7TDMI guideline format is used
  ******************************************************************************/
 
-#include <stdio.h>
 #include "arm7core.h"
 
-#ifdef MAME_DEBUG
-
 static char *WritePadding( char *pBuf, const char *pBuf0 )
 {
 	pBuf0 += 8;
@@ -122,7 +119,7 @@ static char *WriteImmediateOperand( char *pBuf, UINT32 opcode )
 static char *WriteDataProcessingOperand( char *pBuf, UINT32 opcode, int printOp0, int printOp1, int printOp2 )
 {
 	/* ccccctttmmmm */
-	const char *pRegOp[4] = { "LSL","LSR","ASR","ROR" };
+	static const char *pRegOp[4] = { "LSL","LSR","ASR","ROR" };
 
 	if (printOp0)
 		pBuf += sprintf(pBuf,"R%d, ", (opcode>>12)&0xf);
@@ -161,7 +158,7 @@ static char *WriteDataProcessingOperand( char *pBuf, UINT32 opcode, int printOp0
 static char *WriteRegisterOperand1( char *pBuf, UINT32 opcode )
 {
 	/* ccccctttmmmm */
-	const char *pRegOp[4] = { "LSL","LSR","ASR","ROR" };
+	static const char *pRegOp[4] = { "LSL","LSR","ASR","ROR" };
 
 	pBuf += sprintf(
 		pBuf,
@@ -619,5 +616,3 @@ void arm7_disasm( char *pBuf, UINT32 pc, UINT32 opcode )
 		pBuf += sprintf( pBuf, "Undefined" );
 	}
 }
-
-#endif	/*MAME_DEBUG */
