@@ -65,7 +65,7 @@ static void update_interrupts(void)
 }
 
 
-static MACHINE_INIT( atarig42 )
+static MACHINE_RESET( atarig42 )
 {
 	atarigen_eeprom_reset();
 	atarigen_interrupt_reset(update_interrupts);
@@ -513,7 +513,7 @@ static MACHINE_DRIVER_START( atarig42 )
 	MDRV_FRAMES_PER_SECOND(60)
 	MDRV_VBLANK_DURATION(DEFAULT_REAL_60HZ_VBLANK_DURATION)
 
-	MDRV_MACHINE_INIT(atarig42)
+	MDRV_MACHINE_RESET(atarig42)
 	MDRV_NVRAM_HANDLER(atarigen)
 
 	/* video hardware */
