@@ -72,7 +72,7 @@ static void update_interrupts(void)
 }
 
 
-static MACHINE_INIT( atarigt )
+static MACHINE_RESET( atarigt )
 {
 	atarigen_eeprom_reset();
 	atarigen_interrupt_reset(update_interrupts);
@@ -814,7 +814,7 @@ static MACHINE_DRIVER_START( atarigt )
 	MDRV_FRAMES_PER_SECOND(60)
 	MDRV_VBLANK_DURATION(DEFAULT_REAL_60HZ_VBLANK_DURATION)
 
-	MDRV_MACHINE_INIT(atarigt)
+	MDRV_MACHINE_RESET(atarigt)
 	MDRV_NVRAM_HANDLER(atarigen)
 
 	/* video hardware */
