@@ -48,7 +48,7 @@ static void update_interrupts(void)
 }
 
 
-static MACHINE_INIT( blstroid )
+static MACHINE_RESET( blstroid )
 {
 	atarigen_eeprom_reset();
 	atarigen_interrupt_reset(update_interrupts);
@@ -201,7 +201,7 @@ static MACHINE_DRIVER_START( blstroid )
 	MDRV_FRAMES_PER_SECOND(60)
 	MDRV_VBLANK_DURATION(DEFAULT_REAL_60HZ_VBLANK_DURATION)
 
-	MDRV_MACHINE_INIT(blstroid)
+	MDRV_MACHINE_RESET(blstroid)
 	MDRV_NVRAM_HANDLER(atarigen)
 
 	/* video hardware */
