@@ -47,7 +47,6 @@ can take. Should the game reset????
 ***************************************************************************/
 
 #include "driver.h"
-#include "vidhrdw/generic.h"
 #include "cpu/m6502/m6502.h"
 #include "sound/ay8910.h"
 
@@ -60,7 +59,7 @@ extern UINT8 *deco_charram;
 PALETTE_INIT( btime );
 PALETTE_INIT( lnc );
 
-MACHINE_INIT( lnc );
+MACHINE_RESET( lnc );
 
 VIDEO_START( btime );
 VIDEO_START( bnj );
@@ -1365,7 +1364,7 @@ static MACHINE_DRIVER_START( lnc )
 	MDRV_CPU_MODIFY("sound")
 	MDRV_CPU_VBLANK_INT(lnc_sound_interrupt,16)
 
-	MDRV_MACHINE_INIT(lnc)
+	MDRV_MACHINE_RESET(lnc)
 
 	/* video hardware */
 	MDRV_GFXDECODE(lnc_gfxdecodeinfo)
