@@ -26,7 +26,6 @@
 *******************************************************************************/
 
 #include "driver.h"
-#include "vidhrdw/generic.h"
 #include "cpu/m6809/m6809.h"
 #include "sound/ay8910.h"
 #include "sound/2203intf.h"
@@ -722,7 +721,7 @@ static const gfx_decode zerotrgt_gfxdecodeinfo[] =
 
 /***************************************************************************/
 
-MACHINE_INIT( zerotrgt )
+MACHINE_RESET( zerotrgt )
 {
 	nmimask = 0;
 }
@@ -786,7 +785,7 @@ static MACHINE_DRIVER_START( zerotrgt )
 	MDRV_SCREEN_SIZE(256, 256)
 	MDRV_VISIBLE_AREA(0*8, 32*8-1, 0*8, 32*8-1)
 
-	MDRV_MACHINE_INIT(zerotrgt)
+	MDRV_MACHINE_RESET(zerotrgt)
 
 	/* interleave 200? */
 	MDRV_GFXDECODE(zerotrgt_gfxdecodeinfo)
