@@ -40,7 +40,7 @@ static void dragrace_frame_callback(int dummy)
 }
 
 
-static MACHINE_INIT( dragrace )
+static MACHINE_RESET( dragrace )
 {
 	timer_pulse(cpu_getscanlinetime(0), 0, dragrace_frame_callback);
 }
@@ -339,7 +339,7 @@ static MACHINE_DRIVER_START( dragrace )
 	MDRV_FRAMES_PER_SECOND(60)
 	MDRV_VBLANK_DURATION((int) ((22. * 1000000) / (262. * 60) + 0.5))
 
-	MDRV_MACHINE_INIT(dragrace)
+	MDRV_MACHINE_RESET(dragrace)
 
 	/* video hardware */
 	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
