@@ -37,7 +37,6 @@ TODO:
 */
 
 #include "driver.h"
-#include "vidhrdw/generic.h"
 #include "machine/8255ppi.h"
 #include "sound/sn76496.h"
 
@@ -79,7 +78,7 @@ static ppi8255_interface ppi8255_intf =
 	{ NULL,             NULL },				/* Port C write */
 };
 
-MACHINE_INIT( freekckb )
+MACHINE_RESET( freekckb )
 {
 	ppi8255_init(&ppi8255_intf);
 }
@@ -920,7 +919,7 @@ static MACHINE_DRIVER_START( freekckb )
 
 	MDRV_FRAMES_PER_SECOND(60)
 	MDRV_VBLANK_DURATION(DEFAULT_60HZ_VBLANK_DURATION)
-	MDRV_MACHINE_INIT(freekckb)
+	MDRV_MACHINE_RESET(freekckb)
 
 	MDRV_GFXDECODE(gfxdecodeinfo)
 
