@@ -46,7 +46,6 @@
 
 #include "driver.h"
 #include "cpu/m68000/m68000.h"
-#include "vidhrdw/generic.h"
 #include "vidhrdw/taitoic.h"
 #include "sndhrdw/taitosnd.h"
 #include "machine/eeprom.h"
@@ -378,7 +377,7 @@ static const gfx_decode gunbustr_gfxdecodeinfo[] =
                  MACHINE DRIVERS
 ***********************************************************/
 
-static MACHINE_INIT( gunbustr )
+static MACHINE_RESET( gunbustr )
 {
 	/* Sound cpu program loads to 0xc00000 so we use a bank */
 	UINT16 *ROM = (UINT16 *)memory_region(REGION_CPU2);
@@ -448,7 +447,7 @@ static MACHINE_DRIVER_START( gunbustr )
 	MDRV_FRAMES_PER_SECOND(60)
 	MDRV_VBLANK_DURATION(DEFAULT_60HZ_VBLANK_DURATION)
 
-	MDRV_MACHINE_INIT(gunbustr)
+	MDRV_MACHINE_RESET(gunbustr)
 	MDRV_NVRAM_HANDLER(gunbustr)
 
 	/* video hardware */
