@@ -436,6 +436,25 @@ VIDEO_START( hornet )
 	return K037122_vh_start();
 }
 
+VIDEO_START( hornet_2board )
+{
+	if (voodoo_version == 0)
+	{
+		if (voodoo_start(0, VOODOO_1, 2, 4, 0) ||
+		    voodoo_start(1, VOODOO_1, 2, 4, 0))
+			return 1;
+	}
+	else
+	{
+		if (voodoo_start(0, VOODOO_2, 2, 4, 0) ||
+			voodoo_start(1, VOODOO_2, 2, 4, 0))
+			return 1;
+	}
+
+	return K037122_vh_start();
+}
+
+
 VIDEO_UPDATE( hornet )
 {
 	voodoo_update(0, bitmap, cliprect);
@@ -447,6 +466,18 @@ VIDEO_UPDATE( hornet )
 	draw_7segment_led(bitmap, 9, 3, led_reg1);
 }
 
+VIDEO_UPDATE( hornet_2board )
+{
+	voodoo_update(0, bitmap, cliprect);
+	voodoo_update(1, bitmap, cliprect);
+
+	K037122_tile_update();
+	K037122_tile_draw(bitmap, cliprect);
+
+	draw_7segment_led(bitmap, 3, 3, led_reg0);
+	draw_7segment_led(bitmap, 9, 3, led_reg1);
+}
+
 /*****************************************************************************/
 
 static READ32_HANDLER( sysreg_r )
@@ -664,16 +695,26 @@ ADDRESS_MAP_END
 
 /*****************************************************************************/
 
-static UINT32 *sharc_dataram;
+static UINT32 *sharc_dataram[2];
 
-static READ32_HANDLER( dsp_dataram_r )
+static READ32_HANDLER( dsp_dataram0_r )
 {
-	return sharc_dataram[offset] & 0xffff;
+	return sharc_dataram[0][offset] & 0xffff;
 }
 
-static WRITE32_HANDLER( dsp_dataram_w )
+static WRITE32_HANDLER( dsp_dataram0_w )
 {
-	sharc_dataram[offset] = data;
+	sharc_dataram[0][offset] = data;
+}
+
+static READ32_HANDLER( dsp_dataram1_r )
+{
+	return sharc_dataram[1][offset] & 0xffff;
+}
+
+static WRITE32_HANDLER( dsp_dataram1_w )
+{
+	sharc_dataram[1][offset] = data;
 }
 
 /* Konami 033906 seems to be a PCI bridge chip between SHARC and 3dfx chips */
@@ -690,7 +731,7 @@ READ32_HANDLER(pci_3dfx_r)
 		case 0x0f:		return pci_3dfx_reg[0x0f];		/* interrupt_line, interrupt_pin, min_gnt, max_lat */
 
 		default:
-			osd_die("pci_3dfx_r: %08X at %08X\n", offset, activecpu_get_pc());
+			fatalerror("pci_3dfx_r: %08X at %08X", offset, activecpu_get_pc());
 	}
 	return 0;
 }
@@ -738,13 +779,13 @@ WRITE32_HANDLER(pci_3dfx_w)
 			break;
 
 		default:
-			osd_die("pci_3dfx_w: %08X, %08X at %08X\n", data, offset, activecpu_get_pc());
+			fatalerror("pci_3dfx_w: %08X, %08X at %08X", data, offset, activecpu_get_pc());
 	}
 }
 
-static ADDRESS_MAP_START( sharc_map, ADDRESS_SPACE_DATA, 32 )
+static ADDRESS_MAP_START( sharc0_map, ADDRESS_SPACE_DATA, 32 )
 	AM_RANGE(0x0400000, 0x041ffff) AM_READWRITE(cgboard_dsp_shared_r_sharc, cgboard_dsp_shared_w_sharc)
-	AM_RANGE(0x0500000, 0x05fffff) AM_READWRITE(dsp_dataram_r, dsp_dataram_w)
+	AM_RANGE(0x0500000, 0x05fffff) AM_READWRITE(dsp_dataram0_r, dsp_dataram0_w)
 	AM_RANGE(0x1400000, 0x14fffff) AM_RAM
 	AM_RANGE(0x2400000, 0x27fffff) AM_READWRITE(voodoo_0_r, voodoo_0_w)
 	AM_RANGE(0x3400000, 0x34000ff) AM_READWRITE(cgboard_dsp_comm_r_sharc, cgboard_dsp_comm_w_sharc)
@@ -752,6 +793,16 @@ static ADDRESS_MAP_START( sharc_map, ADDRESS_SPACE_DATA, 32 )
 	AM_RANGE(0x3600000, 0x37fffff) AM_ROMBANK(5)
 ADDRESS_MAP_END
 
+static ADDRESS_MAP_START( sharc1_map, ADDRESS_SPACE_DATA, 32 )
+	AM_RANGE(0x0400000, 0x041ffff) AM_READWRITE(cgboard_dsp_shared_r_sharc, cgboard_dsp_shared_w_sharc)
+	AM_RANGE(0x0500000, 0x05fffff) AM_READWRITE(dsp_dataram1_r, dsp_dataram1_w)
+	AM_RANGE(0x1400000, 0x14fffff) AM_RAM
+	AM_RANGE(0x2400000, 0x27fffff) AM_READWRITE(voodoo_1_r, voodoo_1_w)
+	AM_RANGE(0x3400000, 0x34000ff) AM_READWRITE(cgboard_dsp_comm_r_sharc, cgboard_dsp_comm_w_sharc)
+	AM_RANGE(0x3500000, 0x35000ff) AM_READWRITE(pci_3dfx_r, pci_3dfx_w)
+	AM_RANGE(0x3600000, 0x37fffff) AM_ROMBANK(5)
+ADDRESS_MAP_END
+
 /*****************************************************************************/
 
 INPUT_PORTS_START( hornet )
@@ -839,7 +890,7 @@ static INTERRUPT_GEN( hornet_vblank )
 	cpunum_set_input_line(0, INPUT_LINE_IRQ0, ASSERT_LINE);
 }
 
-static MACHINE_INIT( hornet )
+static MACHINE_RESET( hornet )
 {
 	memory_set_bankptr(1, memory_region(REGION_USER3));
 	cpunum_set_input_line(2, INPUT_LINE_RESET, ASSERT_LINE);
@@ -860,12 +911,12 @@ static MACHINE_DRIVER_START( hornet )
 
 	MDRV_CPU_ADD(ADSP21062, 36000000)
 	MDRV_CPU_CONFIG(sharc_cfg)
-	MDRV_CPU_DATA_MAP(sharc_map, 0)
+	MDRV_CPU_DATA_MAP(sharc0_map, 0)
 
 	MDRV_FRAMES_PER_SECOND(60)
 	MDRV_VBLANK_DURATION(DEFAULT_REAL_60HZ_VBLANK_DURATION)
 
-	MDRV_MACHINE_INIT( hornet )
+	MDRV_MACHINE_RESET( hornet )
 
 	MDRV_NVRAM_HANDLER( timekeeper_0 )
 
@@ -902,7 +953,7 @@ static INTERRUPT_GEN( hornet_2board_vblank )
 	vblank &= 1;
 }
 
-static MACHINE_INIT( hornet_2board )
+static MACHINE_RESET( hornet_2board )
 {
 	memory_set_bankptr(1, memory_region(REGION_USER3));
 	cpunum_set_input_line(2, INPUT_LINE_RESET, ASSERT_LINE);
@@ -919,9 +970,18 @@ static MACHINE_DRIVER_START( hornet_2board )
 
 	MDRV_CPU_ADD(ADSP21062, 36000000)
 	MDRV_CPU_CONFIG(sharc_cfg)
-	MDRV_CPU_DATA_MAP(sharc_map, 0)
+	MDRV_CPU_DATA_MAP(sharc1_map, 0)
 
-	MDRV_MACHINE_INIT(hornet_2board)
+	MDRV_MACHINE_RESET(hornet_2board)
+
+	MDRV_VIDEO_START(hornet_2board)
+	MDRV_VIDEO_UPDATE(hornet_2board)
+
+	/* video hardware */
+	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER | VIDEO_NEEDS_6BITS_PER_GUN | VIDEO_RGB_DIRECT)
+	MDRV_SCREEN_SIZE(128*8, 48*8)
+	MDRV_VISIBLE_AREA(0*8, 128*8-1, 0*8, 48*8-1)
+	MDRV_PALETTE_LENGTH(65536)
 MACHINE_DRIVER_END
 
 
@@ -943,9 +1003,27 @@ static void jamma_w(int length)
 static UINT8 backup_ram[0x2000];
 static DRIVER_INIT( hornet )
 {
-	init_konami_cgboard(0);
+	init_konami_cgboard(0, CGBOARD_TYPE_HORNET);
 	set_cgboard_texture_bank(5);
-	sharc_dataram = auto_malloc(0x100000);
+	sharc_dataram[0] = auto_malloc(0x100000);
+
+	m68k_timer = timer_alloc(m68k_timer_tick);
+	timer_adjust(m68k_timer, TIME_IN_MSEC(1000.0/(44100.0/128.0)), 0, TIME_IN_MSEC(1000.0/(44100.0/128.0)));
+
+	timekeeper_init(0, TIMEKEEPER_M48T58, backup_ram);
+
+	ppc403_install_spu_tx_dma_handler(jamma_w, jamma_wdata);
+	ppc403_install_spu_rx_dma_handler(jamma_r, jamma_rdata);
+}
+
+static DRIVER_INIT( hornet_2board )
+{
+	init_konami_cgboard(0, CGBOARD_TYPE_HORNET);
+	init_konami_cgboard(1, CGBOARD_TYPE_HORNET);
+
+	set_cgboard_texture_bank(5);
+	sharc_dataram[0] = auto_malloc(0x100000);
+	sharc_dataram[1] = auto_malloc(0x100000);
 
 	m68k_timer = timer_alloc(m68k_timer_tick);
 	timer_adjust(m68k_timer, TIME_IN_MSEC(1000.0/(44100.0/128.0)), 0, TIME_IN_MSEC(1000.0/(44100.0/128.0)));
@@ -1045,9 +1123,7 @@ static DRIVER_INIT(sscope)
 	backup_ram[0x0f] = (checksum >> 0) & 0xff;	/* checksum */
 
 	voodoo_version = 0;
-	init_hornet();
-
-	init_konami_cgboard(1);
+	init_hornet_2board();
 }
 
 static DRIVER_INIT(sscope2)
@@ -1109,9 +1185,7 @@ static DRIVER_INIT(sscope2)
 	backup_ram[0x1f4f] = (checksum >> 0) & 0xff;	/* checksum */
 
 	voodoo_version = 1;
-	init_hornet();
-
-	init_konami_cgboard(1);
+	init_hornet_2board();
 }
 
 /*****************************************************************************/
@@ -1134,6 +1208,24 @@ ROM_START(sscope)
         ROM_LOAD( "ss1-1.14p",    0x200000, 0x200000, CRC(a5bd9a93) SHA1(c789a272b9f2b449b07fff1c04b6c9ef3ca6bfe0) )
 ROM_END
 
+ROM_START(sscopea)
+	ROM_REGION32_BE(0x200000, REGION_USER1, 0)	/* PowerPC program */
+	ROM_LOAD16_WORD_SWAP("830_a01.bin", 0x000000, 0x200000, CRC(39e353f1) SHA1(569b06969ae7a690f6d6e63cc3b5336061663a37))
+
+	ROM_REGION32_BE(0x800000, REGION_USER2, 0)	/* Data roms */
+
+	ROM_REGION(0x80000, REGION_CPU2, 0)		/* 68K Program */
+	ROM_LOAD16_WORD_SWAP("ss1-1.7s", 0x000000, 0x80000, CRC(2805ea1d) SHA1(2556a51ee98cb8f59bf081e916c69a24532196f1))
+
+	ROM_REGION(0x800000, REGION_USER5, 0)		/* CG Board texture roms */
+    	ROM_LOAD32_WORD_SWAP( "ss1-3.u32",    0x000000, 0x400000, CRC(335793e1) SHA1(d582b53c3853abd59bc728f619a30c27cfc9497c) )
+    	ROM_LOAD32_WORD_SWAP( "ss1-3.u24",    0x000002, 0x400000, CRC(d6e7877e) SHA1(b4d0e17ada7dd126ec564a20e7140775b4b3fdb7) )
+
+	ROM_REGION(0x400000, REGION_SOUND1, 0)		/* PCM sample roms */
+        ROM_LOAD( "ss1-1.16p",    0x000000, 0x200000, CRC(4503ff1e) SHA1(2c208a1e9a5633c97e8a8387b7fcc7460013bc2c) )
+        ROM_LOAD( "ss1-1.14p",    0x200000, 0x200000, CRC(a5bd9a93) SHA1(c789a272b9f2b449b07fff1c04b6c9ef3ca6bfe0) )
+ROM_END
+
 ROM_START(sscope2)
 	ROM_REGION32_BE(0x200000, REGION_USER1, 0)	/* PowerPC program */
 	ROM_LOAD16_WORD_SWAP("931d01.bin", 0x000000, 0x200000, CRC(4065fde6) SHA1(84f2dedc3e8f61651b22c0a21433a64993e1b9e2))
@@ -1204,5 +1296,6 @@ ROM_END
 
 GAME( 1998, gradius4,	0,		hornet,			hornet,	gradius4,	ROT0,	"Konami",	"Gradius 4: Fukkatsu", GAME_IMPERFECT_SOUND )
 GAME( 1998, nbapbp,		0,		hornet,			hornet,	nbapbp,		ROT0,	"Konami",	"NBA Play By Play", GAME_IMPERFECT_SOUND )
-GAME( 2000, sscope,		0,		hornet_2board,	hornet,	sscope,		ROT0,	"Konami",	"Silent Scope", GAME_IMPERFECT_SOUND|GAME_NOT_WORKING )
+GAME( 2000, sscope,		0,		hornet_2board,	hornet,	sscope,		ROT0,	"Konami",	"Silent Scope (ver UAB)", GAME_IMPERFECT_SOUND|GAME_NOT_WORKING )
+GAME( 2000, sscopea,	sscope, hornet_2board,	hornet,	sscope,		ROT0,	"Konami",	"Silent Scope (ver UAA)", GAME_IMPERFECT_SOUND|GAME_NOT_WORKING )
 GAME( 2000, sscope2,	0,		hornet_2board,	hornet,	sscope2,	ROT0,	"Konami",	"Silent Scope 2", GAME_IMPERFECT_SOUND|GAME_NOT_WORKING )
