@@ -66,7 +66,7 @@ static WRITE16_HANDLER( interrupt_ack_w )
  *
  *************************************/
 
-static MACHINE_INIT( klax )
+static MACHINE_RESET( klax )
 {
 	atarigen_eeprom_reset();
 	atarigen_interrupt_reset(update_interrupts);
@@ -205,7 +205,7 @@ static MACHINE_DRIVER_START( klax )
 	MDRV_FRAMES_PER_SECOND(60)
 	MDRV_VBLANK_DURATION(DEFAULT_REAL_60HZ_VBLANK_DURATION)
 
-	MDRV_MACHINE_INIT(klax)
+	MDRV_MACHINE_RESET(klax)
 	MDRV_NVRAM_HANDLER(atarigen)
 
 	/* video hardware */
