@@ -25,15 +25,13 @@ Notes:
 *****************************************************************************/
 
 #include "driver.h"
-#include "vidhrdw/generic.h"
 #include "m92.h"
 #include "machine/irem_cpu.h"
 #include "sndhrdw/m72.h"
-#include "state.h"
 #include "sound/dac.h"
 #include "sound/2151intf.h"
 
-static int bankaddress;
+static UINT32 bankaddress;
 
 extern UINT8 *m90_video_data;
 
@@ -93,7 +91,7 @@ static ADDRESS_MAP_START( writemem, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0x80000, 0x8ffff) AM_WRITE(MWA8_ROM)	/* Quiz F1 only */
 	AM_RANGE(0xa0000, 0xa3fff) AM_WRITE(MWA8_RAM)
 	AM_RANGE(0xd0000, 0xdffff) AM_WRITE(m90_video_w) AM_BASE(&m90_video_data)
-	AM_RANGE(0xe0000, 0xe03ff) AM_WRITE(paletteram_xBBBBBGGGGGRRRRR_w) AM_BASE(&paletteram)
+	AM_RANGE(0xe0000, 0xe03ff) AM_WRITE(paletteram_xBBBBBGGGGGRRRRR_le_w) AM_BASE(&paletteram)
 	AM_RANGE(0xffff0, 0xfffff) AM_WRITE(MWA8_ROM)
 ADDRESS_MAP_END
 
@@ -111,7 +109,7 @@ static ADDRESS_MAP_START( bootleg_writemem, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0x6000e, 0x60fff) AM_WRITE(MWA8_RAM) AM_BASE(&spriteram)
 	AM_RANGE(0xa0000, 0xa3fff) AM_WRITE(MWA8_RAM)
 /*  AM_RANGE(0xd0000, 0xdffff) AM_WRITE(m90_bootleg_video_w) AM_BASE(&m90_video_data) */
-	AM_RANGE(0xe0000, 0xe03ff) AM_WRITE(paletteram_xBBBBBGGGGGRRRRR_w) AM_BASE(&paletteram)
+	AM_RANGE(0xe0000, 0xe03ff) AM_WRITE(paletteram_xBBBBBGGGGGRRRRR_le_w) AM_BASE(&paletteram)
 	AM_RANGE(0xffff0, 0xfffff) AM_WRITE(MWA8_ROM)
 ADDRESS_MAP_END
 
@@ -710,7 +708,7 @@ static MACHINE_DRIVER_START( m90 )
 	MDRV_FRAMES_PER_SECOND(60)
 	MDRV_VBLANK_DURATION(DEFAULT_60HZ_VBLANK_DURATION)
 
-	MDRV_MACHINE_INIT(m72_sound)
+	MDRV_MACHINE_RESET(m72_sound)
 
 	/* video hardware */
 	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
@@ -758,7 +756,7 @@ static MACHINE_DRIVER_START( bombrman )
 								/* IRQs are generated by main Z80 and YM2151 */
 	MDRV_FRAMES_PER_SECOND(60)
 	MDRV_VBLANK_DURATION(DEFAULT_60HZ_VBLANK_DURATION)
-	MDRV_MACHINE_INIT(m72_sound)
+	MDRV_MACHINE_RESET(m72_sound)
 
 	/* video hardware */
 	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
@@ -799,7 +797,7 @@ static MACHINE_DRIVER_START( bbmanw )
 								/* IRQs are generated by main Z80 and YM2151 */
 	MDRV_FRAMES_PER_SECOND(60)
 	MDRV_VBLANK_DURATION(DEFAULT_60HZ_VBLANK_DURATION)
-	MDRV_MACHINE_INIT(m72_sound)
+	MDRV_MACHINE_RESET(m72_sound)
 
 	/* video hardware */
 	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
@@ -847,7 +845,7 @@ static MACHINE_DRIVER_START( bootleg )
 								/* IRQs are generated by main Z80 and YM2151 */
 	MDRV_FRAMES_PER_SECOND(60)
 	MDRV_VBLANK_DURATION(DEFAULT_60HZ_VBLANK_DURATION)
-	MDRV_MACHINE_INIT(m72_sound)
+	MDRV_MACHINE_RESET(m72_sound)
 
 	/* video hardware */
 	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
@@ -1187,7 +1185,7 @@ static DRIVER_INIT( quizf1 )
 	bankaddress = 0;
 	set_m90_bank();
 
-	state_save_register_int("main", 0, "bankaddress", &bankaddress);
+	state_save_register_global(bankaddress);
 	state_save_register_func_postload(set_m90_bank);
 }
 
