@@ -37,7 +37,6 @@ TODO:
 ******************************************************************************/
 
 #include "driver.h"
-#include "vidhrdw/generic.h"
 #include "sound/es5506.h"
 
 /*** README INFO **************************************************************
@@ -270,8 +269,6 @@ static READ32_HANDLER ( macrossp_soundstatus_r )
 
 	toggle ^= 1;
 
-	if (Machine->sample_rate == 0) return (rand()&2) | toggle;
-
 	return (sndpending << 1) | toggle;
 }
 
