@@ -270,11 +270,9 @@ GFX:                Custom 145     ( 80 pin PQFP)
                     Custom 169     (120 pin PQFP)
 */
 #include "driver.h"
-#include "vidhrdw/generic.h"
 #include "namconb1.h"
 #include "namcos2.h"
 #include "namcoic.h"
-#include "machine/random.h"
 #include "sndhrdw/namcoc7x.h"
 
 #define NB1_NVMEM_SIZE (0x800)
