@@ -278,7 +278,6 @@ CPU68 PCB:
   JP3
 */
 #include "driver.h"
-#include "vidhrdw/generic.h"
 #include "namcos2.h"
 #include "cpu/m6809/m6809.h"
 #include "cpu/tms32025/tms32025.h"
@@ -1394,7 +1393,7 @@ static MACHINE_DRIVER_START( s21base )
 	MDRV_VBLANK_DURATION(DEFAULT_REAL_60HZ_VBLANK_DURATION)
 	MDRV_INTERLEAVE(10/*0*/)
 
-	MDRV_MACHINE_INIT(namcos2)
+	MDRV_MACHINE_RESET(namcos2)
 	MDRV_NVRAM_HANDLER(namcos2)
 
 	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER | VIDEO_NEEDS_6BITS_PER_GUN)
@@ -1465,7 +1464,7 @@ static MACHINE_DRIVER_START( winrun_c140_typeB )
 	MDRV_VBLANK_DURATION(DEFAULT_REAL_60HZ_VBLANK_DURATION)
 	MDRV_INTERLEAVE(100) /* 100 CPU slices per frame */
 
-	MDRV_MACHINE_INIT(namcos2)
+	MDRV_MACHINE_RESET(namcos2)
 	MDRV_NVRAM_HANDLER(namcos2)
 
 	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER | VIDEO_NEEDS_6BITS_PER_GUN)
