@@ -121,9 +121,7 @@ Notes:
 */
 
 #include "driver.h"
-#include "vidhrdw/generic.h"
 #include "cpu/arm7/arm7core.h"
-#include "machine/random.h"
 
 enum
 {
@@ -523,7 +521,7 @@ static ADDRESS_MAP_START( ppcar_map, ADDRESS_SPACE_PROGRAM, 32 )
 ADDRESS_MAP_END
 
 
-static MACHINE_INIT( ssfindo )
+static MACHINE_RESET( ssfindo )
 {
 	PS7500_reset();
 }
@@ -617,7 +615,7 @@ static MACHINE_DRIVER_START( ssfindo )
 	MDRV_VBLANK_DURATION(DEFAULT_REAL_60HZ_VBLANK_DURATION)
 
 	MDRV_CPU_VBLANK_INT(ssfindo_interrupt,1)
-	MDRV_MACHINE_INIT(ssfindo)
+	MDRV_MACHINE_RESET(ssfindo)
 
 	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
 	MDRV_SCREEN_SIZE(320, 256)
@@ -639,7 +637,7 @@ static MACHINE_DRIVER_START( ppcar )
 	MDRV_VBLANK_DURATION(DEFAULT_REAL_60HZ_VBLANK_DURATION)
 
 	MDRV_CPU_VBLANK_INT(ssfindo_interrupt,1)
-	MDRV_MACHINE_INIT(ssfindo)
+	MDRV_MACHINE_RESET(ssfindo)
 
 	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
 	MDRV_SCREEN_SIZE(320, 256)
