@@ -12,32 +12,6 @@ Not working games :
 - Super Eagle Shot
    RAM 0x0a000000 - 0x0a003fff (8bit) is shared with ST-0016 ($f000-$ffff)
    after boot, r3000 writes there "KCUFUOY" , and  ST-0016 "YOU!" ;)
-
---
-Renjyu Kizoku
-Visco, 1994
-
-PCB Layout
-
-E51-00001-A
-|------------------------------------|
-|AMP       UPD6376    424400  62256  |
-|    VOL      RESET   424400  62256  |
-|                                    |
-| TD62064 74273                      |
-|J        74273                      |
-|A        74273            42.9545MHz|
-|M                                   |
-|M        74245         UNKNOWN      |
-|A        74245          QFP208      |
-|         74245                      |
-|         74245                 48MHz|
-|                                    |
-|  74138  74138                      |
-|  74253  74253       RNJ2           |
-|                                    |
-|  DSW1   DSW2        RENJYU-1  6264 |
-|------------------------------------|
 */
 
 #include "driver.h"
@@ -66,6 +40,12 @@ void st0016_save_init(void);
 static int mux_port;
 int st0016_rom_bank;
 
+/*************************************
+ *
+ *  Machine's structure ST0016
+ *
+ *************************************/
+
 static ADDRESS_MAP_START( st0016_mem, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x7fff) AM_ROM
 	AM_RANGE(0x8000, 0xbfff) AM_ROMBANK(1)
@@ -128,219 +108,11 @@ static ADDRESS_MAP_START( st0016_io, ADDRESS_SPACE_IO, 8 )
 ADDRESS_MAP_END
 
 
-INPUT_PORTS_START( renju )
-	PORT_START_TAG("IN0")
-	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_JOYSTICK_UP ) PORT_PLAYER(1)
-	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN ) PORT_PLAYER(1)
-	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT ) PORT_PLAYER(1)
-	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_JOYSTICK_RIGHT ) PORT_PLAYER(1)
-	PORT_BIT( 0x10, IP_ACTIVE_LOW, IPT_BUTTON1 ) PORT_PLAYER(1)
-	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_BUTTON2 ) PORT_PLAYER(1)
-	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_BUTTON3 ) PORT_PLAYER(1)
-	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_START1 )
-
-	PORT_START_TAG("IN1")
-	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_JOYSTICK_UP ) PORT_PLAYER(2)
-	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN ) PORT_PLAYER(2)
-	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT ) PORT_PLAYER(2)
-	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_JOYSTICK_RIGHT ) PORT_PLAYER(2)
-	PORT_BIT( 0x10, IP_ACTIVE_LOW, IPT_BUTTON1 ) PORT_PLAYER(2)
-	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_BUTTON2 ) PORT_PLAYER(2)
-	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_BUTTON3 ) PORT_PLAYER(2)
-	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_START2 )
-
-	PORT_START_TAG("IN2")
-	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_COIN1 )
-	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_COIN2 )
-	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_SERVICE1 )
-	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_UNKNOWN )
-
-	PORT_START_TAG("IN3")
-	PORT_BIT( 0xff, IP_ACTIVE_LOW, IPT_UNKNOWN ) /* unused ? */
-
-	PORT_START_TAG("DSW1")
-	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_UNKNOWN )
-	PORT_DIPNAME( 0x02, 0x02, DEF_STR( Flip_Screen ) )
-	PORT_DIPSETTING(    0x02, DEF_STR( Off ) )
-	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
-	PORT_SERVICE( 0x04, IP_ACTIVE_LOW )
-	PORT_DIPNAME( 0x08, 0x08, DEF_STR( Demo_Sounds ) )
-	PORT_DIPSETTING(    0x00, DEF_STR( Off ) )
-	PORT_DIPSETTING(    0x08, DEF_STR( On ) )
-	PORT_DIPNAME( 0x30, 0x30, DEF_STR( Coin_A ) )
-	PORT_DIPSETTING(      0x20, DEF_STR( 2C_1C ) )
-	PORT_DIPSETTING(      0x30, DEF_STR( 1C_1C ) )
-	PORT_DIPSETTING(      0x00, DEF_STR( 2C_3C ) )
-	PORT_DIPSETTING(      0x10, DEF_STR( 1C_2C ) )
-	PORT_DIPNAME( 0xc0, 0xc0, DEF_STR( Coin_B ) )
-	PORT_DIPSETTING(      0x80, DEF_STR( 2C_1C ) )
-	PORT_DIPSETTING(      0xc0, DEF_STR( 1C_1C ) )
-	PORT_DIPSETTING(      0x00, DEF_STR( 2C_3C ) )
-	PORT_DIPSETTING(      0x80, DEF_STR( 1C_2C ) )
-
-	PORT_START_TAG("DSW2")
-	PORT_DIPNAME( 0x03, 0x03, DEF_STR( Difficulty ) )
-	PORT_DIPSETTING(      0x00, DEF_STR( Very_Hard ) )
-	PORT_DIPSETTING(      0x01, DEF_STR( Hard ) )
-	PORT_DIPSETTING(      0x02, DEF_STR( Easy ) )
-	PORT_DIPSETTING(      0x03, DEF_STR( Normal ) )
-	PORT_BIT( 0xfc, IP_ACTIVE_LOW, IPT_UNKNOWN )
-INPUT_PORTS_END
-
-
-INPUT_PORTS_START( nratechu )
-	PORT_START_TAG("IN0")
-	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_JOYSTICK_UP ) PORT_PLAYER(1)
-	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN ) PORT_PLAYER(1)
-	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT ) PORT_PLAYER(1)
-	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_JOYSTICK_RIGHT ) PORT_PLAYER(1)
-	PORT_BIT( 0x10, IP_ACTIVE_LOW, IPT_BUTTON1 ) PORT_PLAYER(1)
-	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_BUTTON2 ) PORT_PLAYER(1)
-	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_BUTTON3 ) PORT_PLAYER(1)
-	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_START1 )
-
-	PORT_START_TAG("IN1")
-	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_JOYSTICK_UP ) PORT_PLAYER(2)
-	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN ) PORT_PLAYER(2)
-	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT ) PORT_PLAYER(2)
-	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_JOYSTICK_RIGHT ) PORT_PLAYER(2)
-	PORT_BIT( 0x10, IP_ACTIVE_LOW, IPT_BUTTON1 ) PORT_PLAYER(2)
-	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_BUTTON2 ) PORT_PLAYER(2)
-	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_BUTTON3 ) PORT_PLAYER(2)
-	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_START2 )
-
-	PORT_START_TAG("IN2")
-	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_COIN1 )
-	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_COIN2 )
-	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_SERVICE1 )
-	PORT_SERVICE( 0x08, IP_ACTIVE_LOW)
-
-	PORT_START_TAG("IN3")
-	PORT_BIT( 0xff, IP_ACTIVE_LOW, IPT_UNKNOWN ) /* read in test mode */
-
-	PORT_START_TAG("DSW1")
-	PORT_DIPNAME( 0x07, 0x07, DEF_STR( Coinage ) )
-	PORT_DIPSETTING(      0x01, DEF_STR( 4C_1C ) )
-	PORT_DIPSETTING(      0x02, DEF_STR( 3C_1C ) )
-	PORT_DIPSETTING(      0x03, DEF_STR( 2C_1C ) )
-	PORT_DIPSETTING(      0x07, DEF_STR( 1C_1C ) )
-	PORT_DIPSETTING(      0x06, DEF_STR( 1C_2C ) )
-	PORT_DIPSETTING(      0x05, DEF_STR( 1C_3C ) )
-	PORT_DIPSETTING(      0x04, DEF_STR( 1C_4C ) )
-	PORT_DIPNAME( 0x08, 0x08, DEF_STR( Unknown ) )
-	PORT_DIPSETTING(    0x08, DEF_STR( Off ) )
-	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
-	PORT_DIPNAME( 0x10, 0x10, DEF_STR( Unknown ) )
-	PORT_DIPSETTING(    0x10, DEF_STR( Off ) )
-	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
-	PORT_DIPNAME( 0x20, 0x20, DEF_STR( Unknown ) )
-	PORT_DIPSETTING(    0x20, DEF_STR( Off ) )
-	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
-	PORT_DIPNAME( 0x40, 0x40, DEF_STR( Unknown ) )
-	PORT_DIPSETTING(    0x40, DEF_STR( Off ) )
-	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
-	PORT_DIPNAME( 0x80, 0x00, DEF_STR( Language ) )
-	PORT_DIPSETTING(    0x00, DEF_STR( English ) )
-	PORT_DIPSETTING(    0x80, DEF_STR( Japanese ) )
-
-	PORT_START_TAG("DSW2")
-	PORT_DIPNAME( 0x03, 0x03, DEF_STR( Difficulty ) ) /*  speed / time.. */
-	PORT_DIPSETTING(    0x02, DEF_STR( Easy ) )
-	PORT_DIPSETTING(    0x03, DEF_STR( Normal ))
-	PORT_DIPSETTING(    0x01, DEF_STR( Hard ) )
-	PORT_DIPSETTING(    0x00, DEF_STR( Hardest ) )
-	PORT_DIPNAME( 0x0C, 0x0C, "VS Round" )
-	PORT_DIPSETTING(    0x00, "1" )
-	PORT_DIPSETTING(    0x0C, "2" )
-	PORT_DIPSETTING(    0x08, "3" )
-	PORT_DIPSETTING(    0x04, "4" )
-	PORT_DIPNAME( 0x10, 0x10, DEF_STR( Unknown ) )
-	PORT_DIPSETTING(    0x10, DEF_STR( Off ) )
-	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
-	PORT_DIPNAME( 0x20, 0x00, DEF_STR( Demo_Sounds ) )
-	PORT_DIPSETTING(    0x20, DEF_STR( Off ) )
-	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
-	PORT_DIPNAME( 0x40, 0x40, DEF_STR( Unknown ) )
-	PORT_DIPSETTING(    0x40, DEF_STR( Off ) )
-	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
-	PORT_DIPNAME( 0x80, 0x80, "Test Mode" )
-	PORT_DIPSETTING(    0x80, DEF_STR( Off ) )
-	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
-INPUT_PORTS_END
-
-static const gfx_decode gfxdecodeinfo[] =
-{
-/*  { 0, 0, &charlayout,      0, 16*4  }, */
-	{ -1 }	/* end of array */
-};
-
-INTERRUPT_GEN(st0016_int)
-{
-	if(!cpu_getiloops())
-		cpunum_set_input_line(0,0,HOLD_LINE);
-	else
-		if(activecpu_get_reg(Z80_IFF1)) /* dirty hack ... */
-			cpunum_set_input_line(0, INPUT_LINE_NMI, PULSE_LINE );
-}
-
-extern UINT8 *st0016_charram;
-static struct ST0016interface st0016_interface =
-{
-	&st0016_charram
-};
-
-static MACHINE_DRIVER_START( st0016 )
-	/* basic machine hardware */
-	MDRV_CPU_ADD_TAG("main",Z80,8000000) /* 8 MHz ? */
-	MDRV_CPU_PROGRAM_MAP(st0016_mem,0)
-	MDRV_CPU_IO_MAP(st0016_io,0)
-
-	MDRV_CPU_VBLANK_INT(st0016_int,5) /*  4*nmi + int0 */
-
-	MDRV_FRAMES_PER_SECOND(60)
-	MDRV_VBLANK_DURATION(DEFAULT_60HZ_VBLANK_DURATION)
-
-	/* video hardware */
-	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
-	MDRV_SCREEN_SIZE(48*8, 48*8)
-	MDRV_VISIBLE_AREA(0*8, 48*8-1, 0*8, 48*8-1)
-	MDRV_GFXDECODE(gfxdecodeinfo)
-	MDRV_PALETTE_LENGTH(16*16*4+1)
-
-	MDRV_VIDEO_START(st0016)
-	MDRV_VIDEO_UPDATE(st0016)
-
-	MDRV_SPEAKER_STANDARD_STEREO("left", "right")
-
-	MDRV_SOUND_ADD(ST0016, 0)
-	MDRV_SOUND_CONFIG(st0016_interface)
-	MDRV_SOUND_ROUTE(0, "left", 1.0)
-	MDRV_SOUND_ROUTE(1, "right", 1.0)
-MACHINE_DRIVER_END
-
-/*
-Super Real Mahjong P5
-(c)199x SETA
-
-CPU   : R3560(custom?)
-SOUND : TC6210AF(custom?)
-OSC.  : 50.0000MHz 42.9545MHz
-
-SX008-01.BIN ; CHR ROM
-SX008-02.BIN ;  |
-SX008-03.BIN ;  |
-SX008-04.BIN ;  |
-SX008-05.BIN ;  |
-SX008-06.BIN ;  |
-SX008-07.BIN ; /
-SX008-08.BIN ; SOUND DATA
-SX008-09.BIN ; /
-SX008-11.BIN ; MAIN PRG
-SX008-12.BIN ;  |
-SX008-13.BIN ;  |
-SX008-14.BIN ; /
-
-*/
+/*************************************
+ *
+ *  Machine's structure ST0016 + R3000
+ *
+ *************************************/
 
 static struct r3000_config config =
 {
@@ -373,79 +145,6 @@ static ADDRESS_MAP_START( srmp5_mem, ADDRESS_SPACE_PROGRAM, 32 )
 	AM_RANGE(0x1fc00000, 0x1fdfffff) AM_READ(MRA32_ROM) AM_WRITE(MWA32_ROM) AM_REGION(REGION_USER1, 0)
 ADDRESS_MAP_END
 
-static MACHINE_DRIVER_START( srmp5 )
-	MDRV_IMPORT_FROM(st0016)
-	MDRV_CPU_ADD(R3000BE, 16000000)
-	MDRV_CPU_CONFIG(config)
-	MDRV_CPU_PROGRAM_MAP(srmp5_mem,0)
-MACHINE_DRIVER_END
-
-INPUT_PORTS_START( srmp5 )
-	PORT_START_TAG("IN0")
-	PORT_BIT( 0xff, IP_ACTIVE_LOW, IPT_UNKNOWN )
-
-	PORT_START_TAG("IN1")
-	PORT_BIT( 0xff, IP_ACTIVE_LOW, IPT_UNKNOWN )
-
-	PORT_START_TAG("IN2")
-	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_COIN1 )
-	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_COIN2 )
-	PORT_SERVICE( 0x04, IP_ACTIVE_LOW)
-	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_UNKNOWN )
-
-	PORT_START_TAG("IN3")
-	PORT_BIT( 0xff, IP_ACTIVE_LOW, IPT_UNKNOWN )
-
-	PORT_START_TAG("IN4")
-	PORT_BIT( 0xff, IP_ACTIVE_LOW, IPT_UNKNOWN )
-
-	PORT_START_TAG("IN5")
-	PORT_BIT( 0xff, IP_ACTIVE_LOW, IPT_UNKNOWN )
-INPUT_PORTS_END
-
-/*
-Super Eagle Shot
-(c)1993 Seta (distributed by Visco)
-E30-001A
-
-CPU  : Integrated Device IDT79R3051-25J 9407C (R3000A)
-Sound: ST-0016
-OSC  : 50.0000MHz (X1) 42.9545MHz (X3)
-
-ROMs:
-SX004-01.PR0 - Main programs (MX27C4000)
-SX004-02.PR1 |
-SX004-03.PR2 |
-SX004-04.PR3 /
-
-SX004-05.RD0 - Graphics? (D23C8000SCZ)
-SX004-06.RD1 /
-
-SX004-07.ZPR - Program? (16M mask, read as 27c160)
-
-GALs (not dumped):
-SX004-08.27 (16V8B)
-SX004-09.46 (16V8B)
-SX004-10.59 (16V8B)
-SX004-11.61 (22V10B)
-SX004-12.62 (22V10B)
-SX004-13.63 (22V10B)
-
-Custom chips:
-SETA ST-0015 60EN502F12 JAPAN 9415YAI (U18, 208pin PQFP, system controller)
-SETA ST-0016 TC6187AF JAPAN 9348YAA (U68, 208pin PQFP, sound & object)
-
-   ?      ST-0015              SX004-01   49.9545MHz    ST-0016       5588-25
-                               SX004-02      52B256-70  514256 514256
- 50MHz                         SX004-03      52B256-70  SX004-07
- 528257-70 514256-70 514256-70 SX004-04
- 528257-70 514256-70 514256-70 SX004-05
- 528257-70 514256-70 514256-70 SX004-06
-           514256-70 514256-70
-                                                NEC D6376
-
-*/
-
 static ADDRESS_MAP_START( speglsht_mem, ADDRESS_SPACE_PROGRAM, 32 )
 	AM_RANGE(0x00000000, 0x000fffff) AM_RAM
 	AM_RANGE(0x01800200, 0x01800203) AM_WRITE(MWA32_RAM)
@@ -457,134 +156,11 @@ static ADDRESS_MAP_START( speglsht_mem, ADDRESS_SPACE_PROGRAM, 32 )
 	AM_RANGE(0x1fc00000, 0x1fdfffff) AM_READ(MRA32_ROM) AM_WRITE(MWA32_ROM) AM_REGION(REGION_USER1, 0)
 ADDRESS_MAP_END
 
-static MACHINE_DRIVER_START( speglsht )
-	MDRV_IMPORT_FROM(st0016)
-	MDRV_CPU_ADD(R3000BE, 16000000)
-	MDRV_CPU_CONFIG(config)
-	MDRV_CPU_PROGRAM_MAP(speglsht_mem,0)
-MACHINE_DRIVER_END
-
-INPUT_PORTS_START( speglsht )
-	PORT_START_TAG("IN0")
-	PORT_BIT( 0xff, IP_ACTIVE_LOW, IPT_UNKNOWN )
-
-	PORT_START_TAG("IN1")
-	PORT_BIT( 0xff, IP_ACTIVE_LOW, IPT_UNKNOWN )
-
-	PORT_START_TAG("IN2")
-	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_COIN1 )
-	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_COIN2 )
-	PORT_SERVICE( 0x04, IP_ACTIVE_LOW)
-	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_UNKNOWN )
-
-	PORT_START_TAG("IN3")
-	PORT_BIT( 0xff, IP_ACTIVE_LOW, IPT_UNKNOWN )
-
-	PORT_START_TAG("DSW1")	/* Dip switch A  */
-	PORT_DIPNAME( 0x07, 0x07, DEF_STR( Coin_A ) )
-	PORT_DIPSETTING(    0x03, DEF_STR( 3C_1C ) )
-	PORT_DIPSETTING(    0x04, DEF_STR( 2C_1C ) )
-	PORT_DIPSETTING(    0x07, DEF_STR( 1C_1C ) )
-	PORT_DIPSETTING(    0x01, "1C/1C or 2C/3C" ) /* 1 coin/1 credit or 2 coins/3 credits */
-	PORT_DIPSETTING(    0x02, DEF_STR( 2C_3C ) )
-	PORT_DIPSETTING(    0x06, DEF_STR( 1C_2C ) )
-	PORT_DIPSETTING(    0x05, DEF_STR( 1C_3C ) )
-	PORT_DIPSETTING(    0x00, "2C Start/1C Continue" )
-	PORT_DIPNAME( 0x38, 0x38, DEF_STR( Coin_B ) )
-	PORT_DIPSETTING(    0x18, DEF_STR( 3C_1C ) )
-	PORT_DIPSETTING(    0x20, DEF_STR( 2C_1C ) )
-	PORT_DIPSETTING(    0x38, DEF_STR( 1C_1C ) )
-	PORT_DIPSETTING(    0x08, "1C/1C or 2C/3C" ) /* 1 coin/1 credit or 2 coins/3 credits */
-	PORT_DIPSETTING(    0x10, DEF_STR( 2C_3C ) )
-	PORT_DIPSETTING(    0x30, DEF_STR( 1C_2C ) )
-	PORT_DIPSETTING(    0x28, DEF_STR( 1C_3C ) )
-	PORT_DIPSETTING(    0x00, "2C Start/1C Continue" )
-	PORT_DIPNAME( 0x40, 0x40, "Unkown / Unused" )
-	PORT_DIPSETTING(    0x40, DEF_STR( Off ) )
-	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
-	PORT_DIPNAME( 0x80, 0x80, "Bonus for PAR Play" )
-	PORT_DIPSETTING(    0x80, DEF_STR( None ) )
-	PORT_DIPSETTING(    0x00, "Extra Hole" )
-
-	PORT_START_TAG("DSW2")	/* Dip switch B */
-	PORT_DIPNAME( 0x03, 0x03, DEF_STR( Difficulty ) )
-	PORT_DIPSETTING(    0x03, DEF_STR( Normal ) )
-	PORT_DIPSETTING(    0x02, DEF_STR( Easy ) )
-	PORT_DIPSETTING(    0x01, DEF_STR( Hard ) )
-	PORT_DIPSETTING(    0x00, DEF_STR( Very_Hard ) )
-	PORT_DIPNAME( 0x0c, 0x0c, "Number of Players" )
-	PORT_DIPSETTING(    0x0c, "3" )
-	PORT_DIPSETTING(    0x08, "4" )
-	PORT_DIPSETTING(    0x04, "2" )
-	PORT_DIPSETTING(    0x00, "1" )
-	PORT_DIPNAME( 0x10, 0x00, DEF_STR( Demo_Sounds ) )
-	PORT_DIPSETTING(    0x10, DEF_STR( Off ) )
-	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
-	PORT_DIPNAME( 0x20, 0x20, "Control Panel" )
-	PORT_DIPSETTING(    0x00, "2P Pair" )
-	PORT_DIPSETTING(    0x40, DEF_STR( Single ) )
-	PORT_DIPNAME( 0x40, 0x40, "Country" )
-	PORT_DIPSETTING(    0x40, DEF_STR( Japan ) )
-	PORT_DIPSETTING(    0x00, "North America" )
-	PORT_DIPNAME( 0x80, 0x80, "Test Mode" )
-	PORT_DIPSETTING(    0x80, DEF_STR( Off ) )
-	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
-INPUT_PORTS_END
-
-/*
-
-Mayjinsen (JPN Ver.)
-(c)1994 Seta
-
-CPU:    UPD70732-25 V810 ?
-Sound:  Custom (ST-0016 ?)
-
-sx003.01    main prg
-sx003.02
-sx003.03
-sx003.04    /
-
-sx003.05d   chr
-sx003.06
-sx003.07d   /
-
------------
-
-Mayjinsen II
-Seta, 1994
-
-This game runs on Seta hardware. The game is similar to Shougi.
-
-PCB Layout
-----------
-
-E52-00001
-|----------------------------------------------------|
-|                  62256    62256    62256    62256  |
-| D70732GD-25                                        |
-| NEC 1991 V810    62256    62256    62256    62256  |
-|                                                    |
-|                  62256    62256    62256    62256  |
-|                                                    |
-|                SX007-01 SX007-02  SX007-03 SX007-04|
-|                                                    |
-|                                   6264             |
-|                                                    |
-|                   62256      42.9545MHz  48MHz     |
-|      PAL                                           |
-|                   62256                            |
-| 46MHz                          ST-0016   SX007-05  |
-|                                TC6210AF            |
-|                                                    |
-|                   TC514800                         |
-|                                                    |
-|                                           DSW1-8   |
-|                                                    |
-|                                           DSW2-8   |
-|                           JAMMA                    |
-|----------------------------------------------------|
-
-*/
+/*************************************
+ *
+ *  Machine's structure ST0016 + V810
+ *
+ *************************************/
 
 static UINT32 latches[8];
 
@@ -646,40 +222,12 @@ static ADDRESS_MAP_START( st0016_m2_io, ADDRESS_SPACE_IO, 8 )
 	AM_RANGE(0xf0, 0xf0) AM_READ(st0016_dma_r)
 ADDRESS_MAP_END
 
-static MACHINE_DRIVER_START( mayjinsn )
-	MDRV_IMPORT_FROM(st0016)
-	MDRV_CPU_MODIFY("main")
-	MDRV_CPU_IO_MAP(st0016_m2_io,0)
-	MDRV_CPU_ADD(V810, 10000000)/*25 Mhz ? */
-	MDRV_CPU_PROGRAM_MAP(v810_mem,0)
-	MDRV_INTERLEAVE(1)
-MACHINE_DRIVER_END
-
-
-INPUT_PORTS_START( mayjinsn )
-	PORT_START_TAG("IN0")
-	PORT_BIT( 0xff, IP_ACTIVE_LOW, IPT_UNKNOWN )
-
-	PORT_START_TAG("IN1")
-	PORT_BIT( 0xff, IP_ACTIVE_LOW, IPT_UNKNOWN )
-
-	PORT_START_TAG("IN2")
-	PORT_BIT( 0x01, IP_ACTIVE_LOW,  IPT_VBLANK ) /* hack to pass some checks */
-	PORT_BIT( 0x02, IP_ACTIVE_HIGH, IPT_VBLANK )
-
-	PORT_BIT( 0x0c, IP_ACTIVE_LOW, IPT_UNKNOWN )
-
-	PORT_START_TAG("IN3")
-	PORT_BIT( 0xff, IP_ACTIVE_LOW, IPT_UNKNOWN )
-
-	PORT_START_TAG("IN4")
-	PORT_BIT( 0xff, IP_ACTIVE_LOW, IPT_UNKNOWN )
-
-	PORT_START_TAG("IN5")
-	PORT_BIT( 0xff, IP_ACTIVE_LOW, IPT_UNKNOWN )
-INPUT_PORTS_END
-
-INPUT_PORTS_START( mayjisn2 )
+/*************************************
+ *
+ *  Generic port definitions
+ *
+ *************************************/
+static INPUT_PORTS_START( st0016 )
 	PORT_START_TAG("IN0")
 	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_JOYSTICK_UP ) PORT_PLAYER(1)
 	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN ) PORT_PLAYER(1)
@@ -706,10 +254,142 @@ INPUT_PORTS_START( mayjisn2 )
 	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_SERVICE1 )
 	PORT_SERVICE( 0x08, IP_ACTIVE_LOW)
 
-	PORT_START_TAG("DSW1")
+	PORT_START_TAG("IN3")
 	PORT_BIT( 0xff, IP_ACTIVE_LOW, IPT_UNKNOWN ) /* unused ? */
 
+	PORT_START_TAG("DSW1")
+	PORT_DIPNAME( 0x01, 0x01, DEF_STR( Unknown ) )
+	PORT_DIPSETTING(    0x01, DEF_STR( Off ) )
+	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
+	PORT_DIPNAME( 0x02, 0x02, DEF_STR( Unknown ) )
+	PORT_DIPSETTING(    0x02, DEF_STR( Off ) )
+	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
+	PORT_DIPNAME( 0x04, 0x04, DEF_STR( Unknown ) )
+	PORT_DIPSETTING(    0x04, DEF_STR( Off ) )
+	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
+	PORT_DIPNAME( 0x08, 0x08, DEF_STR( Unknown ) )
+	PORT_DIPSETTING(    0x08, DEF_STR( Off ) )
+	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
+	PORT_DIPNAME( 0x10, 0x10, DEF_STR( Unknown ) )
+	PORT_DIPSETTING(    0x10, DEF_STR( Off ) )
+	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
+	PORT_DIPNAME( 0x20, 0x20, DEF_STR( Unknown ) )
+	PORT_DIPSETTING(    0x20, DEF_STR( Off ) )
+	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
+	PORT_DIPNAME( 0x40, 0x40, DEF_STR( Unknown ) )
+	PORT_DIPSETTING(    0x40, DEF_STR( Off ) )
+	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
+	PORT_DIPNAME( 0x80, 0x80, DEF_STR( Unknown ) )
+	PORT_DIPSETTING(    0x80, DEF_STR( Off ) )
+	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
+
 	PORT_START_TAG("DSW2")
+	PORT_DIPNAME( 0x01, 0x01, DEF_STR( Unknown ) )
+	PORT_DIPSETTING(    0x01, DEF_STR( Off ) )
+	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
+	PORT_DIPNAME( 0x02, 0x02, DEF_STR( Unknown ) )
+	PORT_DIPSETTING(    0x02, DEF_STR( Off ) )
+	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
+	PORT_DIPNAME( 0x04, 0x04, DEF_STR( Unknown ) )
+	PORT_DIPSETTING(    0x04, DEF_STR( Off ) )
+	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
+	PORT_DIPNAME( 0x08, 0x08, DEF_STR( Unknown ) )
+	PORT_DIPSETTING(    0x08, DEF_STR( Off ) )
+	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
+	PORT_DIPNAME( 0x10, 0x10, DEF_STR( Unknown ) )
+	PORT_DIPSETTING(    0x10, DEF_STR( Off ) )
+	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
+	PORT_DIPNAME( 0x20, 0x20, DEF_STR( Unknown ) )
+	PORT_DIPSETTING(    0x20, DEF_STR( Off ) )
+	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
+	PORT_DIPNAME( 0x40, 0x40, DEF_STR( Unknown ) )
+	PORT_DIPSETTING(    0x40, DEF_STR( Off ) )
+	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
+	PORT_DIPNAME( 0x80, 0x80, DEF_STR( Unknown ) )
+	PORT_DIPSETTING(    0x80, DEF_STR( Off ) )
+	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
+INPUT_PORTS_END
+
+/*************************************
+ *
+ *  Game-specific port definitions
+ *
+ *************************************/
+
+INPUT_PORTS_START( renju )
+	PORT_INCLUDE( st0016 )
+
+	PORT_MODIFY("IN2")
+	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_SERVICE1 )
+	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_UNKNOWN )
+
+	PORT_MODIFY("DSW1")	/* Dip switch A  */
+	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_UNKNOWN )
+	PORT_DIPNAME( 0x02, 0x02, DEF_STR( Flip_Screen ) )
+	PORT_DIPSETTING(    0x02, DEF_STR( Off ) )
+	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
+	PORT_SERVICE( 0x04, IP_ACTIVE_LOW )
+	PORT_DIPNAME( 0x08, 0x08, DEF_STR( Demo_Sounds ) )
+	PORT_DIPSETTING(    0x00, DEF_STR( Off ) )
+	PORT_DIPSETTING(    0x08, DEF_STR( On ) )
+	PORT_DIPNAME( 0x30, 0x30, DEF_STR( Coin_A ) )
+	PORT_DIPSETTING(      0x20, DEF_STR( 2C_1C ) )
+	PORT_DIPSETTING(      0x30, DEF_STR( 1C_1C ) )
+	PORT_DIPSETTING(      0x00, DEF_STR( 2C_3C ) )
+	PORT_DIPSETTING(      0x10, DEF_STR( 1C_2C ) )
+	PORT_DIPNAME( 0xc0, 0xc0, DEF_STR( Coin_B ) )
+	PORT_DIPSETTING(      0x80, DEF_STR( 2C_1C ) )
+	PORT_DIPSETTING(      0xc0, DEF_STR( 1C_1C ) )
+	PORT_DIPSETTING(      0x00, DEF_STR( 2C_3C ) )
+	PORT_DIPSETTING(      0x80, DEF_STR( 1C_2C ) )
+
+	PORT_MODIFY("DSW2")	/* Dip switch B */
+	PORT_DIPNAME( 0x03, 0x03, DEF_STR( Difficulty ) )
+	PORT_DIPSETTING(      0x00, DEF_STR( Very_Hard ) )
+	PORT_DIPSETTING(      0x01, DEF_STR( Hard ) )
+	PORT_DIPSETTING(      0x02, DEF_STR( Easy ) )
+	PORT_DIPSETTING(      0x03, DEF_STR( Normal ) )
+INPUT_PORTS_END
+
+INPUT_PORTS_START( nratechu )
+	PORT_INCLUDE( st0016 )
+
+	PORT_MODIFY("DSW1")	/* Dip switch A  */
+	PORT_DIPNAME( 0x07, 0x07, DEF_STR( Coinage ) )
+	PORT_DIPSETTING(      0x01, DEF_STR( 4C_1C ) )
+	PORT_DIPSETTING(      0x02, DEF_STR( 3C_1C ) )
+	PORT_DIPSETTING(      0x03, DEF_STR( 2C_1C ) )
+	PORT_DIPSETTING(      0x07, DEF_STR( 1C_1C ) )
+	PORT_DIPSETTING(      0x06, DEF_STR( 1C_2C ) )
+	PORT_DIPSETTING(      0x05, DEF_STR( 1C_3C ) )
+	PORT_DIPSETTING(      0x04, DEF_STR( 1C_4C ) )
+	PORT_DIPNAME( 0x80, 0x00, DEF_STR( Language ) )
+	PORT_DIPSETTING(    0x00, DEF_STR( English ) )
+	PORT_DIPSETTING(    0x80, DEF_STR( Japanese ) )
+
+	PORT_MODIFY("DSW2")	/* Dip switch B */
+	PORT_DIPNAME( 0x03, 0x03, DEF_STR( Difficulty ) ) /*  speed / time.. */
+	PORT_DIPSETTING(    0x02, DEF_STR( Easy ) )
+	PORT_DIPSETTING(    0x03, DEF_STR( Normal ))
+	PORT_DIPSETTING(    0x01, DEF_STR( Hard ) )
+	PORT_DIPSETTING(    0x00, DEF_STR( Hardest ) )
+	PORT_DIPNAME( 0x0C, 0x0C, "VS Round" )
+	PORT_DIPSETTING(    0x00, "1" )
+	PORT_DIPSETTING(    0x0C, "2" )
+	PORT_DIPSETTING(    0x08, "3" )
+	PORT_DIPSETTING(    0x04, "4" )
+	PORT_DIPNAME( 0x20, 0x00, DEF_STR( Demo_Sounds ) )
+	PORT_DIPSETTING(    0x20, DEF_STR( Off ) )
+	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
+	PORT_DIPNAME( 0x80, 0x80, "Test Mode" )
+	PORT_DIPSETTING(    0x80, DEF_STR( Off ) )
+	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
+INPUT_PORTS_END
+
+INPUT_PORTS_START( mayjisn2 )
+	PORT_INCLUDE( st0016 )
+
+	PORT_MODIFY("DSW1")	/* Dip switch A  */
 	PORT_DIPNAME( 0x07, 0x07, DEF_STR( Coinage ) )
 	PORT_DIPSETTING(      0x01, DEF_STR( 4C_1C ) )
 	PORT_DIPSETTING(      0x02, DEF_STR( 3C_1C ) )
@@ -723,26 +403,8 @@ INPUT_PORTS_START( mayjisn2 )
 	PORT_DIPSETTING(    0x08, "5:00" )
 	PORT_DIPSETTING(    0x18, "4:00" )
 	PORT_DIPSETTING(    0x10, "3:00" )
-	PORT_DIPNAME( 0x20, 0x00, DEF_STR( Unknown )  )
-	PORT_DIPSETTING(    0x20, DEF_STR( Off ) )
-	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
-	PORT_DIPNAME( 0x40, 0x00, DEF_STR( Unknown )  )
-	PORT_DIPSETTING(    0x40, DEF_STR( Off ) )
-	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
-	PORT_DIPNAME( 0x80, 0x00, DEF_STR( Unknown )  )
-	PORT_DIPSETTING(    0x80, DEF_STR( Off ) )
-	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
 
-	PORT_START_TAG("DSW3")
-	PORT_DIPNAME( 0x01, 0x00, DEF_STR( Unknown )  )
-	PORT_DIPSETTING(    0x01, DEF_STR( Off ) )
-	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
-	PORT_DIPNAME( 0x02, 0x00, DEF_STR( Unknown )  )
-	PORT_DIPSETTING(    0x02, DEF_STR( Off ) )
-	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
-	PORT_DIPNAME( 0x04, 0x00, DEF_STR( Unknown )  )
-	PORT_DIPSETTING(    0x04, DEF_STR( Off ) )
-	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
+	PORT_MODIFY("DSW2")	/* Dip switch B */
 	PORT_DIPNAME( 0x18, 0x18, "Music in Game"  )
 	PORT_DIPSETTING(    0x00, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x08, "Remixed" )
@@ -759,7 +421,193 @@ INPUT_PORTS_START( mayjisn2 )
 	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
 INPUT_PORTS_END
 
-/**********************************************************/
+INPUT_PORTS_START( speglsht )
+	PORT_INCLUDE( st0016 )
+
+	PORT_MODIFY("DSW1")	/* Dip switch A  */
+	PORT_DIPNAME( 0x07, 0x07, DEF_STR( Coin_A ) )
+	PORT_DIPSETTING(    0x03, DEF_STR( 3C_1C ) )
+	PORT_DIPSETTING(    0x04, DEF_STR( 2C_1C ) )
+	PORT_DIPSETTING(    0x07, DEF_STR( 1C_1C ) )
+	PORT_DIPSETTING(    0x01, "1C/1C or 2C/3C" ) /* 1 coin/1 credit or 2 coins/3 credits */
+	PORT_DIPSETTING(    0x02, DEF_STR( 2C_3C ) )
+	PORT_DIPSETTING(    0x06, DEF_STR( 1C_2C ) )
+	PORT_DIPSETTING(    0x05, DEF_STR( 1C_3C ) )
+	PORT_DIPSETTING(    0x00, "2C Start/1C Continue" )
+	PORT_DIPNAME( 0x38, 0x38, DEF_STR( Coin_B ) )
+	PORT_DIPSETTING(    0x18, DEF_STR( 3C_1C ) )
+	PORT_DIPSETTING(    0x20, DEF_STR( 2C_1C ) )
+	PORT_DIPSETTING(    0x38, DEF_STR( 1C_1C ) )
+	PORT_DIPSETTING(    0x08, "1C/1C or 2C/3C" ) /* 1 coin/1 credit or 2 coins/3 credits */
+	PORT_DIPSETTING(    0x10, DEF_STR( 2C_3C ) )
+	PORT_DIPSETTING(    0x30, DEF_STR( 1C_2C ) )
+	PORT_DIPSETTING(    0x28, DEF_STR( 1C_3C ) )
+	PORT_DIPSETTING(    0x00, "2C Start/1C Continue" )
+	PORT_DIPNAME( 0x40, 0x40, "Unkown / Unused" )
+	PORT_DIPSETTING(    0x40, DEF_STR( Off ) )
+	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
+	PORT_DIPNAME( 0x80, 0x80, "Bonus for PAR Play" )
+	PORT_DIPSETTING(    0x80, DEF_STR( None ) )
+	PORT_DIPSETTING(    0x00, "Extra Hole" )
+
+	PORT_MODIFY("DSW2")	/* Dip switch B */
+	PORT_DIPNAME( 0x03, 0x03, DEF_STR( Difficulty ) )
+	PORT_DIPSETTING(    0x03, DEF_STR( Normal ) )
+	PORT_DIPSETTING(    0x02, DEF_STR( Easy ) )
+	PORT_DIPSETTING(    0x01, DEF_STR( Hard ) )
+	PORT_DIPSETTING(    0x00, DEF_STR( Very_Hard ) )
+	PORT_DIPNAME( 0x0c, 0x0c, "Number of Players" )
+	PORT_DIPSETTING(    0x0c, "3" )
+	PORT_DIPSETTING(    0x08, "4" )
+	PORT_DIPSETTING(    0x04, "2" )
+	PORT_DIPSETTING(    0x00, "1" )
+	PORT_DIPNAME( 0x10, 0x00, DEF_STR( Demo_Sounds ) )
+	PORT_DIPSETTING(    0x10, DEF_STR( Off ) )
+	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
+	PORT_DIPNAME( 0x20, 0x20, "Control Panel" )
+	PORT_DIPSETTING(    0x00, "2P Pair" )
+	PORT_DIPSETTING(    0x40, DEF_STR( Single ) )
+	PORT_DIPNAME( 0x40, 0x40, "Country" )
+	PORT_DIPSETTING(    0x40, DEF_STR( Japan ) )
+	PORT_DIPSETTING(    0x00, "North America" )
+	PORT_DIPNAME( 0x80, 0x80, "Test Mode" )
+	PORT_DIPSETTING(    0x80, DEF_STR( Off ) )
+	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
+INPUT_PORTS_END
+
+INPUT_PORTS_START( srmp5 )
+	PORT_START_TAG("IN0")
+	PORT_BIT( 0xff, IP_ACTIVE_LOW, IPT_UNKNOWN )
+
+	PORT_START_TAG("IN1")
+	PORT_BIT( 0xff, IP_ACTIVE_LOW, IPT_UNKNOWN )
+
+	PORT_START_TAG("IN2")
+	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_COIN1 )
+	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_COIN2 )
+	PORT_SERVICE( 0x04, IP_ACTIVE_LOW)
+	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_UNKNOWN )
+
+	PORT_START_TAG("IN3")
+	PORT_BIT( 0xff, IP_ACTIVE_LOW, IPT_UNKNOWN )
+
+	PORT_START_TAG("IN4")
+	PORT_BIT( 0xff, IP_ACTIVE_LOW, IPT_UNKNOWN )
+
+	PORT_START_TAG("IN5")
+	PORT_BIT( 0xff, IP_ACTIVE_LOW, IPT_UNKNOWN )
+INPUT_PORTS_END
+
+static const gfx_decode gfxdecodeinfo[] =
+{
+/*  { 0, 0, &charlayout,      0, 16*4  }, */
+	{ -1 }	/* end of array */
+};
+
+INTERRUPT_GEN(st0016_int)
+{
+	if(!cpu_getiloops())
+		cpunum_set_input_line(0,0,HOLD_LINE);
+	else
+		if(activecpu_get_reg(Z80_IFF1)) /* dirty hack ... */
+			cpunum_set_input_line(0, INPUT_LINE_NMI, PULSE_LINE );
+}
+
+extern UINT8 *st0016_charram;
+static struct ST0016interface st0016_interface =
+{
+	&st0016_charram
+};
+
+/*************************************
+ *
+ *  Machine driver(s)
+ *
+ *************************************/
+
+static MACHINE_DRIVER_START( st0016 )
+	/* basic machine hardware */
+	MDRV_CPU_ADD_TAG("main",Z80,8000000) /* 8 MHz ? */
+	MDRV_CPU_PROGRAM_MAP(st0016_mem,0)
+	MDRV_CPU_IO_MAP(st0016_io,0)
+
+	MDRV_CPU_VBLANK_INT(st0016_int,5) /*  4*nmi + int0 */
+
+	MDRV_FRAMES_PER_SECOND(60)
+	MDRV_VBLANK_DURATION(DEFAULT_60HZ_VBLANK_DURATION)
+
+	/* video hardware */
+	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
+	MDRV_SCREEN_SIZE(48*8, 48*8)
+	MDRV_VISIBLE_AREA(0*8, 48*8-1, 0*8, 48*8-1)
+	MDRV_GFXDECODE(gfxdecodeinfo)
+	MDRV_PALETTE_LENGTH(16*16*4+1)
+
+	MDRV_VIDEO_START(st0016)
+	MDRV_VIDEO_UPDATE(st0016)
+
+	MDRV_SPEAKER_STANDARD_STEREO("left", "right")
+
+	MDRV_SOUND_ADD(ST0016, 0)
+	MDRV_SOUND_CONFIG(st0016_interface)
+	MDRV_SOUND_ROUTE(0, "left", 1.0)
+	MDRV_SOUND_ROUTE(1, "right", 1.0)
+MACHINE_DRIVER_END
+
+static MACHINE_DRIVER_START( mayjinsn )
+	MDRV_IMPORT_FROM(st0016)
+	MDRV_CPU_MODIFY("main")
+	MDRV_CPU_IO_MAP(st0016_m2_io,0)
+	MDRV_CPU_ADD(V810, 10000000)/*25 Mhz ? */
+	MDRV_CPU_PROGRAM_MAP(v810_mem,0)
+	MDRV_INTERLEAVE(1)
+MACHINE_DRIVER_END
+
+static MACHINE_DRIVER_START( srmp5 )
+	MDRV_IMPORT_FROM(st0016)
+	MDRV_CPU_ADD(R3000BE, 16000000)
+	MDRV_CPU_CONFIG(config)
+	MDRV_CPU_PROGRAM_MAP(srmp5_mem,0)
+MACHINE_DRIVER_END
+
+static MACHINE_DRIVER_START( speglsht )
+	MDRV_IMPORT_FROM(st0016)
+	MDRV_CPU_ADD(R3000BE, 16000000)
+	MDRV_CPU_CONFIG(config)
+	MDRV_CPU_PROGRAM_MAP(speglsht_mem,0)
+MACHINE_DRIVER_END
+
+/*************************************
+ *
+ *  ROM definition(s)
+ *
+ *************************************/
+/*
+Renjyu Kizoku
+Visco, 1994
+
+PCB Layout
+
+E51-00001-A
+|------------------------------------|
+|AMP       UPD6376    424400  62256  |
+|    VOL      RESET   424400  62256  |
+|                                    |
+| TD62064 74273                      |
+|J        74273                      |
+|A        74273            42.9545MHz|
+|M                                   |
+|M        74245         UNKNOWN      |
+|A        74245          QFP208      |
+|         74245                      |
+|         74245                 48MHz|
+|                                    |
+|  74138  74138                      |
+|  74253  74253       RNJ2           |
+|                                    |
+|  DSW1   DSW2        RENJYU-1  6264 |
+|------------------------------------|
+*/
 
 ROM_START( renju )
 	ROM_REGION( 0x290000, REGION_CPU1, 0 )
@@ -775,6 +623,30 @@ ROM_START( nratechu )
 	ROM_COPY( REGION_CPU1,  0x10000, 0x00000, 0x08000 )
 ROM_END
 
+/*
+Super Real Mahjong P5
+(c)199x SETA
+
+CPU   : R3560(custom?)
+SOUND : TC6210AF(custom?)
+OSC.  : 50.0000MHz 42.9545MHz
+
+SX008-01.BIN ; CHR ROM
+SX008-02.BIN ;  |
+SX008-03.BIN ;  |
+SX008-04.BIN ;  |
+SX008-05.BIN ;  |
+SX008-06.BIN ;  |
+SX008-07.BIN ; /
+SX008-08.BIN ; SOUND DATA
+SX008-09.BIN ; /
+SX008-11.BIN ; MAIN PRG
+SX008-12.BIN ;  |
+SX008-13.BIN ;  |
+SX008-14.BIN ; /
+
+*/
+
 ROM_START( srmp5 )
 	ROM_REGION( 0x210000, REGION_CPU1, 0 )
 	ROM_LOAD( "sx008-08.bin",   0x10000, 0x200000,   CRC(d4ac54f4) SHA1(c3dc76cd71485796a0b6a960294ea96eae8c946e) )
@@ -799,6 +671,49 @@ ROM_START( srmp5 )
 	ROM_LOAD( "sx008-09.bin",   0xe00000, 0x200000,   CRC(5a3e6560) SHA1(92ea398f3c5e3035869f0ca5dfe7b05c90095318) )
 ROM_END
 
+/*
+Super Eagle Shot
+(c)1993 Seta (distributed by Visco)
+E30-001A
+
+CPU  : Integrated Device IDT79R3051-25J 9407C (R3000A)
+Sound: ST-0016
+OSC  : 50.0000MHz (X1) 42.9545MHz (X3)
+
+ROMs:
+SX004-01.PR0 - Main programs (MX27C4000)
+SX004-02.PR1 |
+SX004-03.PR2 |
+SX004-04.PR3 /
+
+SX004-05.RD0 - Graphics? (D23C8000SCZ)
+SX004-06.RD1 /
+
+SX004-07.ZPR - Program? (16M mask, read as 27c160)
+
+GALs (not dumped):
+SX004-08.27 (16V8B)
+SX004-09.46 (16V8B)
+SX004-10.59 (16V8B)
+SX004-11.61 (22V10B)
+SX004-12.62 (22V10B)
+SX004-13.63 (22V10B)
+
+Custom chips:
+SETA ST-0015 60EN502F12 JAPAN 9415YAI (U18, 208pin PQFP, system controller)
+SETA ST-0016 TC6187AF JAPAN 9348YAA (U68, 208pin PQFP, sound & object)
+
+   ?      ST-0015              SX004-01   49.9545MHz    ST-0016       5588-25
+                               SX004-02      52B256-70  514256 514256
+ 50MHz                         SX004-03      52B256-70  SX004-07
+ 528257-70 514256-70 514256-70 SX004-04
+ 528257-70 514256-70 514256-70 SX004-05
+ 528257-70 514256-70 514256-70 SX004-06
+           514256-70 514256-70
+                                                NEC D6376
+
+*/
+
 ROM_START( speglsht )
 	ROM_REGION( 0x210000, REGION_CPU1, 0 )
 	ROM_LOAD( "sx004-07",   0x10000, 0x200000,   CRC(2d759cc4) SHA1(9fedd829190b2aab850b2f1088caaec91e8715dd) )
@@ -835,6 +750,59 @@ ROM_START( speglsha )
 	ROM_LOAD( "sx004-06",       0x100000, 0x100000,   CRC(5af78e44) SHA1(0131d50348fef80c2b100d74b7c967c6a710d548) )
 ROM_END
 
+/*
+Mayjinsen (JPN Ver.)
+(c)1994 Seta
+
+CPU:    UPD70732-25 V810 ?
+Sound:  Custom (ST-0016 ?)
+
+sx003.01    main prg
+sx003.02
+sx003.03
+sx003.04    /
+
+sx003.05d   chr
+sx003.06
+sx003.07d   /
+
+-----------
+
+Mayjinsen II
+Seta, 1994
+
+This game runs on Seta hardware. The game is similar to Shougi.
+
+PCB Layout
+----------
+
+E52-00001
+|----------------------------------------------------|
+|                  62256    62256    62256    62256  |
+| D70732GD-25                                        |
+| NEC 1991 V810    62256    62256    62256    62256  |
+|                                                    |
+|                  62256    62256    62256    62256  |
+|                                                    |
+|                SX007-01 SX007-02  SX007-03 SX007-04|
+|                                                    |
+|                                   6264             |
+|                                                    |
+|                   62256      42.9545MHz  48MHz     |
+|      PAL                                           |
+|                   62256                            |
+| 46MHz                          ST-0016   SX007-05  |
+|                                TC6210AF            |
+|                                                    |
+|                   TC514800                         |
+|                                                    |
+|                                           DSW1-8   |
+|                                                    |
+|                                           DSW2-8   |
+|                           JAMMA                    |
+|----------------------------------------------------|
+*/
+
 ROM_START(mayjinsn )
 	ROM_REGION( 0x190000, REGION_CPU1, 0 )
 	ROM_LOAD( "sx003.05d",   0x010000, 0x80000,  CRC(2be6d620) SHA1(113db888fb657d45be55708bbbf9a9ac159a9636) )
@@ -861,6 +829,11 @@ ROM_START(mayjisn2 )
 	ROM_LOAD32_BYTE( "sx007-01.4s",   0x00000, 0x20000,   CRC(d210bfe5) SHA1(96d9f2b198d98125df4bd6b15705646d472a8a87) )
 ROM_END
 
+/*************************************
+ *
+ *  Game-specific driver inits
+ *
+ *************************************/
 
 static DRIVER_INIT(renju)
 {
@@ -888,12 +861,17 @@ static DRIVER_INIT(mayjinsn)
 	memory_set_bankptr(2, memory_region(REGION_USER1));
 }
 
+/*************************************
+ *
+ *  Game driver(s)
+ *
+ *************************************/
 
-GAME(  1994, renju,     0,     	  st0016,   renju,     renju,    ROT0, "Visco", "Renju Kizoku", 0)
-GAME(  1996, nratechu,  0,     	  st0016,   nratechu,  nratechu, ROT0, "Seta",  "Neratte Chu", 0)
-GAME(  1994, mayjisn2,	 0, 	  	mayjinsn,   mayjisn2,  mayjinsn, ROT0, "Seta",  "Mayjinsen 2", 0)
+GAME(  1994, renju,	0,	  st0016,   renju,    renju,    ROT0, "Visco", "Renju Kizoku", 0)
+GAME(  1996, nratechu,	0,	  st0016,   nratechu, nratechu, ROT0, "Seta",  "Neratte Chu", 0)
+GAME(  1994, mayjisn2,	0,	  mayjinsn, mayjisn2, mayjinsn, ROT0, "Seta",  "Mayjinsen 2", 0)
 /* Not working */
-GAME( 199?, srmp5,  	0,     	  srmp5,    srmp5,     srmp5,    ROT0, "Seta",  "Super Real Mahjong P5",GAME_NOT_WORKING)
-GAME( 1994, speglsht,	0,     	  speglsht, speglsht,  speglsht, ROT0, "Seta",  "Super Eagle Shot (set 1)",GAME_NOT_WORKING)
-GAME( 1994, speglsha,	speglsht, speglsht, speglsht,  speglsht, ROT0, "Seta",  "Super Eagle Shot (set 2)",GAME_NOT_WORKING)
-GAME( 1994, mayjinsn,	0, 	    	mayjinsn,   mayjisn2,  mayjinsn, ROT0, "Seta",  "Mayjinsen",GAME_IMPERFECT_GRAPHICS|GAME_NOT_WORKING)
+GAME( 199?, srmp5,	0,	  srmp5,    srmp5,    srmp5,    ROT0, "Seta",  "Super Real Mahjong P5",GAME_NOT_WORKING)
+GAME( 1994, speglsht,	0,	  speglsht, speglsht, speglsht, ROT0, "Seta",  "Super Eagle Shot (set 1)",GAME_NOT_WORKING)
+GAME( 1994, speglsha,	speglsht, speglsht, speglsht, speglsht, ROT0, "Seta",  "Super Eagle Shot (set 2)",GAME_NOT_WORKING)
+GAME( 1994, mayjinsn,	0,	  mayjinsn, st0016,   mayjinsn, ROT0, "Seta",  "Mayjinsen",GAME_IMPERFECT_GRAPHICS|GAME_NOT_WORKING)
