@@ -37,7 +37,6 @@ Notes:
 */
 
 #include "driver.h"
-#include "vidhrdw/generic.h"
 #include "machine/8255ppi.h"
 #include "sound/ay8910.h"
 
@@ -100,7 +99,7 @@ static ppi8255_interface ppi8255_intf =
 	{ NULL, NULL },
 };
 
-MACHINE_INIT( tcl )
+MACHINE_RESET( tcl )
 {
 	ppi8255_init(&ppi8255_intf);
 }
@@ -125,7 +124,7 @@ static MACHINE_DRIVER_START( tcl )
 	MDRV_VIDEO_START(tcl)
 	MDRV_VIDEO_UPDATE(tcl)
 
-	MDRV_MACHINE_INIT(tcl)
+	MDRV_MACHINE_RESET(tcl)
 
 	/* sound hardware */
 	MDRV_SPEAKER_STANDARD_MONO("mono")
