@@ -119,7 +119,6 @@ need to reproduce the $18141a calculations.
 
 #include "driver.h"
 #include "cpu/m68000/m68000.h"
-#include "vidhrdw/generic.h"
 #include "vidhrdw/taitoic.h"
 #include "sndhrdw/taitosnd.h"
 #include "machine/eeprom.h"
@@ -569,7 +568,7 @@ static const gfx_decode undrfire_gfxdecodeinfo[] =
                  MACHINE DRIVERS
 ***********************************************************/
 
-static MACHINE_INIT( undrfire )
+static MACHINE_RESET( undrfire )
 {
 	/* Sound cpu program loads to 0xc00000 so we use a bank */
 	UINT16 *ROM = (UINT16 *)memory_region(REGION_CPU2);
@@ -609,7 +608,7 @@ static MACHINE_DRIVER_START( undrfire )
 	MDRV_FRAMES_PER_SECOND(60)
 	MDRV_VBLANK_DURATION(DEFAULT_60HZ_VBLANK_DURATION)
 
-	MDRV_MACHINE_INIT(undrfire)
+	MDRV_MACHINE_RESET(undrfire)
 	MDRV_NVRAM_HANDLER(undrfire)
 
 	/* video hardware */
