@@ -7,15 +7,16 @@
 
 Main  CPU    :  MC68000
 Sound CPU    :  Z80 [Optional]
-Video Chips  :  ?
+Video Chips  :  Actel A1020B PL84C
 Sound Chips  :  OKI M6295 + YM3812 [Optional]
 
 
 ---------------------------------------------------------------------------
 Year + Game         Board#
 ---------------------------------------------------------------------------
-97 Shocking         ?
-?? Magic Bubble     YS-1302
+19?? Magic Bubble     YS-1302
+1997 Shocking         YS-0211?
+1998 Bomb Kick        YS-0211
 ---------------------------------------------------------------------------
 
 - In shocking, service mode just shows the menu, with mangled graphics
@@ -31,7 +32,6 @@ Year + Game         Board#
 ***************************************************************************/
 
 #include "driver.h"
-#include "vidhrdw/generic.h"
 #include "sound/okim6295.h"
 #include "sound/3812intf.h"
 
@@ -60,8 +60,7 @@ VIDEO_UPDATE( yunsun16 );
 
 static WRITE16_HANDLER( yunsun16_sound_bank_w )
 {
-	/* To avoid crash if running the game without sound */
-	if ((Machine->sample_rate != 0) && (ACCESSING_LSB))
+	if (ACCESSING_LSB)
 	{
 		int bank = data & 3;
 		unsigned char *dst	= memory_region(REGION_SOUND1);
@@ -341,7 +340,85 @@ INPUT_PORTS_START( shocking )
 
 INPUT_PORTS_END
 
+/***************************************************************************
+                                bomb Kick
+***************************************************************************/
 
+INPUT_PORTS_START( bombkick )
+
+	PORT_START	/* IN0 - $800000.w */
+	PORT_BIT(  0x0001, IP_ACTIVE_LOW, IPT_JOYSTICK_RIGHT ) PORT_PLAYER(1)
+	PORT_BIT(  0x0002, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT ) PORT_PLAYER(1)
+	PORT_BIT(  0x0004, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN ) PORT_PLAYER(1)
+	PORT_BIT(  0x0008, IP_ACTIVE_LOW, IPT_JOYSTICK_UP ) PORT_PLAYER(1)
+	PORT_BIT(  0x0010, IP_ACTIVE_LOW, IPT_BUTTON2 ) PORT_PLAYER(1)
+	PORT_BIT(  0x0020, IP_ACTIVE_LOW, IPT_BUTTON1 ) PORT_PLAYER(1)
+	PORT_BIT(  0x0040, IP_ACTIVE_LOW, IPT_BUTTON3 ) PORT_PLAYER(1)
+	PORT_BIT(  0x0080, IP_ACTIVE_LOW, IPT_UNKNOWN )
+
+	PORT_BIT(  0x0100, IP_ACTIVE_LOW, IPT_JOYSTICK_RIGHT ) PORT_PLAYER(2)
+	PORT_BIT(  0x0200, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT ) PORT_PLAYER(2)
+	PORT_BIT(  0x0400, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN ) PORT_PLAYER(2)
+	PORT_BIT(  0x0800, IP_ACTIVE_LOW, IPT_JOYSTICK_UP ) PORT_PLAYER(2)
+	PORT_BIT(  0x1000, IP_ACTIVE_LOW, IPT_BUTTON2 ) PORT_PLAYER(2)
+	PORT_BIT(  0x2000, IP_ACTIVE_LOW, IPT_BUTTON1 ) PORT_PLAYER(2)
+	PORT_BIT(  0x4000, IP_ACTIVE_LOW, IPT_BUTTON3 ) PORT_PLAYER(2)
+	PORT_BIT(  0x8000, IP_ACTIVE_LOW, IPT_UNKNOWN )
+
+	PORT_START	/* IN1 - $800019.b */
+	PORT_BIT(  0x0001, IP_ACTIVE_LOW, IPT_COIN1 )
+	PORT_BIT(  0x0002, IP_ACTIVE_LOW, IPT_UNKNOWN )
+	PORT_BIT(  0x0004, IP_ACTIVE_LOW, IPT_UNKNOWN )
+	PORT_BIT(  0x0008, IP_ACTIVE_LOW, IPT_UNKNOWN )
+	PORT_BIT(  0x0010, IP_ACTIVE_LOW, IPT_START1 )
+	PORT_BIT(  0x0020, IP_ACTIVE_LOW, IPT_START2 )
+	PORT_BIT(  0x0040, IP_ACTIVE_LOW, IPT_UNKNOWN )
+	PORT_BIT(  0x0080, IP_ACTIVE_LOW, IPT_UNKNOWN )
+	PORT_BIT(  0xff00, IP_ACTIVE_LOW, IPT_UNUSED )
+
+	PORT_START	/* IN2 - $80001b.b */
+	PORT_DIPNAME( 0x0007, 0x0007, DEF_STR( Coinage ) )
+	PORT_DIPSETTING(      0x0002, DEF_STR( 3C_1C ) )
+	PORT_DIPSETTING(      0x0004, DEF_STR( 2C_1C ) )
+	PORT_DIPSETTING(      0x0001, DEF_STR( 3C_2C ) )
+	PORT_DIPSETTING(      0x0007, DEF_STR( 1C_1C ) )
+	PORT_DIPSETTING(      0x0003, DEF_STR( 2C_3C ) )
+	PORT_DIPSETTING(      0x0006, DEF_STR( 1C_2C ) )
+	PORT_DIPSETTING(      0x0005, DEF_STR( 1C_3C ) )
+	PORT_DIPSETTING(      0x0000, DEF_STR( Free_Play ) )
+	PORT_DIPNAME( 0x0018, 0x0018, DEF_STR( Difficulty ) )
+	PORT_DIPSETTING(      0x0000, DEF_STR( Very_Hard ) )
+	PORT_DIPSETTING(      0x0008, DEF_STR( Hard ) )
+	PORT_DIPSETTING(      0x0018, DEF_STR( Normal ) )
+	PORT_DIPSETTING(      0x0010, DEF_STR( Easy ) )
+	PORT_DIPNAME( 0x0020, 0x0020, DEF_STR( Unknown ) )
+	PORT_DIPSETTING(      0x0020, DEF_STR( Off ) )
+	PORT_DIPSETTING(      0x0000, DEF_STR( On ) )
+	PORT_DIPNAME( 0x0040, 0x0000, DEF_STR( Demo_Sounds ) )
+	PORT_DIPSETTING(      0x0040, DEF_STR( Off ) )
+	PORT_DIPSETTING(      0x0000, DEF_STR( On ) )
+	PORT_SERVICE( 0x0080, IP_ACTIVE_LOW )
+	PORT_BIT(  0xff00, IP_ACTIVE_LOW, IPT_UNUSED )
+
+	PORT_START	/* IN3 - $80001d.b */
+	PORT_DIPNAME( 0x0003, 0x0003, DEF_STR( Lives ) )
+	PORT_DIPSETTING(      0x0001, "5" )
+	PORT_DIPSETTING(      0x0002, "4" )
+	PORT_DIPSETTING(      0x0003, "3" )
+	PORT_DIPSETTING(      0x0000, "2" )
+	PORT_DIPNAME( 0x0004, 0x0004, DEF_STR( Unknown ) )
+	PORT_DIPSETTING(      0x0004, DEF_STR( Off ) )
+	PORT_DIPSETTING(      0x0000, DEF_STR( On ) )
+	PORT_BIT(  0x0008, IP_ACTIVE_LOW,  IPT_UNKNOWN ) /* keep it off --> otherwise it hangs when you select some levels */
+	PORT_BIT(  0x0010, IP_ACTIVE_HIGH, IPT_UNKNOWN ) /* keep it on  / */
+	PORT_DIPNAME( 0x0020, 0x0020, DEF_STR( Unknown ) )
+	PORT_DIPSETTING(      0x0020, DEF_STR( Off ) )
+	PORT_DIPSETTING(      0x0000, DEF_STR( On ) )
+	PORT_BIT(  0x0040, IP_ACTIVE_HIGH, IPT_UNKNOWN ) /* keep it on  --> otherwise it doesn't boot */
+	PORT_BIT(  0x0080, IP_ACTIVE_LOW,  IPT_UNKNOWN ) /* keep it off / */
+	PORT_BIT(  0xff00, IP_ACTIVE_LOW,  IPT_UNUSED )
+
+INPUT_PORTS_END
 
 
 /***************************************************************************
@@ -495,26 +572,29 @@ MACHINE_DRIVER_END
 
                                 Magic Bubble
 
-by Yung Sung YS102
+by Yun Sung YS102
 
-U143 ---27c512
-U23, 21, 22, 20, 131 ----27c010
+U143 -------------------27c512
+U23, 21, 22, 20, 131 ---27c010
 U67, 68, 69, 70 --------27c040
-U32, 33   ------------27c020
+U32, 33 ----------------27c020
 
-U143, 131  .........most likely sound
-U32, 33 .............most likely program
-U20-23........most likely sprites
+U143, 131 .......most likely sound
+U32, 33 .........most likely program
+U20-23 ..........most likely sprites
 U67-70 ..........most likely BG
 
-A1020b is close to U67-70
+Actel A1020b is close to U67-70
 
 68HC000 p16 is close to  U32,33
 
 16.000000 MHz
 
-Sound section uses "KS8001" and "KS8002" and SMD --> Z80
-and SMD "AD-65"
+Sound section:
+ SMD Z80
+  "KS8001" (YM3812)
+  "KS8002" (YM3014)
+  "AD-65"  (OKI M6295 and is SMD)
 
 ***************************************************************************/
 
@@ -606,6 +686,45 @@ ROM_START( shocking )
 ROM_END
 
 
+/***************************************************************************
+
+                                Bomb Kick
+
+YunSung YS-0211
+
+  CPU: 68HC000 P16
+Video: Actel A1020B PL84C
+  OSC: 16.000000 MHz
+Sound: Unmarked OKI M6295
+
+***************************************************************************/
+
+ROM_START( bombkick )
+
+	ROM_REGION( 0x080000, REGION_CPU1, 0 )		/* 68000 Code */
+	ROM_LOAD16_BYTE( "bk_u33",       0x000000, 0x040000, CRC(d6eb50bf) SHA1(a24c31f212f86f066c35d39da137ef0933323e43) )
+	ROM_LOAD16_BYTE( "bk_u32",       0x000001, 0x040000, CRC(d55388a2) SHA1(928f1a8933b986cf099e184002660e30ee1aeb0a) )
+
+	ROM_REGION( 0x200000*8, REGION_GFX1, ROMREGION_ERASEFF | ROMREGION_DISPOSE )	/* 16x16x8 */
+	ROMX_LOAD( "bk_u67",       0x000000, 0x080000, CRC(1962f536) SHA1(36d3c73a322330058e963efcb9b81324724382cc) , ROM_GROUPWORD | ROM_SKIP(6))
+	ROMX_LOAD( "bk_u68",       0x000002, 0x080000, CRC(d80c75a4) SHA1(330c20d126b9f1f61f17750028c92843be55ec78) , ROM_GROUPWORD | ROM_SKIP(6))
+	ROMX_LOAD( "bk_u69",       0x000004, 0x080000, CRC(615e1e6f) SHA1(73875313010514ff5ca9e0bc96d6f93baaee391e) , ROM_GROUPWORD | ROM_SKIP(6))
+	ROMX_LOAD( "bk_u70",       0x000006, 0x080000, CRC(59817ef1) SHA1(d23df30b34223575d6a9c814f2ec3db990b18679) , ROM_GROUPWORD | ROM_SKIP(6))
+
+	ROM_REGION( 0x100000, REGION_GFX2, ROMREGION_DISPOSE )	/* 16x16x4 */
+	ROM_LOAD( "bk_u20",       0x000000, 0x040000, CRC(c2b83e3f) SHA1(8bcd862dbf56cf579058d045f89f900ebfea2f1d) )
+	ROM_LOAD( "bk_u21",       0x040000, 0x040000, CRC(d6890192) SHA1(3c26a08580ceecf2f61f008861a459e175c99ed9) )
+	ROM_LOAD( "bk_u22",       0x080000, 0x040000, CRC(9538c46c) SHA1(d7d0e167d5abc2ee81eae6fde152b2f5cc716c0e) )
+	ROM_LOAD( "bk_u23",       0x0c0000, 0x040000, CRC(e3831f3d) SHA1(096658ee5a7b83d774b671c0a38113533c8751d1) )
+
+	ROM_REGION( 0x080000 * 2, REGION_SOUND1, 0 )	/* Samples */
+	ROM_LOAD( "bk_u131",      0x000000, 0x080000, CRC(22cc5732) SHA1(38aefa4e543ea54e004eee428ee087121eb20905) )
+	ROM_RELOAD(               0x080000, 0x080000             )
+
+ROM_END
+
+
+
 /***************************************************************************
 
 
@@ -617,3 +736,4 @@ ROM_END
 GAME( 19??, magicbub, 0,        magicbub, magicbub, magicbub, ROT0, "Yun Sung", "Magic Bubble", GAME_NO_COCKTAIL )
 GAME( 19??, magicbua, magicbub, magicbub, magicbub, magicbub, ROT0, "Yun Sung", "Magic Bubble (Adult version)", GAME_NO_COCKTAIL )
 GAME( 1997, shocking, 0,        shocking, shocking, 0,        ROT0, "Yun Sung", "Shocking",     GAME_NO_COCKTAIL )
+GAME( 1998, bombkick, 0,        shocking, bombkick, 0,        ROT0, "Yun Sung", "Bomb Kick",    GAME_NO_COCKTAIL )
