@@ -15,21 +15,21 @@
 #define GFX_8X8_8BIT    4
 #define GFX_16X16_8BIT  5
 
-extern void nvsram( offs_t offset, data16_t data );
+extern void nvsram( offs_t offset, UINT16 data );
 
 /* MACHINE */
+extern UINT8 namcond1_gfxbank;
 
+extern UINT8 namcond1_h8_irq5_enabled;
 extern unsigned short int *namcond1_shared_ram;
-extern unsigned short int *namcond1_eeprom;
 
 extern READ16_HANDLER( namcond1_shared_ram_r );
 extern READ16_HANDLER( namcond1_cuskey_r );
 extern WRITE16_HANDLER( namcond1_shared_ram_w );
 extern WRITE16_HANDLER( namcond1_cuskey_w );
 
-void namcond1_nvramhandler( void *f, int state );
-void namcond1_init_machine(void);
-int namcond1_vb_interrupt( void );
+MACHINE_START( namcond1 );
+MACHINE_RESET( namcond1 );
 
 /* VIDHRDW */
 
