@@ -1,5 +1,4 @@
 #include "driver.h"
-#include "vidhrdw/generic.h"
 
 #define USE_NAMCOS22_SPEED_HACK
 
@@ -77,5 +76,6 @@ VIDEO_START( namcos22s );
 VIDEO_UPDATE( namcos22s );
 
 void namcos22_WriteDataToRenderDevice( UINT32 data );
-void namcos22_UploadCodeToDSP( void );
 void namcos22_draw_direct_poly( const UINT16 *pSource );
+extern UINT32 namcos22_point_rom_r( offs_t offs );
+extern void namcos22_enable_slave_simulation( void );
