@@ -8,14 +8,10 @@
 
 /*----------- defined in machine/sega.c -----------*/
 
-extern UINT8 *sega_mainram;
-extern UINT8 *sega_soundram;
 extern void sega_security(int chip);
 
 WRITE8_HANDLER( sega_w );
 
-INTERRUPT_GEN( sega_interrupt );
-
 READ8_HANDLER( sega_mult_r );
 WRITE8_HANDLER( sega_mult1_w );
 WRITE8_HANDLER( sega_mult2_w );
