@@ -998,9 +998,13 @@ void print_mame_xml(FILE* out, const game_driver* games[])
 		"\t\t\t<!ATTLIST driver savestate (supported|unsupported) #REQUIRED>\n"
  		"\t\t\t<!ATTLIST driver palettesize CDATA #REQUIRED>\n"
 #ifdef MESS
-		"\t\t<!ELEMENT device (extension*)>\n"
-		"\t\t\t<!ATTLIST device name CDATA #REQUIRED>\n"
+		"\t\t<!ELEMENT device (instance*, extension*)>\n"
+		"\t\t\t<!ATTLIST device type CDATA #REQUIRED>\n"
+		"\t\t\t<!ATTLIST device tag CDATA #IMPLIED>\n"
 		"\t\t\t<!ATTLIST device mandatory CDATA #IMPLIED>\n"
+		"\t\t\t<!ELEMENT instance EMPTY>\n"
+		"\t\t\t\t<!ATTLIST instance name CDATA #REQUIRED>\n"
+		"\t\t\t\t<!ATTLIST instance briefname CDATA #REQUIRED>\n"
 		"\t\t\t<!ELEMENT extension EMPTY>\n"
 		"\t\t\t\t<!ATTLIST extension name CDATA #REQUIRED>\n"
 		"\t\t<!ELEMENT ramoption (#PCDATA)>\n"
