@@ -71,7 +71,7 @@ READ8_HANDLER( seawolf2_controller2_r )
 }
 
 
-static int ebases_trackball_select = 0;
+static UINT8 ebases_trackball_select = 0;
 
 WRITE8_HANDLER( ebases_trackball_select_w )
 {
@@ -177,16 +177,15 @@ WRITE8_HANDLER( profpac_banksw_w )
 		if (data < 0x8e)
 		{
 			/* 640K eprom board bank handling */
-			int bankoffset = (data-0x80) * 0x4000;
 			memory_install_read8_handler(0, ADDRESS_SPACE_PROGRAM, 0x4000, 0x7fff, 0, 0, MRA8_BANK1);
-			memory_set_bankptr(1, memory_region(REGION_USER1) + bankoffset);
+			memory_set_bank(1, data-0x80);
 		}
 		else
 		{
 			memory_install_read8_handler(0, ADDRESS_SPACE_PROGRAM, 0x4000, 0x7fff, 0, 0, profpac_blank_r);
 		}
 		memory_install_read8_handler(0, ADDRESS_SPACE_PROGRAM, 0x8000, 0xbfff, 0, 0, MRA8_BANK2);
-		memory_set_bankptr(2, memory_region(REGION_CPU1) + 0x8000);
+		memory_set_bank(2, 0);
 	}
 	else
 	{
@@ -195,28 +194,28 @@ WRITE8_HANDLER( profpac_banksw_w )
 		{
 			memory_install_read8_handler(0, ADDRESS_SPACE_PROGRAM, 0x4000, 0x7fff, 0, 0, astrocde_videoram_r);
 			memory_install_read8_handler(0, ADDRESS_SPACE_PROGRAM, 0x8000, 0xbfff, 0, 0, MRA8_BANK2);
-			memory_set_bankptr(2, memory_region(REGION_CPU1) + 0x8000);
+			memory_set_bank(2, 0);
 		}
 		else if (data == 0x20)
 		{
 			memory_install_read8_handler(0, ADDRESS_SPACE_PROGRAM, 0x4000, 0x7fff, 0, 0, MRA8_BANK1);
 			memory_install_read8_handler(0, ADDRESS_SPACE_PROGRAM, 0x8000, 0xbfff, 0, 0, MRA8_BANK2);
-			memory_set_bankptr(1, memory_region(REGION_CPU1) + 0x14000);
-			memory_set_bankptr(2, memory_region(REGION_CPU1) + 0x18000);
+			memory_set_bank(1, 14);
+			memory_set_bank(2, 1);
 		}
 		else if (data == 0x40)
 		{
 			memory_install_read8_handler(0, ADDRESS_SPACE_PROGRAM, 0x4000, 0x7fff, 0, 0, MRA8_BANK1);
 			memory_install_read8_handler(0, ADDRESS_SPACE_PROGRAM, 0x8000, 0xbfff, 0, 0, MRA8_BANK2);
-			memory_set_bankptr(1, memory_region(REGION_CPU1) + 0x1c000);
-			memory_set_bankptr(2, memory_region(REGION_CPU1) + 0x20000);
+			memory_set_bank(1, 15);
+			memory_set_bank(2, 2);
 		}
 		else if (data == 0x60)
 		{
 			memory_install_read8_handler(0, ADDRESS_SPACE_PROGRAM, 0x4000, 0x7fff, 0, 0, MRA8_BANK1);
 			memory_install_read8_handler(0, ADDRESS_SPACE_PROGRAM, 0x8000, 0xbfff, 0, 0, MRA8_BANK2);
-			memory_set_bankptr(1, memory_region(REGION_CPU1) + 0x24000);
-			memory_set_bankptr(2, memory_region(REGION_CPU1) + 0x28000);
+			memory_set_bank(1, 16);
+			memory_set_bank(2, 3);
 		}
 		else
 		{
@@ -302,3 +301,27 @@ WRITE8_HANDLER( demndrgn_sound_w )
 	logerror("Trigger sound sample 0x%02x\n",data);
 }
 
+MACHINE_START( astrocde )
+{
+	astrocade_state_save_register_main();
+
+	state_save_register_global(ebases_trackball_select);
+	state_save_register_global(ram_write_enable);
+	state_save_register_global(demndrgn_ad_select);
+
+	return 0;
+}
+
+MACHINE_START( profpac )
+{
+	state_save_register_global(ram_write_enable);
+
+	memory_configure_bank(1, 0,  14, memory_region(REGION_USER1), 0x4000);
+	memory_configure_bank(1, 14, 3,  memory_region(REGION_CPU1) + 0x14000, 0x8000);
+	memory_configure_bank(2, 0,  1,  memory_region(REGION_CPU1) + 0x8000, 0);
+	memory_configure_bank(2, 1,  1,  memory_region(REGION_CPU1) + 0x18000, 0);
+	memory_configure_bank(2, 2,  1,  memory_region(REGION_CPU1) + 0x20000, 0);
+	memory_configure_bank(2, 3,  1,  memory_region(REGION_CPU1) + 0x28000, 0);
+
+	return 0;
+}
