@@ -7,7 +7,6 @@
 ***************************************************************************/
 
 #include "driver.h"
-#include "vidhrdw/generic.h"
 #include "machine/eeprom.h"
 #include "cpu/z80/z80.h"
 #include "leland.h"
@@ -156,7 +155,7 @@ WRITE8_HANDLER( alleymas_joystick_kludge )
 {
 	/* catch the case where they clear this memory location at PC $1827 and change */
 	/* the value written to be a 1 */
-	if (activecpu_get_previouspc() == 0x1827)
+	if (safe_activecpu_get_pc() == 0x1827)
 		*alleymas_kludge_mem = 1;
 	else
 		*alleymas_kludge_mem = data;
@@ -356,7 +355,7 @@ WRITE8_HANDLER( indyheat_analog_w )
  *
  *************************************/
 
-MACHINE_INIT( leland )
+MACHINE_RESET( leland )
 {
 	/* set the odd data bank */
 	battery_ram = memory_region(REGION_USER2);
@@ -366,7 +365,8 @@ MACHINE_INIT( leland )
 	timer_adjust(master_int_timer, cpu_getscanlinetime(8), 8, 0);
 
 	/* reset globals */
-	leland_gfx_control = 0xff;
+	leland_gfx_control = 0x00;
+	leland_sound_port_w(0, 0xff);
 	wcol_enable = 0;
 
 	dangerz_x = 512;
@@ -402,7 +402,7 @@ MACHINE_INIT( leland )
 }
 
 
-MACHINE_INIT( ataxx )
+MACHINE_RESET( ataxx )
 {
 	/* set the odd data banks */
 	battery_ram = memory_region(REGION_USER2);
@@ -500,7 +500,7 @@ WRITE8_HANDLER( leland_master_alt_bankswitch_w )
 	/* update any bankswitching */
 	if (LOG_BANKSWITCHING_M)
 		if ((alternate_bank ^ data) & 0x0f)
-			logerror("%04X:alternate_bank = %02X\n", activecpu_get_previouspc(), data & 0x0f);
+			logerror("%04X:alternate_bank = %02X\n", safe_activecpu_get_pc(), data & 0x0f);
 	alternate_bank = data & 15;
 	(*leland_update_master_bank)();
 
@@ -591,7 +591,7 @@ void viper_bankswitch(void)
 	address = &master_base[bank_list[alternate_bank & 3]];
 	if (bank_list[alternate_bank & 3] >= master_length)
 	{
-		logerror("%04X:Master bank %02X out of range!\n", activecpu_get_previouspc(), alternate_bank & 3);
+		logerror("%04X:Master bank %02X out of range!\n", safe_activecpu_get_pc(), alternate_bank & 3);
 		address = &master_base[bank_list[0]];
 	}
 	memory_set_bankptr(1, address);
@@ -612,7 +612,7 @@ void offroad_bankswitch(void)
 	address = &master_base[bank_list[alternate_bank & 7]];
 	if (bank_list[alternate_bank & 7] >= master_length)
 	{
-		logerror("%04X:Master bank %02X out of range!\n", activecpu_get_previouspc(), alternate_bank & 7);
+		logerror("%04X:Master bank %02X out of range!\n", safe_activecpu_get_pc(), alternate_bank & 7);
 		address = &master_base[bank_list[0]];
 	}
 	memory_set_bankptr(1, address);
@@ -637,7 +637,7 @@ void ataxx_bankswitch(void)
 	address = &master_base[bank_list[master_bank & 15]];
 	if (bank_list[master_bank & 15] >= master_length)
 	{
-		logerror("%04X:Master bank %02X out of range!\n", activecpu_get_previouspc(), master_bank & 15);
+		logerror("%04X:Master bank %02X out of range!\n", safe_activecpu_get_pc(), master_bank & 15);
 		address = &master_base[bank_list[0]];
 	}
 	memory_set_bankptr(1, address);
@@ -835,14 +835,14 @@ void ataxx_init_eeprom(UINT8 default_val, const UINT16 *data, UINT8 serial_offse
 READ8_HANDLER( ataxx_eeprom_r )
 {
 	int port = readinputport(2);
-	if (LOG_EEPROM) logerror("%04X:EE read\n", activecpu_get_previouspc());
+	if (LOG_EEPROM) logerror("%04X:EE read\n", safe_activecpu_get_pc());
 	return (port & ~0x01) | EEPROM_read_bit();
 }
 
 
 WRITE8_HANDLER( ataxx_eeprom_w )
 {
-	if (LOG_EEPROM) logerror("%04X:EE write %d%d%d\n", activecpu_get_previouspc(),
+	if (LOG_EEPROM) logerror("%04X:EE write %d%d%d\n", safe_activecpu_get_pc(),
 			(data >> 6) & 1, (data >> 5) & 1, (data >> 4) & 1);
 	EEPROM_write_bit     ((data & 0x10) >> 4);
 	EEPROM_set_clock_line((data & 0x20) ? ASSERT_LINE : CLEAR_LINE);
@@ -861,11 +861,11 @@ WRITE8_HANDLER( leland_battery_ram_w )
 {
 	if (battery_ram_enable)
 	{
-		if (LOG_BATTERY_RAM) logerror("%04X:BatteryW@%04X=%02X\n", activecpu_get_previouspc(), offset, data);
+		if (LOG_BATTERY_RAM) logerror("%04X:BatteryW@%04X=%02X\n", safe_activecpu_get_pc(), offset, data);
 		battery_ram[offset] = data;
 	}
 	else
-		logerror("%04X:BatteryW@%04X (invalid!)\n", activecpu_get_previouspc(), offset);
+		logerror("%04X:BatteryW@%04X (invalid!)\n", safe_activecpu_get_pc(), offset);
 }
 
 
@@ -873,13 +873,13 @@ WRITE8_HANDLER( ataxx_battery_ram_w )
 {
 	if (battery_ram_enable)
 	{
-		if (LOG_BATTERY_RAM) logerror("%04X:BatteryW@%04X=%02X\n", activecpu_get_previouspc(), offset, data);
+		if (LOG_BATTERY_RAM) logerror("%04X:BatteryW@%04X=%02X\n", safe_activecpu_get_pc(), offset, data);
 		battery_ram[offset] = data;
 	}
 	else if ((master_bank & 0x30) == 0x20)
 		ataxx_qram[((master_bank & 0xc0) << 8) + offset] = data;
 	else
-		logerror("%04X:BatteryW@%04X (invalid!)\n", activecpu_get_previouspc(), offset);
+		logerror("%04X:BatteryW@%04X (invalid!)\n", safe_activecpu_get_pc(), offset);
 }
 
 
@@ -975,7 +975,7 @@ static int keycard_r(void)
 {
 	int result = 0;
 
-	if (LOG_KEYCARDS_FULL) logerror("  (%04X:keycard_r)\n", activecpu_get_previouspc());
+	if (LOG_KEYCARDS_FULL) logerror("  (%04X:keycard_r)\n", safe_activecpu_get_pc());
 
 	/* if we have a valid keycard read state, we're reading from the keycard */
 	if (keycard_state & 0x80)
@@ -999,7 +999,7 @@ static void keycard_w(int data)
 	int new_state = data & 0xb0;
 	int new_clock = data & 0x40;
 
-	if (LOG_KEYCARDS_FULL) logerror("  (%04X:keycard_w=%02X)\n", activecpu_get_previouspc(), data);
+	if (LOG_KEYCARDS_FULL) logerror("  (%04X:keycard_w=%02X)\n", safe_activecpu_get_pc(), data);
 
 	/* check for going active */
 	if (!keycard_state && new_state)
@@ -1109,7 +1109,7 @@ WRITE8_HANDLER( leland_master_analog_key_w )
 			/* update top board banking for some games */
 			if (LOG_BANKSWITCHING_M)
 				if ((top_board_bank ^ data) & 0xc0)
-					logerror("%04X:top_board_bank = %02X\n", activecpu_get_previouspc(), data & 0xc0);
+					logerror("%04X:top_board_bank = %02X\n", safe_activecpu_get_pc(), data & 0xc0);
 			top_board_bank = data & 0xc0;
 			(*leland_update_master_bank)();
 			break;
@@ -1160,7 +1160,7 @@ READ8_HANDLER( leland_master_input_r )
 
 		case 0x11:	/* /GIN1 */
 			result = readinputport(3);
-			if (LOG_EEPROM) logerror("%04X:EE read\n", activecpu_get_previouspc());
+			if (LOG_EEPROM) logerror("%04X:EE read\n", safe_activecpu_get_pc());
 			result = (result & ~0x01) | EEPROM_read_bit();
 			break;
 
@@ -1182,7 +1182,7 @@ WRITE8_HANDLER( leland_master_output_w )
 			cpunum_set_input_line(1, INPUT_LINE_NMI, (data & 0x04) ? CLEAR_LINE : ASSERT_LINE);
 			cpunum_set_input_line  (1, 0, (data & 0x08) ? CLEAR_LINE : ASSERT_LINE);
 
-			if (LOG_EEPROM) logerror("%04X:EE write %d%d%d\n", activecpu_get_previouspc(),
+			if (LOG_EEPROM) logerror("%04X:EE write %d%d%d\n", safe_activecpu_get_pc(),
 					(data >> 6) & 1, (data >> 5) & 1, (data >> 4) & 1);
 			EEPROM_write_bit     ((data & 0x10) >> 4);
 			EEPROM_set_clock_line((data & 0x20) ? ASSERT_LINE : CLEAR_LINE);
@@ -1249,13 +1249,13 @@ WRITE8_HANDLER( ataxx_master_output_w )
 		case 0x04:	/* /MBNK */
 			if (LOG_BANKSWITCHING_M)
 				if ((master_bank ^ data) & 0xff)
-					logerror("%04X:master_bank = %02X\n", activecpu_get_previouspc(), data & 0xff);
+					logerror("%04X:master_bank = %02X\n", safe_activecpu_get_pc(), data & 0xff);
 			master_bank = data;
 			ataxx_bankswitch();
 			break;
 
 		case 0x05:	/* /SLV0 */
-			cpunum_set_input_line  (1, 0, (data & 0x01) ? CLEAR_LINE : ASSERT_LINE);
+			cpunum_set_input_line(1, 0, (data & 0x01) ? CLEAR_LINE : ASSERT_LINE);
 			cpunum_set_input_line(1, INPUT_LINE_NMI, (data & 0x04) ? CLEAR_LINE : ASSERT_LINE);
 			cpunum_set_input_line(1, INPUT_LINE_RESET, (data & 0x10) ? CLEAR_LINE : ASSERT_LINE);
 			break;
@@ -1296,28 +1296,28 @@ READ8_HANDLER( leland_gated_paletteram_r )
 WRITE8_HANDLER( ataxx_paletteram_and_misc_w )
 {
 	if (wcol_enable)
-		paletteram_xxxxRRRRGGGGBBBB_w(offset, data);
+		paletteram_xxxxRRRRGGGGBBBB_le_w(offset, data);
 	else if (offset == 0x7f8 || offset == 0x7f9)
 		leland_master_video_addr_w(offset - 0x7f8, data);
 	else if (offset == 0x7fc)
 	{
 		xrom1_addr = (xrom1_addr & 0xff00) | (data & 0x00ff);
-		if (LOG_XROM) logerror("%04X:XROM1 address low write = %02X (addr=%04X)\n", activecpu_get_previouspc(), data, xrom1_addr);
+		if (LOG_XROM) logerror("%04X:XROM1 address low write = %02X (addr=%04X)\n", safe_activecpu_get_pc(), data, xrom1_addr);
 	}
 	else if (offset == 0x7fd)
 	{
 		xrom1_addr = (xrom1_addr & 0x00ff) | ((data << 8) & 0xff00);
-		if (LOG_XROM) logerror("%04X:XROM1 address high write = %02X (addr=%04X)\n", activecpu_get_previouspc(), data, xrom1_addr);
+		if (LOG_XROM) logerror("%04X:XROM1 address high write = %02X (addr=%04X)\n", safe_activecpu_get_pc(), data, xrom1_addr);
 	}
 	else if (offset == 0x7fe)
 	{
 		xrom2_addr = (xrom2_addr & 0xff00) | (data & 0x00ff);
-		if (LOG_XROM) logerror("%04X:XROM2 address low write = %02X (addr=%04X)\n", activecpu_get_previouspc(), data, xrom2_addr);
+		if (LOG_XROM) logerror("%04X:XROM2 address low write = %02X (addr=%04X)\n", safe_activecpu_get_pc(), data, xrom2_addr);
 	}
 	else if (offset == 0x7ff)
 	{
 		xrom2_addr = (xrom2_addr & 0x00ff) | ((data << 8) & 0xff00);
-		if (LOG_XROM) logerror("%04X:XROM2 address high write = %02X (addr=%04X)\n", activecpu_get_previouspc(), data, xrom2_addr);
+		if (LOG_XROM) logerror("%04X:XROM2 address high write = %02X (addr=%04X)\n", safe_activecpu_get_pc(), data, xrom2_addr);
 	}
 	else
 		extra_tram[offset] = data;
@@ -1331,13 +1331,13 @@ READ8_HANDLER( ataxx_paletteram_and_misc_r )
 	else if (offset == 0x7fc || offset == 0x7fd)
 	{
 		int result = xrom_base[0x00000 | xrom1_addr | ((offset & 1) << 16)];
-		if (LOG_XROM) logerror("%04X:XROM1 read(%d) = %02X (addr=%04X)\n", activecpu_get_previouspc(), offset - 0x7fc, result, xrom1_addr);
+		if (LOG_XROM) logerror("%04X:XROM1 read(%d) = %02X (addr=%04X)\n", safe_activecpu_get_pc(), offset - 0x7fc, result, xrom1_addr);
 		return result;
 	}
 	else if (offset == 0x7fe || offset == 0x7ff)
 	{
 		int result = xrom_base[0x20000 | xrom2_addr | ((offset & 1) << 16)];
-		if (LOG_XROM) logerror("%04X:XROM2 read(%d) = %02X (addr=%04X)\n", activecpu_get_previouspc(), offset - 0x7fc, result, xrom2_addr);
+		if (LOG_XROM) logerror("%04X:XROM2 read(%d) = %02X (addr=%04X)\n", safe_activecpu_get_pc(), offset - 0x7fc, result, xrom2_addr);
 		return result;
 	}
 	else
@@ -1375,7 +1375,7 @@ WRITE8_HANDLER( leland_sound_port_w )
     /* some bankswitching occurs here */
 	if (LOG_BANKSWITCHING_M)
 		if ((sound_port_bank ^ data) & 0x24)
-			logerror("%04X:sound_port_bank = %02X\n", activecpu_get_previouspc(), data & 0x24);
+			logerror("%04X:sound_port_bank = %02X\n", safe_activecpu_get_pc(), data & 0x24);
     sound_port_bank = data & 0x24;
     (*leland_update_master_bank)();
 }
@@ -1394,12 +1394,12 @@ WRITE8_HANDLER( leland_slave_small_banksw_w )
 
 	if (bankaddress >= slave_length)
 	{
-		logerror("%04X:Slave bank %02X out of range!", activecpu_get_previouspc(), data & 1);
+		logerror("%04X:Slave bank %02X out of range!", safe_activecpu_get_pc(), data & 1);
 		bankaddress = 0x10000;
 	}
 	memory_set_bankptr(3, &slave_base[bankaddress]);
 
-	if (LOG_BANKSWITCHING_S) logerror("%04X:Slave bank = %02X (%05X)\n", activecpu_get_previouspc(), data & 1, bankaddress);
+	if (LOG_BANKSWITCHING_S) logerror("%04X:Slave bank = %02X (%05X)\n", safe_activecpu_get_pc(), data & 1, bankaddress);
 }
 
 
@@ -1409,12 +1409,12 @@ WRITE8_HANDLER( leland_slave_large_banksw_w )
 
 	if (bankaddress >= slave_length)
 	{
-		logerror("%04X:Slave bank %02X out of range!", activecpu_get_previouspc(), data & 15);
+		logerror("%04X:Slave bank %02X out of range!", safe_activecpu_get_pc(), data & 15);
 		bankaddress = 0x10000;
 	}
 	memory_set_bankptr(3, &slave_base[bankaddress]);
 
-	if (LOG_BANKSWITCHING_S) logerror("%04X:Slave bank = %02X (%05X)\n", activecpu_get_previouspc(), data & 15, bankaddress);
+	if (LOG_BANKSWITCHING_S) logerror("%04X:Slave bank = %02X (%05X)\n", safe_activecpu_get_pc(), data & 15, bankaddress);
 }
 
 
@@ -1433,12 +1433,12 @@ WRITE8_HANDLER( ataxx_slave_banksw_w )
 
 	if (bankaddress >= slave_length)
 	{
-		logerror("%04X:Slave bank %02X out of range!", activecpu_get_previouspc(), data & 0x3f);
+		logerror("%04X:Slave bank %02X out of range!", safe_activecpu_get_pc(), data & 0x3f);
 		bankaddress = 0x2000;
 	}
 	memory_set_bankptr(3, &slave_base[bankaddress]);
 
-	if (LOG_BANKSWITCHING_S) logerror("%04X:Slave bank = %02X (%05X)\n", activecpu_get_previouspc(), data, bankaddress);
+	if (LOG_BANKSWITCHING_S) logerror("%04X:Slave bank = %02X (%05X)\n", safe_activecpu_get_pc(), data, bankaddress);
 }
 
 
