@@ -1,6 +1,5 @@
 
 #include "driver.h"
-#include "vidhrdw/generic.h"
 
 
 /*
@@ -178,19 +177,19 @@ void mspacman_decode(void)
 }
 
 
-MACHINE_INIT( mspacman )
+MACHINE_RESET( mspacman )
 {
 	unsigned char *RAM = memory_region(REGION_CPU1);
 	mspacman_decode();
-	memory_set_bankptr (1, &RAM[0x00000]);
+
+	memory_configure_bank(1, 0, 2, &RAM[0x00000], 0x10000);
+	memory_set_bank(1, 0);
 }
 
 
 WRITE8_HANDLER( mspacman_activate_rom )
 {
-	unsigned char *RAM = memory_region(REGION_CPU1);
-
-	if(data==1) memory_set_bankptr (1, &RAM[0x10000]);
+	if (data==1) memory_set_bank(1, 1);
 }
 
 
