@@ -1,8 +1,8 @@
 /***************************************************************************
 
-	Taito Qix hardware
+    Taito Qix hardware
 
-	driver by John Butler, Ed Mueller, Aaron Giles
+    driver by John Butler, Ed Mueller, Aaron Giles
 
 ***************************************************************************/
 
@@ -12,6 +12,7 @@
 #include "cpu/m6800/m6800.h"
 #include "cpu/m6805/m6805.h"
 #include "cpu/m6809/m6809.h"
+#include "sound/sn76496.h"
 
 
 /* Globals */
@@ -26,77 +27,78 @@ static UINT8 qix_coinctrl;
 
 
 /* Prototypes */
-static READ_HANDLER( qixmcu_coin_r );
-static WRITE_HANDLER( qixmcu_coinctrl_w );
-static WRITE_HANDLER( qixmcu_coin_w );
+static READ8_HANDLER( qixmcu_coin_r );
+static WRITE8_HANDLER( qixmcu_coinctrl_w );
+static WRITE8_HANDLER( qixmcu_coin_w );
 
-static WRITE_HANDLER( qix_dac_w );
-static WRITE_HANDLER( sync_pia_4_porta_w );
+static WRITE8_HANDLER( sync_pia_4_porta_w );
 
-static WRITE_HANDLER( qix_inv_flag_w );
+static WRITE8_HANDLER( pia_5_warning_w );
 
-static WRITE_HANDLER( qix_coinctl_w );
-static WRITE_HANDLER( slither_coinctl_w );
+static WRITE8_HANDLER( qix_inv_flag_w );
+
+static WRITE8_HANDLER( qix_coinctl_w );
+static WRITE8_HANDLER( slither_coinctl_w );
 
 static void qix_pia_sint(int state);
 static void qix_pia_dint(int state);
 
-static WRITE_HANDLER( slither_76489_0_w );
-static WRITE_HANDLER( slither_76489_1_w );
+static WRITE8_HANDLER( slither_76489_0_w );
+static WRITE8_HANDLER( slither_76489_1_w );
 
-static READ_HANDLER( slither_trak_lr_r );
-static READ_HANDLER( slither_trak_ud_r );
+static READ8_HANDLER( slither_trak_lr_r );
+static READ8_HANDLER( slither_trak_ud_r );
 
 
 
 /***************************************************************************
 
-	Qix has 6 PIAs on board:
+    Qix has 6 PIAs on board:
 
-	From the ROM I/O schematic:
+    From the ROM I/O schematic:
 
-	PIA 0 = U11: (mapped to $9400 on the data CPU)
-		port A = external input (input_port_0)
-		port B = external input (input_port_1) (coin)
+    PIA 0 = U11: (mapped to $9400 on the data CPU)
+        port A = external input (input_port_0)
+        port B = external input (input_port_1) (coin)
 
-	PIA 1 = U20: (mapped to $9800/$9900 on the data CPU)
-		port A = external input (???)
-		port B = external input (???)
+    PIA 1 = U20: (mapped to $9800/$9900 on the data CPU)
+        port A = external input (input_port_2)
+        port B = external input (input_port_3)
 
-	PIA 2 = U30: (mapped to $9c00 on the data CPU)
-		port A = external input (???)
-		port B = external input (???)
+    PIA 2 = U30: (mapped to $9c00 on the data CPU)
+        port A = external input (input_port_4)
+        port B = external output (coin control)
 
 
-	From the data/sound processor schematic:
+    From the data/sound processor schematic:
 
-	PIA 3 = U20: (mapped to $9000 on the data CPU)
-		port A = data CPU to sound CPU communication
-		port B = some kind of sound control, 2 4-bit values
-		CA1 = interrupt signal from sound CPU
-		CA2 = interrupt signal to sound CPU
-		CB1 = VS input signal (vertical sync)
-		CB2 = INV output signal (cocktail flip)
-		IRQA = /DINT1 signal
-		IRQB = /DINT1 signal
+    PIA 3 = U20: (mapped to $9000 on the data CPU)
+        port A = data CPU to sound CPU communication
+        port B = stereo volume control, 2 4-bit values
+        CA1 = interrupt signal from sound CPU
+        CA2 = interrupt signal to sound CPU
+        CB1 = VS input signal (vertical sync)
+        CB2 = INV output signal (cocktail flip)
+        IRQA = /DINT1 signal
+        IRQB = /DINT1 signal
 
-	PIA 4 = U8: (mapped to $4000 on the sound CPU)
-		port A = sound CPU to data CPU communication
-		port B = DAC value (port B)
-		CA1 = interrupt signal from data CPU
-		CA2 = interrupt signal to data CPU
-		IRQA = /SINT1 signal
-		IRQB = /SINT1 signal
+    PIA 4 = U8: (mapped to $4000 on the sound CPU)
+        port A = sound CPU to data CPU communication
+        port B = DAC value (port B)
+        CA1 = interrupt signal from data CPU
+        CA2 = interrupt signal to data CPU
+        IRQA = /SINT1 signal
+        IRQB = /SINT1 signal
 
-	PIA 5 = U7: (never actually used, mapped to $2000 on the sound CPU)
-		port A = unused
-		port B = sound CPU to TMS5220 communication
-		CA1 = interrupt signal from TMS5220
-		CA2 = write signal to TMS5220
-		CB1 = ready signal from TMS5220
-		CB2 = read signal to TMS5220
-		IRQA = /SINT2 signal
-		IRQB = /SINT2 signal
+    PIA 5 = U7: (never actually used, mapped to $2000 on the sound CPU)
+        port A = unused
+        port B = sound CPU to TMS5220 communication
+        CA1 = interrupt signal from TMS5220
+        CA2 = write signal to TMS5220
+        CB1 = ready signal from TMS5220
+        CB2 = read signal to TMS5220
+        IRQA = /SINT2 signal
+        IRQB = /SINT2 signal
 
 ***************************************************************************/
 
@@ -124,7 +126,7 @@ static struct pia6821_interface qix_pia_2_intf =
 static struct pia6821_interface qix_pia_3_intf =
 {
 	/*inputs : A/B,CA/B1,CA/B2 */ 0, 0, 0, 0, 0, 0,
-	/*outputs: A/B,CA/B2       */ sync_pia_4_porta_w, 0, pia_4_ca1_w, qix_inv_flag_w,
+	/*outputs: A/B,CA/B2       */ sync_pia_4_porta_w, qix_vol_w, pia_4_ca1_w, qix_inv_flag_w,
 	/*irqs   : A/B             */ qix_pia_dint, qix_pia_dint
 };
 
@@ -138,16 +140,21 @@ static struct pia6821_interface qix_pia_4_intf =
 static struct pia6821_interface qix_pia_5_intf =
 {
 	/*inputs : A/B,CA/B1,CA/B2 */ 0, 0, 0, 0, 0, 0,
-	/*outputs: A/B,CA/B2       */ pia_3_porta_w, qix_dac_w, pia_3_ca1_w, 0,
+	/*outputs: A/B,CA/B2       */ pia_5_warning_w, pia_5_warning_w, pia_5_warning_w, pia_5_warning_w,
 	/*irqs   : A/B             */ 0, 0
 };
 
 
+static WRITE8_HANDLER( pia_5_warning_w )
+{
+	ui_popup("PIA 5 write!!");
+}
+
 
 /***************************************************************************
 
-	Games with an MCU need to handle coins differently, and provide
-	communication with the MCU
+    Games with an MCU need to handle coins differently, and provide
+    communication with the MCU
 
 ***************************************************************************/
 
@@ -169,8 +176,8 @@ static struct pia6821_interface qixmcu_pia_2_intf =
 
 /***************************************************************************
 
-	Slither uses 2 SN76489's for sound instead of the 6802+DAC; these
-	are accessed via the PIAs.
+    Slither uses 2 SN76489's for sound instead of the 6802+DAC; these
+    are accessed via the PIAs.
 
 ***************************************************************************/
 
@@ -199,11 +206,11 @@ static struct pia6821_interface slither_pia_3_intf =
 
 /*************************************
  *
- *	Machine initialization
+ *  Machine initialization
  *
  *************************************/
 
-void qix_init_machine(void)
+MACHINE_RESET( qix )
 {
 	/* set a timer for the first scanline */
 	timer_set(cpu_getscanlinetime(0), 0, qix_scanline_callback);
@@ -220,7 +227,7 @@ void qix_init_machine(void)
 }
 
 
-void qixmcu_init_machine(void)
+MACHINE_RESET( qixmcu )
 {
 	/* set a timer for the first scanline */
 	timer_set(cpu_getscanlinetime(0), 0, qix_scanline_callback);
@@ -240,7 +247,7 @@ void qixmcu_init_machine(void)
 }
 
 
-void slither_init_machine(void)
+MACHINE_RESET( slither )
 {
 	/* set a timer for the first scanline */
 	timer_set(cpu_getscanlinetime(0), 0, qix_scanline_callback);
@@ -258,7 +265,7 @@ void slither_init_machine(void)
 
 /*************************************
  *
- *	VSYNC interrupt handling
+ *  VSYNC interrupt handling
  *
  *************************************/
 
@@ -268,28 +275,27 @@ static void vblank_stop(int param)
 }
 
 
-int qix_vblank_start(void)
+INTERRUPT_GEN( qix_vblank_start )
 {
 	pia_3_cb1_w(0, 1);
 	timer_set(cpu_getscanlinetime(0), 0, vblank_stop);
-	return ignore_interrupt();
 }
 
 
 
 /*************************************
  *
- *	Shared RAM
+ *  Shared RAM
  *
  *************************************/
 
-READ_HANDLER( qix_sharedram_r )
+READ8_HANDLER( qix_sharedram_r )
 {
 	return qix_sharedram[offset];
 }
 
 
-WRITE_HANDLER( qix_sharedram_w )
+WRITE8_HANDLER( qix_sharedram_w )
 {
 	qix_sharedram[offset] = data;
 }
@@ -298,50 +304,53 @@ WRITE_HANDLER( qix_sharedram_w )
 
 /*************************************
  *
- *	Zoo Keeper bankswitching
+ *  Zoo Keeper bankswitching
  *
  *************************************/
 
-WRITE_HANDLER( zoo_bankswitch_w )
+WRITE8_HANDLER( zoo_bankswitch_w )
 {
-	UINT8 *RAM = memory_region(REGION_CPU2);
+	UINT8 *rom = memory_region(REGION_CPU2);
 
 	if (data & 0x04)
-		cpu_setbank(1, &RAM[0x10000]);
+		memory_set_bankptr(1, &rom[0x10000]);
 	else
-		cpu_setbank(1, &RAM[0xa000]);
+		memory_set_bankptr(1, &rom[0xa000]);
+
+	/* not necessary, but technically correct */
+	qix_palettebank_w(offset,data);
 }
 
 
 
 /*************************************
  *
- *	Data CPU FIRQ generation/ack
+ *  Data CPU FIRQ generation/ack
  *
  *************************************/
 
-WRITE_HANDLER( qix_data_firq_w )
+WRITE8_HANDLER( qix_data_firq_w )
 {
-	cpu_set_irq_line(0, M6809_FIRQ_LINE, ASSERT_LINE);
+	cpunum_set_input_line(0, M6809_FIRQ_LINE, ASSERT_LINE);
 }
 
 
-WRITE_HANDLER( qix_data_firq_ack_w )
+WRITE8_HANDLER( qix_data_firq_ack_w )
 {
-	cpu_set_irq_line(0, M6809_FIRQ_LINE, CLEAR_LINE);
+	cpunum_set_input_line(0, M6809_FIRQ_LINE, CLEAR_LINE);
 }
 
 
-READ_HANDLER( qix_data_firq_r )
+READ8_HANDLER( qix_data_firq_r )
 {
-	cpu_set_irq_line(0, M6809_FIRQ_LINE, ASSERT_LINE);
+	cpunum_set_input_line(0, M6809_FIRQ_LINE, ASSERT_LINE);
 	return 0xff;
 }
 
 
-READ_HANDLER( qix_data_firq_ack_r )
+READ8_HANDLER( qix_data_firq_ack_r )
 {
-	cpu_set_irq_line(0, M6809_FIRQ_LINE, CLEAR_LINE);
+	cpunum_set_input_line(0, M6809_FIRQ_LINE, CLEAR_LINE);
 	return 0xff;
 }
 
@@ -349,32 +358,32 @@ READ_HANDLER( qix_data_firq_ack_r )
 
 /*************************************
  *
- *	Video CPU FIRQ generation/ack
+ *  Video CPU FIRQ generation/ack
  *
  *************************************/
 
-WRITE_HANDLER( qix_video_firq_w )
+WRITE8_HANDLER( qix_video_firq_w )
 {
-	cpu_set_irq_line(1, M6809_FIRQ_LINE, ASSERT_LINE);
+	cpunum_set_input_line(1, M6809_FIRQ_LINE, ASSERT_LINE);
 }
 
 
-WRITE_HANDLER( qix_video_firq_ack_w )
+WRITE8_HANDLER( qix_video_firq_ack_w )
 {
-	cpu_set_irq_line(1, M6809_FIRQ_LINE, CLEAR_LINE);
+	cpunum_set_input_line(1, M6809_FIRQ_LINE, CLEAR_LINE);
 }
 
 
-READ_HANDLER( qix_video_firq_r )
+READ8_HANDLER( qix_video_firq_r )
 {
-	cpu_set_irq_line(1, M6809_FIRQ_LINE, ASSERT_LINE);
+	cpunum_set_input_line(1, M6809_FIRQ_LINE, ASSERT_LINE);
 	return 0xff;
 }
 
 
-READ_HANDLER( qix_video_firq_ack_r )
+READ8_HANDLER( qix_video_firq_ack_r )
 {
-	cpu_set_irq_line(1, M6809_FIRQ_LINE, CLEAR_LINE);
+	cpunum_set_input_line(1, M6809_FIRQ_LINE, CLEAR_LINE);
 	return 0xff;
 }
 
@@ -382,23 +391,17 @@ READ_HANDLER( qix_video_firq_ack_r )
 
 /*************************************
  *
- *	Sound PIA interfaces
+ *  Sound PIA interfaces
  *
  *************************************/
 
-static WRITE_HANDLER( qix_dac_w )
-{
-	DAC_data_w(0, data);
-}
-
-
 static void deferred_pia_4_porta_w(int data)
 {
 	pia_4_porta_w(0, data);
 }
 
 
-static WRITE_HANDLER( sync_pia_4_porta_w )
+static WRITE8_HANDLER( sync_pia_4_porta_w )
 {
 	/* we need to synchronize this so the sound CPU doesn't drop anything important */
 	timer_set(TIME_NOW, data, deferred_pia_4_porta_w);
@@ -408,38 +411,38 @@ static WRITE_HANDLER( sync_pia_4_porta_w )
 
 /*************************************
  *
- *	IRQ generation
+ *  IRQ generation
  *
  *************************************/
 
 static void qix_pia_dint(int state)
 {
 	/* DINT is connected to the data CPU's IRQ line */
-	cpu_set_irq_line(0, M6809_IRQ_LINE, state ? ASSERT_LINE : CLEAR_LINE);
+	cpunum_set_input_line(0, M6809_IRQ_LINE, state ? ASSERT_LINE : CLEAR_LINE);
 }
 
 
 static void qix_pia_sint(int state)
 {
 	/* SINT is connected to the sound CPU's IRQ line */
-	cpu_set_irq_line(2, M6802_IRQ_LINE, state ? ASSERT_LINE : CLEAR_LINE);
+	cpunum_set_input_line(2, M6802_IRQ_LINE, state ? ASSERT_LINE : CLEAR_LINE);
 }
 
 
 
 /*************************************
  *
- *	68705 Communication
+ *  68705 Communication
  *
  *************************************/
 
-READ_HANDLER( qixmcu_coin_r )
+READ8_HANDLER( qixmcu_coin_r )
 {
 	return qix_68705_port_out[0];
 }
 
 
-static WRITE_HANDLER( qixmcu_coin_w )
+static WRITE8_HANDLER( qixmcu_coin_w )
 {
 	/* this is a callback called by pia_0_w(), so I don't need to synchronize */
 	/* the CPUs - they have already been synchronized by qix_pia_0_w() */
@@ -447,16 +450,17 @@ static WRITE_HANDLER( qixmcu_coin_w )
 }
 
 
-static WRITE_HANDLER( qixmcu_coinctrl_w )
+static WRITE8_HANDLER( qixmcu_coinctrl_w )
 {
 	if (data & 0x04)
 	{
-		cpu_set_irq_line(3, M6809_IRQ_LINE, ASSERT_LINE);
-		/* spin for a while to let the 68705 write the result */
-		cpu_spinuntil_time(TIME_IN_USEC(50));
+		cpunum_set_input_line(3, M6809_IRQ_LINE, ASSERT_LINE);
+		/* temporarily boost the interleave to sync things up */
+		/* note: I'm using 50 because 30 is not enough for space dungeon at game over */
+		cpu_boost_interleave(0, TIME_IN_USEC(50));
 	}
 	else
-		cpu_set_irq_line(3, M6809_IRQ_LINE, CLEAR_LINE);
+		cpunum_set_input_line(3, M6809_IRQ_LINE, CLEAR_LINE);
 
 	/* this is a callback called by pia_0_w(), so I don't need to synchronize */
 	/* the CPUs - they have already been synchronized by qix_pia_0_w() */
@@ -467,11 +471,11 @@ static WRITE_HANDLER( qixmcu_coinctrl_w )
 
 /*************************************
  *
- *	68705 Port Inputs
+ *  68705 Port Inputs
  *
  *************************************/
 
-READ_HANDLER( qix_68705_portA_r )
+READ8_HANDLER( qix_68705_portA_r )
 {
 	UINT8 ddr = qix_68705_ddr[0];
 	UINT8 out = qix_68705_port_out[0];
@@ -480,7 +484,7 @@ READ_HANDLER( qix_68705_portA_r )
 }
 
 
-READ_HANDLER( qix_68705_portB_r )
+READ8_HANDLER( qix_68705_portB_r )
 {
 	UINT8 ddr = qix_68705_ddr[1];
 	UINT8 out = qix_68705_port_out[1];
@@ -489,7 +493,7 @@ READ_HANDLER( qix_68705_portB_r )
 }
 
 
-READ_HANDLER( qix_68705_portC_r )
+READ8_HANDLER( qix_68705_portC_r )
 {
 	UINT8 ddr = qix_68705_ddr[2];
 	UINT8 out = qix_68705_port_out[2];
@@ -501,17 +505,17 @@ READ_HANDLER( qix_68705_portC_r )
 
 /*************************************
  *
- *	68705 Port Outputs
+ *  68705 Port Outputs
  *
  *************************************/
 
-WRITE_HANDLER( qix_68705_portA_w )
+WRITE8_HANDLER( qix_68705_portA_w )
 {
 	qix_68705_port_out[0] = data;
 }
 
 
-WRITE_HANDLER( qix_68705_portB_w )
+WRITE8_HANDLER( qix_68705_portB_w )
 {
 	qix_68705_port_out[1] = data;
 	coin_lockout_w(0, (~data >> 6) & 1);
@@ -519,7 +523,7 @@ WRITE_HANDLER( qix_68705_portB_w )
 }
 
 
-WRITE_HANDLER( qix_68705_portC_w )
+WRITE8_HANDLER( qix_68705_portC_w )
 {
 	qix_68705_port_out[2] = data;
 }
@@ -528,7 +532,7 @@ WRITE_HANDLER( qix_68705_portC_w )
 
 /*************************************
  *
- *	Data CPU PIA 0 synchronization
+ *  Data CPU PIA 0 synchronization
  *
  *************************************/
 
@@ -538,7 +542,7 @@ static void pia_0_w_callback(int param)
 }
 
 
-WRITE_HANDLER( qix_pia_0_w )
+WRITE8_HANDLER( qix_pia_0_w )
 {
 	/* make all the CPUs synchronize, and only AFTER that write the command to the PIA */
 	/* otherwise the 68705 will miss commands */
@@ -549,11 +553,11 @@ WRITE_HANDLER( qix_pia_0_w )
 
 /*************************************
  *
- *	PIA/Protection(?) workarounds
+ *  PIA/Protection(?) workarounds
  *
  *************************************/
 
-WRITE_HANDLER( zookeep_pia_0_w )
+WRITE8_HANDLER( zookeep_pia_0_w )
 {
 	/* Hack: Kram and Zoo Keeper for some reason (protection?) leave the port A */
 	/* DDR set to 0xff, so they cannot read the player 1 controls. Here we force */
@@ -564,7 +568,7 @@ WRITE_HANDLER( zookeep_pia_0_w )
 }
 
 
-WRITE_HANDLER( zookeep_pia_2_w )
+WRITE8_HANDLER( zookeep_pia_2_w )
 {
 	/* Hack: Zoo Keeper for some reason (protection?) leaves the port A */
 	/* DDR set to 0xff, so they cannot read the player 2 controls. Here we force */
@@ -578,11 +582,11 @@ WRITE_HANDLER( zookeep_pia_2_w )
 
 /*************************************
  *
- *	Cocktail flip
+ *  Cocktail flip
  *
  *************************************/
 
-static WRITE_HANDLER( qix_inv_flag_w )
+static WRITE8_HANDLER( qix_inv_flag_w )
 {
 	qix_cocktail_flip = data;
 }
@@ -591,18 +595,18 @@ static WRITE_HANDLER( qix_inv_flag_w )
 
 /*************************************
  *
- *	Coin I/O for games without coin CPU
+ *  Coin I/O for games without coin CPU
  *
  *************************************/
 
-static WRITE_HANDLER( qix_coinctl_w )
+static WRITE8_HANDLER( qix_coinctl_w )
 {
 	coin_lockout_w(0, (~data >> 2) & 1);
 	coin_counter_w(0, (data >> 1) & 1);
 }
 
 
-static WRITE_HANDLER( slither_coinctl_w )
+static WRITE8_HANDLER( slither_coinctl_w )
 {
 	coin_lockout_w(0, (~data >> 6) & 1);
 	coin_counter_w(0, (data >> 5) & 1);
@@ -612,11 +616,11 @@ static WRITE_HANDLER( slither_coinctl_w )
 
 /*************************************
  *
- *	Slither SN76489 I/O
+ *  Slither SN76489 I/O
  *
  *************************************/
 
-static WRITE_HANDLER( slither_76489_0_w )
+static WRITE8_HANDLER( slither_76489_0_w )
 {
 	/* write to the sound chip */
 	SN76496_0_w(0, data);
@@ -627,7 +631,7 @@ static WRITE_HANDLER( slither_76489_0_w )
 }
 
 
-static WRITE_HANDLER( slither_76489_1_w )
+static WRITE8_HANDLER( slither_76489_1_w )
 {
 	/* write to the sound chip */
 	SN76496_1_w(0, data);
@@ -641,17 +645,17 @@ static WRITE_HANDLER( slither_76489_1_w )
 
 /*************************************
  *
- *	Slither trackball I/O
+ *  Slither trackball I/O
  *
  *************************************/
 
-static READ_HANDLER( slither_trak_lr_r )
+static READ8_HANDLER( slither_trak_lr_r )
 {
 	return readinputport(qix_cocktail_flip ? 6 : 4);
 }
 
 
-static READ_HANDLER( slither_trak_ud_r )
+static READ8_HANDLER( slither_trak_ud_r )
 {
 	return readinputport(qix_cocktail_flip ? 5 : 3);
 }
