@@ -1,44 +1,31 @@
 /***************************************************************************
 
-  machine.c
-
-  Functions to emulate general aspects of the machine (RAM, ROM, interrupts,
-  I/O ports)
+    Williams 6809 system
 
 ***************************************************************************/
 
 #include "driver.h"
-#include "vidhrdw/generic.h"
 #include "sndhrdw/williams.h"
 #include "cpu/m6800/m6800.h"
 #include "cpu/m6809/m6809.h"
 #include "6821pia.h"
 #include "machine/ticket.h"
+#include "williams.h"
+#include "sound/dac.h"
+#include "sound/hc55516.h"
 
 
-/* defined in vidhrdw/williams.c */
-extern UINT8 *williams_videoram;
-extern UINT8 *williams2_paletteram;
-
-void williams_vh_update(int counter);
-WRITE_HANDLER( williams_videoram_w );
-READ_HANDLER( williams_video_counter_r );
-
+/* timers */
+static mame_timer *scanline_timer;
+static mame_timer *scan240_timer;
+static mame_timer *scan254_timer;
 
 /* banking addresses set by the drivers */
-UINT8 *williams_bank_base;
-UINT8 *defender_bank_base;
-const UINT32 *defender_bank_list;
 UINT8 *mayday_protection;
 
 /* internal bank switching tracking */
 static UINT8 blaster_bank;
 static UINT8 vram_bank;
-UINT8 williams2_bank;
-
-/* switches controlled by $c900 */
-UINT16 sinistar_clip;
-UINT8 williams_cocktail;
 
 /* other stuff */
 static UINT16 joust2_current_sound_data;
@@ -47,45 +34,37 @@ static UINT16 joust2_current_sound_data;
 static void williams_main_irq(int state);
 static void williams_main_firq(int state);
 static void williams_snd_irq(int state);
-static WRITE_HANDLER( williams_snd_cmd_w );
+static WRITE8_HANDLER( williams_snd_cmd_w );
+static WRITE8_HANDLER( playball_snd_cmd_w );
 
 /* input port mapping */
 static UINT8 port_select;
-static WRITE_HANDLER( williams_port_select_w );
-static READ_HANDLER( williams_input_port_0_3_r );
-static READ_HANDLER( williams_input_port_1_4_r );
-static READ_HANDLER( williams_49way_port_0_r );
+static WRITE8_HANDLER( williams_port_select_w );
+static READ8_HANDLER( williams_input_port_0_3_r );
+static READ8_HANDLER( williams_input_port_49way_0_5_r );
+static READ8_HANDLER( williams_input_port_1_4_r );
+static READ8_HANDLER( williams_49way_port_0_r );
 
 /* newer-Williams routines */
-WRITE_HANDLER( williams2_bank_select_w );
-static WRITE_HANDLER( williams2_snd_cmd_w );
-
-/* Defender-specific code */
-WRITE_HANDLER( defender_bank_select_w );
-READ_HANDLER( defender_input_port_0_r );
-static READ_HANDLER( defender_io_r );
-static WRITE_HANDLER( defender_io_w );
-
-/* Stargate-specific code */
-READ_HANDLER( stargate_input_port_0_r );
+static WRITE8_HANDLER( williams2_snd_cmd_w );
 
 /* Lotto Fun-specific code */
-static READ_HANDLER( lottofun_input_port_0_r );
+static READ8_HANDLER( lottofun_input_port_0_r );
 
 /* Turkey Shoot-specific code */
-static READ_HANDLER( tshoot_input_port_0_3_r );
-static WRITE_HANDLER( tshoot_lamp_w );
-static WRITE_HANDLER( tshoot_maxvol_w );
+static READ8_HANDLER( tshoot_input_port_0_3_r );
+static WRITE8_HANDLER( tshoot_lamp_w );
+static WRITE8_HANDLER( tshoot_maxvol_w );
 
 /* Joust 2-specific code */
-static WRITE_HANDLER( joust2_snd_cmd_w );
-static WRITE_HANDLER( joust2_pia_3_cb1_w );
+static WRITE8_HANDLER( joust2_snd_cmd_w );
+static WRITE8_HANDLER( joust2_pia_3_cb1_w );
 
 
 
 /*************************************
  *
- *	Generic old-Williams PIA interfaces
+ *  Generic old-Williams PIA interfaces
  *
  *************************************/
 
@@ -121,6 +100,14 @@ struct pia6821_interface williams_49way_pia_0_intf =
 	/*irqs   : A/B             */ 0, 0
 };
 
+/* Muxing 49-way joystick PIA 0 for Blaster kit */
+struct pia6821_interface williams_49way_muxed_pia_0_intf =
+{
+	/*inputs : A/B,CA/B1,CA/B2 */ williams_input_port_49way_0_5_r, input_port_1_r, 0, 0, 0, 0,
+	/*outputs: A/B,CA/B2       */ 0, 0, 0, williams_port_select_w,
+	/*irqs   : A/B             */ 0, 0
+};
+
 /* Generic PIA 1, maps to input port 2, sound command out, and IRQs */
 struct pia6821_interface williams_pia_1_intf =
 {
@@ -141,26 +128,10 @@ struct pia6821_interface williams_snd_pia_intf =
 
 /*************************************
  *
- *	Game-specific old-Williams PIA interfaces
+ *  Game-specific old-Williams PIA interfaces
  *
  *************************************/
 
-/* Special PIA 0 for Defender, to handle the controls */
-struct pia6821_interface defender_pia_0_intf =
-{
-	/*inputs : A/B,CA/B1,CA/B2 */ defender_input_port_0_r, input_port_1_r, 0, 0, 0, 0,
-	/*outputs: A/B,CA/B2       */ 0, 0, 0, 0,
-	/*irqs   : A/B             */ 0, 0
-};
-
-/* Special PIA 0 for Stargate, to handle the controls */
-struct pia6821_interface stargate_pia_0_intf =
-{
-	/*inputs : A/B,CA/B1,CA/B2 */ stargate_input_port_0_r, input_port_1_r, 0, 0, 0, 0,
-	/*outputs: A/B,CA/B2       */ 0, 0, 0, 0,
-	/*irqs   : A/B             */ 0, 0
-};
-
 /* Special PIA 0 for Lotto Fun, to handle the controls and ticket dispenser */
 struct pia6821_interface lottofun_pia_0_intf =
 {
@@ -177,11 +148,27 @@ struct pia6821_interface sinistar_snd_pia_intf =
 	/*irqs   : A/B             */ williams_snd_irq, williams_snd_irq
 };
 
+/* Special PIA 1 for PlayBall, doesn't set the high bits on sound commands */
+struct pia6821_interface playball_pia_1_intf =
+{
+	/*inputs : A/B,CA/B1,CA/B2 */ input_port_2_r, 0, 0, 0, 0, 0,
+	/*outputs: A/B,CA/B2       */ 0, playball_snd_cmd_w, 0, 0,
+	/*irqs   : A/B             */ williams_main_irq, williams_main_irq
+};
+
+/* extra PIA 3 for Speed Ball */
+struct pia6821_interface spdball_pia_3_intf =
+{
+	/*inputs : A/B,CA/B1,CA/B2 */ input_port_3_r, input_port_4_r, 0, 0, 0, 0,
+	/*outputs: A/B,CA/B2       */ 0, 0, 0, 0,
+	/*irqs   : A/B             */ 0, 0
+};
+
 
 
 /*************************************
  *
- *	Generic later-Williams PIA interfaces
+ *  Generic later-Williams PIA interfaces
  *
  *************************************/
 
@@ -213,7 +200,7 @@ struct pia6821_interface williams2_snd_pia_intf =
 
 /*************************************
  *
- *	Game-specific later-Williams PIA interfaces
+ *  Game-specific later-Williams PIA interfaces
  *
  *************************************/
 
@@ -253,7 +240,7 @@ struct pia6821_interface joust2_pia_1_intf =
 
 /*************************************
  *
- *	Older Williams interrupts
+ *  Older Williams interrupts
  *
  *************************************/
 
@@ -263,12 +250,12 @@ static void williams_va11_callback(int scanline)
 	pia_1_cb1_w(0, scanline & 0x20);
 
 	/* update the screen while we're here */
-	williams_vh_update(scanline);
+	force_partial_update(scanline - 1);
 
 	/* set a timer for the next update */
 	scanline += 8;
 	if (scanline >= 256) scanline = 0;
-	timer_set(cpu_getscanlinetime(scanline), scanline, williams_va11_callback);
+	timer_adjust(scanline_timer, cpu_getscanlinetime(scanline), scanline, 0);
 }
 
 
@@ -288,39 +275,39 @@ static void williams_count240_callback(int param)
 	timer_set(cpu_getscanlinetime(0), 0, williams_count240_off_callback);
 
 	/* set a timer for next frame */
-	timer_set(cpu_getscanlinetime(240), 0, williams_count240_callback);
+	timer_adjust(scan240_timer, cpu_getscanlinetime(240), 0, 0);
 }
 
 
 static void williams_main_irq(int state)
 {
 	/* IRQ to the main CPU */
-	cpu_set_irq_line(0, M6809_IRQ_LINE, state ? ASSERT_LINE : CLEAR_LINE);
+	cpunum_set_input_line(0, M6809_IRQ_LINE, state ? ASSERT_LINE : CLEAR_LINE);
 }
 
 
 static void williams_main_firq(int state)
 {
 	/* FIRQ to the main CPU */
-	cpu_set_irq_line(0, M6809_FIRQ_LINE, state ? ASSERT_LINE : CLEAR_LINE);
+	cpunum_set_input_line(0, M6809_FIRQ_LINE, state ? ASSERT_LINE : CLEAR_LINE);
 }
 
 
 static void williams_snd_irq(int state)
 {
 	/* IRQ to the sound CPU */
-	cpu_set_irq_line(1, M6800_IRQ_LINE, state ? ASSERT_LINE : CLEAR_LINE);
+	cpunum_set_input_line(1, M6800_IRQ_LINE, state ? ASSERT_LINE : CLEAR_LINE);
 }
 
 
 
 /*************************************
  *
- *	Older Williams initialization
+ *  Older Williams initialization
  *
  *************************************/
 
-void williams_init_machine(void)
+static void williams_common_init(void)
 {
 	/* reset the PIAs */
 	pia_reset();
@@ -329,132 +316,31 @@ void williams_init_machine(void)
 	ticket_dispenser_init(70, TICKET_MOTOR_ACTIVE_LOW, TICKET_STATUS_ACTIVE_HIGH);
 
 	/* set a timer to go off every 16 scanlines, to toggle the VA11 line and update the screen */
-	timer_set(cpu_getscanlinetime(0), 0, williams_va11_callback);
+	scanline_timer = timer_alloc(williams_va11_callback);
+	timer_adjust(scanline_timer, cpu_getscanlinetime(0), 0, 0);
 
 	/* also set a timer to go off on scanline 240 */
-	timer_set(cpu_getscanlinetime(240), 0, williams_count240_callback);
+	scan240_timer = timer_alloc(williams_count240_callback);
+	timer_adjust(scan240_timer, cpu_getscanlinetime(240), 0, 0);
+
+	state_save_register_global(vram_bank);
+}
+
+
+MACHINE_RESET( williams )
+{
+	williams_common_init();
+
+	/* configure the memory bank */
+	memory_configure_bank(1, 0, 1, williams_videoram, 0);
+	memory_configure_bank(1, 1, 1, memory_region(REGION_CPU1) + 0x10000, 0);
 }
 
 
 
 /*************************************
  *
- *	Older Williams VRAM/ROM banking
- *
- *************************************/
-
-WRITE_HANDLER( williams_vram_select_w )
-{
-	/* VRAM/ROM banking from bit 0 */
-	vram_bank = data & 0x01;
-
-	/* cocktail flip from bit 1 */
-	williams_cocktail = data & 0x02;
-
-	/* sinistar clipping enable from bit 2 */
-	sinistar_clip = (data & 0x04) ? 0x7400 : 0xffff;
-
-	/* set the bank */
-	if (vram_bank)
-	{
-		cpu_setbank(1, williams_bank_base);
-	}
-	else
-	{
-		cpu_setbank(1, williams_videoram);
-	}
-}
-
-
-
-/*************************************
- *
- *	Older Williams sound commands
- *
- *************************************/
-
-static void williams_deferred_snd_cmd_w(int param)
-{
-	pia_2_portb_w(0, param);
-	pia_2_cb1_w(0, (param == 0xff) ? 0 : 1);
-}
-
-WRITE_HANDLER( williams_snd_cmd_w )
-{
-	/* the high two bits are set externally, and should be 1 */
-	timer_set(TIME_NOW, data | 0xc0, williams_deferred_snd_cmd_w);
-}
-
-
-
-/*************************************
- *
- *	General input port handlers
- *
- *************************************/
-
-WRITE_HANDLER( williams_port_select_w )
-{
-	port_select = data;
-}
-
-
-READ_HANDLER( williams_input_port_0_3_r )
-{
-	return readinputport(port_select ? 3 : 0);
-}
-
-
-READ_HANDLER( williams_input_port_1_4_r )
-{
-	return readinputport(port_select ? 4 : 1);
-}
-
-
-/*
- *  Williams 49-way joystick
- *
- * The joystick has 48 positions + center.
- *
- * I'm not 100% sure but it looks like it's mapped this way:
- *
- *	xxxx1000 = up full
- *	xxxx1100 = up 2/3
- *	xxxx1110 = up 1/3
- *	xxxx0111 = center
- *	xxxx0011 = down 1/3
- *	xxxx0001 = down 2/3
- *	xxxx0000 = down full
- *
- *	1000xxxx = right full
- *	1100xxxx = right 2/3
- *	1110xxxx = right 1/3
- *	0111xxxx = center
- *	0011xxxx = left 1/3
- *	0001xxxx = left 2/3
- *	0000xxxx = left full
- *
- */
-
-READ_HANDLER( williams_49way_port_0_r )
-{
-	int joy_x, joy_y;
-	int bits_x, bits_y;
-
-	joy_x = readinputport(3) >> 4;	/* 0 = left 3 = center 6 = right */
-	joy_y = readinputport(4) >> 4;	/* 0 = down 3 = center 6 = up */
-
-	bits_x = (0x70 >> (7 - joy_x)) & 0x0f;
-	bits_y = (0x70 >> (7 - joy_y)) & 0x0f;
-
-	return (bits_x << 4) | bits_y;
-}
-
-
-
-/*************************************
- *
- *	Newer Williams interrupts
+ *  Newer Williams interrupts
  *
  *************************************/
 
@@ -465,12 +351,12 @@ static void williams2_va11_callback(int scanline)
 	pia_1_ca1_w(0, scanline & 0x20);
 
 	/* update the screen while we're here */
-	williams_vh_update(scanline);
+	force_partial_update(scanline);
 
 	/* set a timer for the next update */
 	scanline += 8;
 	if (scanline >= 256) scanline = 0;
-	timer_set(cpu_getscanlinetime(scanline), scanline, williams2_va11_callback);
+	timer_adjust(scanline_timer, cpu_getscanlinetime(scanline), scanline, 0);
 }
 
 
@@ -490,90 +376,129 @@ static void williams2_endscreen_callback(int param)
 	timer_set(cpu_getscanlinetime(8), 0, williams2_endscreen_off_callback);
 
 	/* set a timer for next frame */
-	timer_set(cpu_getscanlinetime(254), 0, williams2_endscreen_callback);
+	timer_adjust(scan254_timer, cpu_getscanlinetime(254), 0, 0);
 }
 
 
 
 /*************************************
  *
- *	Newer Williams initialization
+ *  Newer Williams initialization
  *
  *************************************/
 
-void williams2_init_machine(void)
+static void williams2_postload(void)
+{
+	williams2_bank_select_w(0, vram_bank);
+}
+
+
+MACHINE_RESET( williams2 )
 {
 	/* reset the PIAs */
 	pia_reset();
 
+	/* configure memory banks */
+	memory_configure_bank(1, 0, 1, williams_videoram, 0);
+	memory_configure_bank(1, 1, 4, memory_region(REGION_CPU1) + 0x10000, 0x10000);
+
 	/* make sure our banking is reset */
 	williams2_bank_select_w(0, 0);
 
 	/* set a timer to go off every 16 scanlines, to toggle the VA11 line and update the screen */
-	timer_set(cpu_getscanlinetime(0), 0, williams2_va11_callback);
+	scanline_timer = timer_alloc(williams2_va11_callback);
+	timer_adjust(scanline_timer, cpu_getscanlinetime(0), 0, 0);
 
 	/* also set a timer to go off on scanline 254 */
-	timer_set(cpu_getscanlinetime(254), 0, williams2_endscreen_callback);
+	scan254_timer = timer_alloc(williams2_endscreen_callback);
+	timer_adjust(scan254_timer, cpu_getscanlinetime(254), 0, 0);
+
+	state_save_register_global(vram_bank);
+	state_save_register_func_postload(williams2_postload);
 }
 
 
 
 /*************************************
  *
- *	Newer Williams ROM banking
+ *  VRAM/ROM banking
  *
  *************************************/
 
-WRITE_HANDLER( williams2_bank_select_w )
+WRITE8_HANDLER( williams_vram_select_w )
 {
-	static const UINT32 bank[8] = { 0, 0x10000, 0x20000, 0x10000, 0, 0x30000, 0x40000, 0x30000 };
+	/* VRAM/ROM banking from bit 0 */
+	vram_bank = data & 0x01;
+	memory_set_bank(1, vram_bank);
 
-	/* select bank index (only lower 3 bits used by IC56) */
-	williams2_bank = data & 0x07;
+	/* cocktail flip from bit 1 */
+	williams_cocktail = data & 0x02;
+}
 
-	/* bank 0 references videoram */
-	if (williams2_bank == 0)
+
+WRITE8_HANDLER( williams2_bank_select_w )
+{
+	vram_bank = data & 0x07;
+
+	/* the low two bits control the paging */
+	switch (vram_bank & 0x03)
 	{
-		cpu_setbank(1, williams_videoram);
-		cpu_setbank(2, williams_videoram + 0x8000);
+		/* page 0 is video ram */
+		case 0:
+			memory_install_read8_handler(0, ADDRESS_SPACE_PROGRAM, 0x0000, 0x8fff, 0, 0, MRA8_BANK1);
+			memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0x8000, 0x87ff, 0, 0, MWA8_RAM);
+			memory_set_bank(1, 0);
+			break;
+
+		/* pages 1 and 2 are ROM */
+		case 1:
+		case 2:
+			memory_install_read8_handler(0, ADDRESS_SPACE_PROGRAM, 0x0000, 0x8fff, 0, 0, MRA8_BANK1);
+			memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0x8000, 0x87ff, 0, 0, MWA8_RAM);
+			memory_set_bank(1, 1 + ((vram_bank & 6) >> 1));
+			break;
+
+		/* page 3 accesses palette RAM; the remaining areas are as if page 1 ROM was selected */
+		case 3:
+			memory_install_read8_handler(0, ADDRESS_SPACE_PROGRAM, 0x8000, 0x87ff, 0, 0, williams2_paletteram_r);
+			memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0x8000, 0x87ff, 0, 0, williams2_paletteram_w);
+			memory_set_bank(1, 1 + ((vram_bank & 4) >> 1));
+			break;
 	}
-
-	/* other banks reference ROM plus either palette RAM or the top of videoram */
-	else
-	{
-		unsigned char *RAM = memory_region(REGION_CPU1);
-
-		cpu_setbank(1, &RAM[bank[williams2_bank]]);
-
-		if ((williams2_bank & 0x03) == 0x03)
-		{
-			cpu_setbank(2, williams2_paletteram);
-		}
-		else
-		{
-			cpu_setbank(2, williams_videoram + 0x8000);
-		}
-	}
-
-	/* regardless, the top 2k references videoram */
-	cpu_setbank(3, williams_videoram + 0x8800);
 }
 
 
 
 /*************************************
  *
- *	Newer Williams sound commands
+ *  Sound commands
  *
  *************************************/
 
+static void williams_deferred_snd_cmd_w(int param)
+{
+	pia_2_portb_w(0, param);
+	pia_2_cb1_w(0, (param == 0xff) ? 0 : 1);
+}
+
+WRITE8_HANDLER( williams_snd_cmd_w )
+{
+	/* the high two bits are set externally, and should be 1 */
+	timer_set(TIME_NOW, data | 0xc0, williams_deferred_snd_cmd_w);
+}
+
+WRITE8_HANDLER( playball_snd_cmd_w )
+{
+	timer_set(TIME_NOW, data, williams_deferred_snd_cmd_w);
+}
+
+
 static void williams2_deferred_snd_cmd_w(int param)
 {
 	pia_2_porta_w(0, param);
 }
 
-
-static WRITE_HANDLER( williams2_snd_cmd_w )
+static WRITE8_HANDLER( williams2_snd_cmd_w )
 {
 	timer_set(TIME_NOW, data, williams2_deferred_snd_cmd_w);
 }
@@ -582,15 +507,124 @@ static WRITE_HANDLER( williams2_snd_cmd_w )
 
 /*************************************
  *
- *	Newer Williams other stuff
+ *  General input port handlers
  *
  *************************************/
 
-WRITE_HANDLER( williams2_7segment_w )
+WRITE8_HANDLER( williams_port_select_w )
+{
+	port_select = data;
+}
+
+
+READ8_HANDLER( williams_input_port_0_3_r )
+{
+	return readinputport(port_select ? 3 : 0);
+}
+
+
+READ8_HANDLER( williams_input_port_1_4_r )
+{
+	return readinputport(port_select ? 4 : 1);
+}
+
+
+/*
+ *  Williams 49-way joystick
+ *
+ *  The joystick works on a 7x7 grid system:
+ *
+ *      + + + | + + +
+ *      + + + | + + +
+ *      + + + | + + +
+ *      ------+------
+ *      + + + | + + +
+ *      + + + | + + +
+ *      + + + | + + +
+ *
+ *  Each axis has 7 positions, reported as follows
+ *  in 4 bits/axis:
+ *
+ *      0000 = left/up full
+ *      0100 = left/up 2/3
+ *      0110 = left/up 1/3
+ *      0111 = center
+ *      1011 = right/down 1/3
+ *      1001 = right/down 2/3
+ *      1000 = right/down full
+ */
+
+READ8_HANDLER( williams_49way_port_0_r )
+{
+	static const UINT8 translate49[7] = { 0x0, 0x4, 0x6, 0x7, 0xb, 0x9, 0x8 };
+	return (translate49[readinputportbytag("49WAYX") >> 4] << 4) | translate49[readinputportbytag("49WAYY") >> 4];
+}
+
+
+READ8_HANDLER( williams_input_port_49way_0_5_r )
+{
+	if (port_select)
+		return williams_49way_port_0_r(0);
+	else
+		return readinputport(5);
+}
+
+
+
+/*************************************
+ *
+ *  CMOS access
+ *
+ *************************************/
+
+WRITE8_HANDLER( williams_cmos_w )
+{
+	/* only 4 bits are valid */
+	generic_nvram[offset] = data | 0xf0;
+}
+
+
+WRITE8_HANDLER( bubbles_cmos_w )
+{
+	/* bubbles has additional CMOS for a full 8 bits */
+	generic_nvram[offset] = data;
+}
+
+
+
+/*************************************
+ *
+ *  Watchdog
+ *
+ *************************************/
+
+WRITE8_HANDLER( williams_watchdog_reset_w )
+{
+	/* yes, the data bits are checked for this specific value */
+	if (data == 0x39)
+		watchdog_reset_w(0,0);
+}
+
+
+WRITE8_HANDLER( williams2_watchdog_reset_w )
+{
+	/* yes, the data bits are checked for this specific value */
+	if ((data & 0x3f) == 0x14)
+		watchdog_reset_w(0,0);
+}
+
+
+
+/*************************************
+ *
+ *  Diagnostic controls
+ *
+ *************************************/
+
+WRITE8_HANDLER( williams2_7segment_w )
 {
 	int n;
 	char dot;
-	char buffer[5];
 
 	switch (data & 0x7F)
 	{
@@ -615,127 +649,87 @@ WRITE_HANDLER( williams2_7segment_w )
 		dot = ' ';
 
 	if (n == -1)
-		sprintf(buffer, "[ %c]\n", dot);
+		logerror("[ %c]\n", dot);
 	else
-		sprintf(buffer, "[%d%c]\n", n, dot);
-
-	logerror(buffer);
+		logerror("[%d%c]\n", n, dot);
 }
 
 
 
 /*************************************
  *
- *	Defender-specific routines
+ *  Defender-specific routines
  *
  *************************************/
 
-void defender_init_machine(void)
+static void defender_postload(void)
 {
-	/* standard init */
-	williams_init_machine();
-
-	/* make sure the banking is reset to 0 */
-	defender_bank_select_w(0, 0);
-	cpu_setbank(1, williams_videoram);
+	defender_bank_select_w(0, vram_bank);
 }
 
 
-
-WRITE_HANDLER( defender_bank_select_w )
+MACHINE_RESET( defender )
 {
-	UINT32 bank_offset = defender_bank_list[data & 7];
+	williams_common_init();
+
+	/* configure the banking and make sure it is reset to 0 */
+	memory_configure_bank(1, 0, 9, &memory_region(REGION_CPU1)[0x10000], 0x1000);
+	defender_bank_select_w(0, 0);
+
+	state_save_register_func_postload(defender_postload);
+}
+
+
+WRITE8_HANDLER( defender_video_control_w )
+{
+	williams_cocktail = data & 0x01;
+}
+
+
+WRITE8_HANDLER( defender_bank_select_w )
+{
+	vram_bank = data & 0x0f;
 
 	/* set bank address */
-	cpu_setbank(2, &memory_region(REGION_CPU1)[bank_offset]);
-
-	/* if the bank maps into normal RAM, it represents I/O space */
-	if (bank_offset < 0x10000)
+	switch (data)
 	{
-		memory_set_bankhandler_r(2, 0, defender_io_r);
-		memory_set_bankhandler_w(2, 0, defender_io_w);
+		/* page 0 is I/O space */
+		case 0:
+			defender_install_io_space();
+			break;
+
+		/* pages 1-9 map to ROM banks */
+		case 1:
+		case 2:
+		case 3:
+		case 4:
+		case 5:
+		case 6:
+		case 7:
+		case 8:
+		case 9:
+			memory_install_read8_handler(0, ADDRESS_SPACE_PROGRAM, 0xc000, 0xcfff, 0, 0, MRA8_BANK1);
+			memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0xc000, 0xcfff, 0, 0, MWA8_ROM);
+			memory_set_bank(1, vram_bank - 1);
+			break;
+
+		/* pages A-F are not connected */
+		default:
+			memory_install_read8_handler(0, ADDRESS_SPACE_PROGRAM, 0xc000, 0xcfff, 0, 0, MRA8_NOP);
+			memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0xc000, 0xcfff, 0, 0, MWA8_NOP);
+			break;
 	}
-
-	/* otherwise, it's ROM space */
-	else
-	{
-		memory_set_bankhandler_r(2, 0, MRA_BANK2);
-		memory_set_bankhandler_w(2, 0, MWA_ROM);
-	}
-}
-
-
-READ_HANDLER( defender_input_port_0_r )
-{
-	int keys, altkeys;
-
-	/* read the standard keys and the cheat keys */
-	keys = readinputport(0);
-	altkeys = readinputport(3);
-
-	/* modify the standard keys with the cheat keys */
-	if (altkeys)
-	{
-		keys |= altkeys;
-		if (memory_region(REGION_CPU1)[0xa0bb] == 0xfd)
-		{
-			if (keys & 0x02)
-				keys = (keys & 0xfd) | 0x40;
-			else if (keys & 0x40)
-				keys = (keys & 0xbf) | 0x02;
-		}
-	}
-
-	return keys;
-}
-
-
-READ_HANDLER( defender_io_r )
-{
-	/* PIAs */
-	if (offset >= 0x0c00 && offset < 0x0c04)
-		return pia_1_r(offset & 3);
-	else if (offset >= 0x0c04 && offset < 0x0c08)
-		return pia_0_r(offset & 3);
-
-	/* video counter */
-	else if (offset == 0x800)
-		return williams_video_counter_r(offset);
-
-	/* If not bank 0 then return banked RAM */
-	return defender_bank_base[offset];
-}
-
-
-WRITE_HANDLER( defender_io_w )
-{
-	/* write the data through */
-	defender_bank_base[offset] = data;
-
-	/* watchdog */
-	if (offset == 0x03fc)
-		watchdog_reset_w(offset, data);
-
-	/* palette */
-	else if (offset < 0x10)
-		paletteram_BBGGGRRR_w(offset, data);
-
-	/* PIAs */
-	else if (offset >= 0x0c00 && offset < 0x0c04)
-		pia_1_w(offset & 3, data);
-	else if (offset >= 0x0c04 && offset < 0x0c08)
-		pia_0_w(offset & 3, data);
 }
 
 
 
 /*************************************
  *
- *	Mayday-specific routines
+ *  Mayday-specific routines
  *
  *************************************/
 
-READ_HANDLER( mayday_protection_r )
+READ8_HANDLER( mayday_protection_r )
 {
 	/* Mayday does some kind of protection check that is not currently understood  */
 	/* However, the results of that protection check are stored at $a190 and $a191 */
@@ -749,93 +743,78 @@ READ_HANDLER( mayday_protection_r )
 
 /*************************************
  *
- *	Stargate-specific routines
+ *  Sinistar-specific routines
  *
  *************************************/
 
-READ_HANDLER( stargate_input_port_0_r )
+WRITE8_HANDLER( sinistar_vram_select_w )
 {
-	int keys, altkeys;
+	/* low two bits are standard */
+	williams_vram_select_w(offset, data);
 
-	/* read the standard keys and the cheat keys */
-	keys = input_port_0_r(0);
-	altkeys = input_port_3_r(0);
-
-	/* modify the standard keys with the cheat keys */
-	if (altkeys)
-	{
-		keys |= altkeys;
-		if (memory_region(REGION_CPU1)[0x9c92] == 0xfd)
-		{
-			if (keys & 0x02)
-				keys = (keys & 0xfd) | 0x40;
-			else if (keys & 0x40)
-				keys = (keys & 0xbf) | 0x02;
-		}
-	}
-
-	return keys;
+	/* window enable from bit 2 (clips to 0x7400) */
+	williams_blitter_window_enable = data & 0x04;
 }
 
 
 
 /*************************************
  *
- *	Blaster-specific routines
+ *  Blaster-specific routines
  *
  *************************************/
 
-static const UINT32 blaster_bank_offset[16] =
+MACHINE_RESET( blaster )
 {
-	0x00000, 0x10000, 0x14000, 0x18000, 0x1c000, 0x20000, 0x24000, 0x28000,
-	0x2c000, 0x30000, 0x34000, 0x38000, 0x2c000, 0x30000, 0x34000, 0x38000
-};
+	williams_common_init();
 
+	/* banking is different for blaster */
+	memory_configure_bank(1, 0, 1, williams_videoram, 0);
+	memory_configure_bank(1, 1, 16, memory_region(REGION_CPU1) + 0x18000, 0x4000);
 
-WRITE_HANDLER( blaster_vram_select_w )
-{
-	unsigned char *RAM = memory_region(REGION_CPU1);
+	memory_configure_bank(2, 0, 1, williams_videoram + 0x4000, 0);
+	memory_configure_bank(2, 1, 16, memory_region(REGION_CPU1) + 0x10000, 0x0000);
 
-	vram_bank = data;
-
-	/* non-zero banks map to RAM and the currently-selected bank */
-	if (vram_bank)
-	{
-		cpu_setbank(1, &RAM[blaster_bank_offset[blaster_bank]]);
-		cpu_setbank(2, williams_bank_base + 0x4000);
-	}
-
-	/* bank 0 maps to videoram */
-	else
-	{
-		cpu_setbank(1, williams_videoram);
-		cpu_setbank(2, williams_videoram + 0x4000);
-	}
+	state_save_register_global(blaster_bank);
 }
 
 
-WRITE_HANDLER( blaster_bank_select_w )
+INLINE void update_blaster_banking(void)
 {
-	unsigned char *RAM = memory_region(REGION_CPU1);
+	memory_set_bank(1, vram_bank * (blaster_bank + 1));
+	memory_set_bank(2, vram_bank * (blaster_bank + 1));
+}
 
+
+WRITE8_HANDLER( blaster_vram_select_w )
+{
+	/* VRAM/ROM banking from bit 0 */
+	vram_bank = data & 0x01;
+	update_blaster_banking();
+
+	/* cocktail flip from bit 1 */
+	williams_cocktail = data & 0x02;
+
+	/* window enable from bit 2 (clips to 0x9700) */
+	williams_blitter_window_enable = data & 0x04;
+}
+
+
+WRITE8_HANDLER( blaster_bank_select_w )
+{
 	blaster_bank = data & 15;
-
-	/* only need to change anything if we're not pointing to VRAM */
-	if (vram_bank)
-	{
-		cpu_setbank(1, &RAM[blaster_bank_offset[blaster_bank]]);
-	}
+	update_blaster_banking();
 }
 
 
 
 /*************************************
  *
- *	Lotto Fun-specific routines
+ *  Lotto Fun-specific routines
  *
  *************************************/
 
-static READ_HANDLER( lottofun_input_port_0_r )
+static READ8_HANDLER( lottofun_input_port_0_r )
 {
 	/* merge in the ticket dispenser status */
 	return input_port_0_r(offset) | ticket_dispenser_r(offset);
@@ -845,11 +824,11 @@ static READ_HANDLER( lottofun_input_port_0_r )
 
 /*************************************
  *
- *	Turkey Shoot-specific routines
+ *  Turkey Shoot-specific routines
  *
  *************************************/
 
-static READ_HANDLER( tshoot_input_port_0_3_r )
+static READ8_HANDLER( tshoot_input_port_0_3_r )
 {
 	/* merge in the gun inputs with the standard data */
 	int data = williams_input_port_0_3_r(offset);
@@ -858,14 +837,14 @@ static READ_HANDLER( tshoot_input_port_0_3_r )
 }
 
 
-static WRITE_HANDLER( tshoot_maxvol_w )
+static WRITE8_HANDLER( tshoot_maxvol_w )
 {
 	/* something to do with the sound volume */
-	logerror("tshoot maxvol = %d (pc:%x)\n", data, cpu_get_pc());
+	logerror("tshoot maxvol = %d (pc:%x)\n", data, activecpu_get_pc());
 }
 
 
-static WRITE_HANDLER( tshoot_lamp_w )
+static WRITE8_HANDLER( tshoot_lamp_w )
 {
 	/* set the grenade lamp */
 	set_led_status(0,data & 0x04);
@@ -894,18 +873,20 @@ static WRITE_HANDLER( tshoot_lamp_w )
 
 /*************************************
  *
- *	Joust 2-specific routines
+ *  Joust 2-specific routines
  *
  *************************************/
 
-void joust2_init_machine(void)
+MACHINE_RESET( joust2 )
 {
 	/* standard init */
-	williams2_init_machine();
+	machine_reset_williams2();
 
 	/* make sure sound board starts out in the reset state */
-	williams_cvsd_init(2, 3);
+	williams_cvsd_init(3);
 	pia_reset();
+
+	state_save_register_global(joust2_current_sound_data);
 }
 
 
@@ -915,14 +896,14 @@ static void joust2_deferred_snd_cmd_w(int param)
 }
 
 
-static WRITE_HANDLER( joust2_pia_3_cb1_w )
+static WRITE8_HANDLER( joust2_pia_3_cb1_w )
 {
 	joust2_current_sound_data = (joust2_current_sound_data & ~0x100) | ((data << 8) & 0x100);
 	pia_3_cb1_w(offset, data);
 }
 
 
-static WRITE_HANDLER( joust2_snd_cmd_w )
+static WRITE8_HANDLER( joust2_snd_cmd_w )
 {
 	joust2_current_sound_data = (joust2_current_sound_data & ~0xff) | (data & 0xff);
 	williams_cvsd_data_w(joust2_current_sound_data);
