@@ -27,8 +27,9 @@ Air Duel                                1990  Rev 3.14 M72   No
 Daiku no Gensan                         1990  Rev 3.14 M81  Yes
 Daiku no Gensan (M72)                   1990  Rev 3.15 M72   No
 Hammerin' Harry                         1990  Rev 3.15 M81  Yes
-Ken-Go	                                1991  Rev 3.15 M81  Yes
+Ken-Go                                  1991  Rev 3.15 M81  Yes
 Pound for Pound                         1990  Rev 3.15 M83   No
+Cosmic Cop                              1991  Rev 3.15 M81  Yes
 Gallop - Armed Police Unit              1991  Rev 3.15 M72   No
 Hasamu                                  1991  Rev 3.15 M81  Yes
 Bomber Man                              1991  Rev 3.15 M81  Yes
@@ -41,6 +42,7 @@ Shisensho II                            1993  Rev 3.34 M81  Yes
 ***************************************************************************/
 
 #include "driver.h"
+#include "sound/dac.h"
 
 
 /*
@@ -64,10 +66,11 @@ enum
 	Z80_CLEAR
 };
 
+static UINT8 irqvector;
+static UINT32 sample_addr;
+
 static void setvector_callback(int param)
 {
-	static int irqvector;
-
 	switch(param)
 	{
 		case VECTOR_INIT:
@@ -94,16 +97,19 @@ static void setvector_callback(int param)
 	if (irqvector == 0)
 		logerror("You didn't call m72_init_sound()\n");
 
-	cpu_irq_line_vector_w(1,0,irqvector);
+	cpunum_set_input_line_vector(1,0,irqvector);
 	if (irqvector == 0xff)	/* no IRQs pending */
-		cpu_set_irq_line(1,0,CLEAR_LINE);
+		cpunum_set_input_line(1,0,CLEAR_LINE);
 	else	/* IRQ pending */
-		cpu_set_irq_line(1,0,ASSERT_LINE);
+		cpunum_set_input_line(1,0,ASSERT_LINE);
 }
 
-void m72_init_sound(void)
+MACHINE_RESET( m72_sound )
 {
 	setvector_callback(VECTOR_INIT);
+
+	state_save_register_global(irqvector);
+	state_save_register_global(sample_addr);
 }
 
 void m72_ym2151_irq_handler(int irq)
@@ -114,7 +120,7 @@ void m72_ym2151_irq_handler(int irq)
 		timer_set(TIME_NOW,YM2151_CLEAR,setvector_callback);
 }
 
-WRITE_HANDLER( m72_sound_command_w )
+WRITE8_HANDLER( m72_sound_command_w )
 {
 	if (offset == 0)
 	{
@@ -123,21 +129,19 @@ WRITE_HANDLER( m72_sound_command_w )
 	}
 }
 
-WRITE_HANDLER( m72_sound_irq_ack_w )
+WRITE8_HANDLER( m72_sound_irq_ack_w )
 {
 	timer_set(TIME_NOW,Z80_CLEAR,setvector_callback);
 }
 
 
 
-static int sample_addr;
-
 void m72_set_sample_start(int start)
 {
 	sample_addr = start;
 }
 
-WRITE_HANDLER( vigilant_sample_addr_w )
+WRITE8_HANDLER( vigilant_sample_addr_w )
 {
 	if (offset == 1)
 		sample_addr = (sample_addr & 0x00ff) | ((data << 8) & 0xff00);
@@ -145,7 +149,7 @@ WRITE_HANDLER( vigilant_sample_addr_w )
 		sample_addr = (sample_addr & 0xff00) | ((data << 0) & 0x00ff);
 }
 
-WRITE_HANDLER( shisen_sample_addr_w )
+WRITE8_HANDLER( shisen_sample_addr_w )
 {
 	sample_addr >>= 2;
 
@@ -157,7 +161,7 @@ WRITE_HANDLER( shisen_sample_addr_w )
 	sample_addr <<= 2;
 }
 
-WRITE_HANDLER( rtype2_sample_addr_w )
+WRITE8_HANDLER( rtype2_sample_addr_w )
 {
 	sample_addr >>= 5;
 
@@ -169,12 +173,28 @@ WRITE_HANDLER( rtype2_sample_addr_w )
 	sample_addr <<= 5;
 }
 
-READ_HANDLER( m72_sample_r )
+WRITE8_HANDLER( poundfor_sample_addr_w )
+{
+	/* poundfor writes both sample start and sample END - a first for Irem...
+       we don't handle the end written here, 00 marks the sample end as usual. */
+	if (offset > 1) return;
+
+	sample_addr >>= 4;
+
+	if (offset == 1)
+		sample_addr = (sample_addr & 0x00ff) | ((data << 8) & 0xff00);
+	else
+		sample_addr = (sample_addr & 0xff00) | ((data << 0) & 0x00ff);
+
+	sample_addr <<= 4;
+}
+
+READ8_HANDLER( m72_sample_r )
 {
 	return memory_region(REGION_SOUND1)[sample_addr];
 }
 
-WRITE_HANDLER( m72_sample_w )
+WRITE8_HANDLER( m72_sample_w )
 {
 	DAC_signed_data_w(0,data);
 	sample_addr = (sample_addr + 1) & (memory_region_length(REGION_SOUND1) - 1);
