@@ -1,11 +1,12 @@
 #include "driver.h"
+#include "sound/es5506.h"
 
 static int counter,vector_reg,imr_status;
-static data16_t es5510_dsp_ram[0x200];
-static data32_t	es5510_gpr[0xc0];
-static data32_t	es5510_gpr_latch;
+static UINT16 es5510_dsp_ram[0x200];
+static UINT32	es5510_gpr[0xc0];
+static UINT32	es5510_gpr_latch;
 static void *timer_68681=NULL;
-extern data32_t *f3_shared_ram;
+extern UINT32 *f3_shared_ram;
 static int timer_mode,m68681_imr;
 
 static int es_tmp=1;
@@ -38,34 +39,29 @@ WRITE16_HANDLER( f3_es5505_bank_w )
 #if 0
 {
 	static char count[10];
-	char t[32];
 	count[data&7]++;
-	sprintf(t,"%d %d %d %d %d %d %d %d",count[0],count[1],count[2],count[3],count[4],count[5],count[6],count[7]);
-	usrintf_showmessage(t);
+	ui_popup("%x %x %x %x %x %x %x %x (%d)",count[0]&0xf,count[1]&0xf,count[2]&0xf,count[3]&0xf,count[4]&0xf,count[5]&0xf,count[6]&0xf,count[7]&0xf, max_banks_this_game);
 }
 #endif
 
-	/* If game is using a out of range (empty) bank - just set it to the last empty bank */
-	if ((data&0x7)>max_banks_this_game)
-		ES5506_voice_bank_0_w(offset,max_banks_this_game<<20);
-	else
-		ES5506_voice_bank_0_w(offset,(data&0x7)<<20);
+	/* mask out unused bits */
+	data &= max_banks_this_game;
+	ES5505_voice_bank_0_w(offset,data<<20);
 }
 
 WRITE16_HANDLER( f3_volume_w )
 {
-	static data16_t channel[8],last_l,last_r;
+	static UINT16 channel[8],last_l,last_r;
 	static int latch;
 
 	if (offset==0) latch=(data>>8)&0x7;
 	if (offset==1) channel[latch]=data>>8;
 
-	if(Machine->sample_rate) {
-/*		if (channel[7]!=last_l) mixer_set_volume(0, (int)((float)channel[7]*1.58));    Left master volume    */
-/*		if (channel[6]!=last_r) mixer_set_volume(1, (int)((float)channel[6]*1.58));    Right master volume    */
-		last_l=channel[7];
-		last_r=channel[6];
-	}
+/*      if (channel[7]!=last_l) mixer_set_volume(0, (int)((float)channel[7]*1.58));    Left master volume    */
+/*      if (channel[6]!=last_r) mixer_set_volume(1, (int)((float)channel[6]*1.58));    Right master volume    */
+	last_l=channel[7];
+	last_r=channel[6];
+
 	/* Channel 5 - Left Aux?  Always set to volume, but never used for panning */
 	/* Channel 4 - Right Aux?  Always set to volume, but never used for panning */
 	/* Channels 0, 1, 2, 3 - Unused */
@@ -73,22 +69,17 @@ WRITE16_HANDLER( f3_volume_w )
 
 static void timer_callback(int param)
 {
-	if (timer_mode==TIMER_SINGLESHOT) timer_68681=NULL;
-
 	/* Only cause IRQ if the mask is set to allow it */
 	if (m68681_imr&8) {
-		cpu_irq_line_vector_w(1, 6, vector_reg);
-		cpu_set_irq_line(1, 6, ASSERT_LINE);
+		cpunum_set_input_line_vector(1, 6, vector_reg);
+		cpunum_set_input_line(1, 6, ASSERT_LINE);
 		imr_status|=0x8;
 	}
 }
 
 void f3_68681_reset(void)
 {
-	if (timer_68681) {
-		timer_remove(timer_68681);
-		timer_68681=NULL;
-	}
+	timer_68681 = timer_alloc(timer_callback);
 }
 
 READ16_HANDLER(f3_68681_r)
@@ -104,7 +95,7 @@ READ16_HANDLER(f3_68681_r)
 
 	/* IRQ ack */
 	if (offset==0xf) {
-		cpu_set_irq_line(1, 6, CLEAR_LINE);
+		cpunum_set_input_line(1, 6, CLEAR_LINE);
 		return 0;
 	}
 
@@ -127,9 +118,8 @@ WRITE16_HANDLER(f3_68681_w)
 					break;
 				case 3:
 					logerror("Counter:  X1/Clk - divided by 16, counter is %04x, so interrupt every %d cycles\n",counter,(M68000_CLOCK/M68681_CLOCK)*counter*16);
-					if (timer_68681) timer_remove(timer_68681);
 					timer_mode=TIMER_SINGLESHOT;
-					timer_68681=timer_set(TIME_IN_CYCLES((M68000_CLOCK/M68681_CLOCK)*counter*16,1), 0, timer_callback);
+					timer_adjust(timer_68681, TIME_IN_CYCLES((M68000_CLOCK/M68681_CLOCK)*counter*16,1), 0, 0);
 					break;
 				case 4:
 					logerror("Timer:  Unimplemented external IP2\n");
@@ -139,9 +129,8 @@ WRITE16_HANDLER(f3_68681_w)
 					break;
 				case 6:
 					logerror("Timer:  X1/Clk, counter is %04x, so interrupt every %d cycles\n",counter,(M68000_CLOCK/M68681_CLOCK)*counter);
-					if (timer_68681) timer_remove(timer_68681);
 					timer_mode=TIMER_PULSE;
-					timer_68681=timer_pulse(TIME_IN_CYCLES((M68000_CLOCK/M68681_CLOCK)*counter,1), 0, timer_callback);
+					timer_adjust(timer_68681, TIME_IN_CYCLES((M68000_CLOCK/M68681_CLOCK)*counter,1), 0, TIME_IN_CYCLES((M68000_CLOCK/M68681_CLOCK)*counter,1));
 					break;
 				case 7:
 					logerror("Timer:  Unimplemented X1/Clk - divided by 16\n");
@@ -175,23 +164,23 @@ WRITE16_HANDLER(f3_68681_w)
 
 READ16_HANDLER(es5510_dsp_r)
 {
-/*	logerror("%06x: DSP read offset %04x (data is %04x)\n",cpu_get_pc(),offset,es5510_dsp_ram[offset]); */
-/*	if (es_tmp) return es5510_dsp_ram[offset]; */
+/*  logerror("%06x: DSP read offset %04x (data is %04x)\n",activecpu_get_pc(),offset,es5510_dsp_ram[offset]); */
+/*  if (es_tmp) return es5510_dsp_ram[offset]; */
 /*
-	switch (offset) {
-		case 0x00: return (es5510_gpr_latch>>16)&0xff;
-		case 0x01: return (es5510_gpr_latch>> 8)&0xff;
-		case 0x02: return (es5510_gpr_latch>> 0)&0xff;
-		case 0x03: return 0;
-	}
+    switch (offset) {
+        case 0x00: return (es5510_gpr_latch>>16)&0xff;
+        case 0x01: return (es5510_gpr_latch>> 8)&0xff;
+        case 0x02: return (es5510_gpr_latch>> 0)&0xff;
+        case 0x03: return 0;
+    }
 */
-/*	offset<<=1; */
+/*  offset<<=1; */
 
 /*if (offset<7 && es5510_dsp_ram[0]!=0xff) return rand()%0xffff; */
 
 	if (offset==0x12) return 0;
 
-/*	if (offset>4) */
+/*  if (offset>4) */
 	if (offset==0x16) return 0x27;
 
 	return es5510_dsp_ram[offset];
@@ -201,8 +190,8 @@ WRITE16_HANDLER(es5510_dsp_w)
 {
 	UINT8 *snd_mem = (UINT8 *)memory_region(REGION_SOUND1);
 
-/*	if (offset>4 && offset!=0x80  && offset!=0xa0  && offset!=0xc0  && offset!=0xe0) */
-/*		logerror("%06x: DSP write offset %04x %04x\n",cpu_get_pc(),offset,data); */
+/*  if (offset>4 && offset!=0x80  && offset!=0xa0  && offset!=0xc0  && offset!=0xe0) */
+/*      logerror("%06x: DSP write offset %04x %04x\n",activecpu_get_pc(),offset,data); */
 
 	COMBINE_DATA(&es5510_dsp_ram[offset]);
 
@@ -213,7 +202,7 @@ WRITE16_HANDLER(es5510_dsp_w)
 		case 0x03: break;
 
 		case 0x80: /* Read select - GPR + INSTR */
-	/*		logerror("ES5510:  Read GPR/INSTR %06x (%06x)\n",data,es5510_gpr[data]); */
+	/*      logerror("ES5510:  Read GPR/INSTR %06x (%06x)\n",data,es5510_gpr[data]); */
 
 			/* Check if a GPR is selected */
 			if (data<0xc0) {
@@ -223,17 +212,17 @@ WRITE16_HANDLER(es5510_dsp_w)
 			break;
 
 		case 0xa0: /* Write select - GPR */
-	/*		logerror("ES5510:  Write GPR %06x %06x (0x%04x:=0x%06x\n",data,es5510_gpr_latch,data,snd_mem[es5510_gpr_latch>>8]); */
+	/*      logerror("ES5510:  Write GPR %06x %06x (0x%04x:=0x%06x\n",data,es5510_gpr_latch,data,snd_mem[es5510_gpr_latch>>8]); */
 			if (data<0xc0)
 				es5510_gpr[data]=snd_mem[es5510_gpr_latch>>8];
 			break;
 
 		case 0xc0: /* Write select - INSTR */
-	/*		logerror("ES5510:  Write INSTR %06x %06x\n",data,es5510_gpr_latch); */
+	/*      logerror("ES5510:  Write INSTR %06x %06x\n",data,es5510_gpr_latch); */
 			break;
 
 		case 0xe0: /* Write select - GPR + INSTR */
-	/*		logerror("ES5510:  Write GPR/INSTR %06x %06x\n",data,es5510_gpr_latch); */
+	/*      logerror("ES5510:  Write GPR/INSTR %06x %06x\n",data,es5510_gpr_latch); */
 			break;
 	}
 }
