@@ -38,12 +38,12 @@
 
 UINT8 williams_sound_int_state;
 
+static UINT8 audio_talkback;
+
 static INT8 sound_cpunum;
 static INT8 soundalt_cpunum;
 static UINT8 williams_pianum;
 
-static UINT8 adpcm_bank_count;
-
 
 
 /***************************************************************************
@@ -57,20 +57,25 @@ static void adpcm_ym2151_irq(int state);
 static void cvsd_irqa(int state);
 static void cvsd_irqb(int state);
 
-static READ8_HANDLER( cvsd_pia_r );
-
-static WRITE8_HANDLER( cvsd_pia_w );
 static WRITE8_HANDLER( cvsd_bank_select_w );
+static READ8_HANDLER( cvsd_pia_r );
+static WRITE8_HANDLER( cvsd_pia_w );
+static WRITE8_HANDLER( cvsd_talkback_w );
 
 static READ8_HANDLER( adpcm_command_r );
 static WRITE8_HANDLER( adpcm_bank_select_w );
 static WRITE8_HANDLER( adpcm_6295_bank_select_w );
+static WRITE8_HANDLER( adpcm_talkback_w );
 
 static READ8_HANDLER( narc_command_r );
 static READ8_HANDLER( narc_command2_r );
 static WRITE8_HANDLER( narc_command2_w );
 static WRITE8_HANDLER( narc_master_bank_select_w );
 static WRITE8_HANDLER( narc_slave_bank_select_w );
+static WRITE8_HANDLER( narc_master_talkback_w );
+static WRITE8_HANDLER( narc_master_sync_w );
+static WRITE8_HANDLER( narc_slave_talkback_w );
+static WRITE8_HANDLER( narc_slave_sync_w );
 
 
 
@@ -79,94 +84,61 @@ static WRITE8_HANDLER( narc_slave_bank_select_w );
 ****************************************************************************/
 
 /* CVSD readmem/writemem structures */
-ADDRESS_MAP_START( williams_cvsd_readmem, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0x07ff) AM_READ(MRA8_RAM)
-	AM_RANGE(0x2000, 0x2001) AM_READ(YM2151_status_port_0_r)
-	AM_RANGE(0x4000, 0x4003) AM_READ(cvsd_pia_r)
-	AM_RANGE(0x8000, 0xffff) AM_READ(MRA8_BANK6)
+ADDRESS_MAP_START( williams_cvsd_map, ADDRESS_SPACE_PROGRAM, 8 )
+	AM_RANGE(0x0000, 0x07ff) AM_MIRROR(0x1800) AM_RAM
+	AM_RANGE(0x2000, 0x2000) AM_MIRROR(0x1ffe) AM_WRITE(YM2151_register_port_0_w)
+	AM_RANGE(0x2001, 0x2001) AM_MIRROR(0x1ffe) AM_READWRITE(YM2151_status_port_0_r, YM2151_data_port_0_w)
+	AM_RANGE(0x4000, 0x4003) AM_MIRROR(0x1ffc) AM_READWRITE(cvsd_pia_r, cvsd_pia_w)
+	AM_RANGE(0x6000, 0x6000) AM_MIRROR(0x07ff) AM_WRITE(hc55516_0_digit_clock_clear_w)
+	AM_RANGE(0x6800, 0x6800) AM_MIRROR(0x07ff) AM_WRITE(hc55516_0_clock_set_w)
+	AM_RANGE(0x7800, 0x7800) AM_MIRROR(0x07ff) AM_WRITE(cvsd_bank_select_w)
+	AM_RANGE(0x8000, 0xffff) AM_ROMBANK(5)
 ADDRESS_MAP_END
 
 
-ADDRESS_MAP_START( williams_cvsd_writemem, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0x07ff) AM_WRITE(MWA8_RAM)
-	AM_RANGE(0x2000, 0x2000) AM_WRITE(YM2151_register_port_0_w)
-	AM_RANGE(0x2001, 0x2001) AM_WRITE(YM2151_data_port_0_w)
-	AM_RANGE(0x4000, 0x4003) AM_WRITE(cvsd_pia_w)
-	AM_RANGE(0x6000, 0x6000) AM_WRITE(hc55516_0_digit_clock_clear_w)
-	AM_RANGE(0x6800, 0x6800) AM_WRITE(hc55516_0_clock_set_w)
-	AM_RANGE(0x7800, 0x7800) AM_WRITE(cvsd_bank_select_w)
-	AM_RANGE(0x8000, 0xffff) AM_WRITE(MWA8_ROM)
-ADDRESS_MAP_END
-
-
-
-/* ADPCM readmem/writemem structures */
-ADDRESS_MAP_START( williams_adpcm_readmem, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0x1fff) AM_READ(MRA8_RAM)
-	AM_RANGE(0x2401, 0x2401) AM_READ(YM2151_status_port_0_r)
-	AM_RANGE(0x2c00, 0x2c00) AM_READ(OKIM6295_status_0_r)
-	AM_RANGE(0x3000, 0x3000) AM_READ(adpcm_command_r)
-	AM_RANGE(0x4000, 0xbfff) AM_READ(MRA8_BANK6)
-	AM_RANGE(0xc000, 0xffff) AM_READ(MRA8_ROM)
-ADDRESS_MAP_END
-
-
-ADDRESS_MAP_START( williams_adpcm_writemem, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0x1fff) AM_WRITE(MWA8_RAM)
-	AM_RANGE(0x2000, 0x2000) AM_WRITE(adpcm_bank_select_w)
-	AM_RANGE(0x2400, 0x2400) AM_WRITE(YM2151_register_port_0_w)
-	AM_RANGE(0x2401, 0x2401) AM_WRITE(YM2151_data_port_0_w)
-	AM_RANGE(0x2800, 0x2800) AM_WRITE(DAC_0_data_w)
-	AM_RANGE(0x2c00, 0x2c00) AM_WRITE(OKIM6295_data_0_w)
-	AM_RANGE(0x3400, 0x3400) AM_WRITE(adpcm_6295_bank_select_w)
-	AM_RANGE(0x3c00, 0x3c00) AM_WRITE(MWA8_NOP)/*mk_sound_talkback_w }, -- talkback port? */
-	AM_RANGE(0x4000, 0xffff) AM_WRITE(MWA8_ROM)
-ADDRESS_MAP_END
-
-
-
 /* NARC master readmem/writemem structures */
-ADDRESS_MAP_START( williams_narc_master_readmem, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0x1fff) AM_READ(MRA8_RAM)
-	AM_RANGE(0x2001, 0x2001) AM_READ(YM2151_status_port_0_r)
-	AM_RANGE(0x3000, 0x3000) AM_READ(MRA8_NOP)
-	AM_RANGE(0x3400, 0x3400) AM_READ(narc_command_r)
-	AM_RANGE(0x4000, 0xbfff) AM_READ(MRA8_BANK6)
-	AM_RANGE(0xc000, 0xffff) AM_READ(MRA8_ROM)
+ADDRESS_MAP_START( williams_narc_master_map, ADDRESS_SPACE_PROGRAM, 8 )
+	AM_RANGE(0x0000, 0x1fff) AM_RAM
+	AM_RANGE(0x2000, 0x2000) AM_MIRROR(0x03fe) AM_WRITE(YM2151_register_port_0_w)
+	AM_RANGE(0x2001, 0x2001) AM_MIRROR(0x03fe) AM_READWRITE(YM2151_status_port_0_r, YM2151_data_port_0_w)
+	AM_RANGE(0x2800, 0x2800) AM_MIRROR(0x03ff) AM_WRITE(narc_master_talkback_w)
+	AM_RANGE(0x2c00, 0x2c00) AM_MIRROR(0x03ff) AM_WRITE(narc_command2_w)
+	AM_RANGE(0x3000, 0x3000) AM_MIRROR(0x03ff) AM_WRITE(DAC_0_data_w)
+	AM_RANGE(0x3400, 0x3400) AM_MIRROR(0x03ff) AM_READ(narc_command_r)
+	AM_RANGE(0x3800, 0x3800) AM_MIRROR(0x03ff) AM_WRITE(narc_master_bank_select_w)
+	AM_RANGE(0x3c00, 0x3c00) AM_MIRROR(0x03ff) AM_WRITE(narc_master_sync_w)
+	AM_RANGE(0x4000, 0xbfff) AM_ROMBANK(5)
+	AM_RANGE(0xc000, 0xffff) AM_ROMBANK(6)
 ADDRESS_MAP_END
 
-
-ADDRESS_MAP_START( williams_narc_master_writemem, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0x1fff) AM_WRITE(MWA8_RAM)
-	AM_RANGE(0x2000, 0x2000) AM_WRITE(YM2151_register_port_0_w)
-	AM_RANGE(0x2001, 0x2001) AM_WRITE(YM2151_data_port_0_w)
-	AM_RANGE(0x2800, 0x2800) AM_WRITE(MWA8_NOP)/*mk_sound_talkback_w }, -- talkback port? */
-	AM_RANGE(0x2c00, 0x2c00) AM_WRITE(narc_command2_w)
-	AM_RANGE(0x3000, 0x3000) AM_WRITE(DAC_0_data_w)
-	AM_RANGE(0x3800, 0x3800) AM_WRITE(narc_master_bank_select_w)
-	AM_RANGE(0x4000, 0xffff) AM_WRITE(MWA8_ROM)
-ADDRESS_MAP_END
-
-
-
 /* NARC slave readmem/writemem structures */
-ADDRESS_MAP_START( williams_narc_slave_readmem, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0x1fff) AM_READ(MRA8_RAM)
-	AM_RANGE(0x3000, 0x3000) AM_READ(MRA8_NOP)
-	AM_RANGE(0x3400, 0x3400) AM_READ(narc_command2_r)
-	AM_RANGE(0x4000, 0xbfff) AM_READ(MRA8_BANK5)
-	AM_RANGE(0xc000, 0xffff) AM_READ(MRA8_ROM)
+ADDRESS_MAP_START( williams_narc_slave_map, ADDRESS_SPACE_PROGRAM, 8 )
+	AM_RANGE(0x0000, 0x1fff) AM_RAM
+	AM_RANGE(0x2000, 0x2000) AM_MIRROR(0x03ff) AM_WRITE(hc55516_0_clock_set_w)
+	AM_RANGE(0x2400, 0x2400) AM_MIRROR(0x03ff) AM_WRITE(hc55516_0_digit_clock_clear_w)
+	AM_RANGE(0x2800, 0x2800) AM_MIRROR(0x03ff) AM_WRITE(narc_slave_talkback_w)
+	AM_RANGE(0x3000, 0x3000) AM_MIRROR(0x03ff) AM_WRITE(DAC_1_data_w)
+	AM_RANGE(0x3400, 0x3400) AM_MIRROR(0x03ff) AM_READ(narc_command2_r)
+	AM_RANGE(0x3800, 0x3800) AM_MIRROR(0x03ff) AM_WRITE(narc_slave_bank_select_w)
+	AM_RANGE(0x3c00, 0x3c00) AM_MIRROR(0x03ff) AM_WRITE(narc_slave_sync_w)
+	AM_RANGE(0x4000, 0xbfff) AM_ROMBANK(7)
+	AM_RANGE(0xc000, 0xffff) AM_ROMBANK(8)
 ADDRESS_MAP_END
 
 
-ADDRESS_MAP_START( williams_narc_slave_writemem, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0x1fff) AM_WRITE(MWA8_RAM)
-	AM_RANGE(0x2000, 0x2000) AM_WRITE(hc55516_0_clock_set_w)
-	AM_RANGE(0x2400, 0x2400) AM_WRITE(hc55516_0_digit_clock_clear_w)
-	AM_RANGE(0x3000, 0x3000) AM_WRITE(DAC_1_data_w)
-	AM_RANGE(0x3800, 0x3800) AM_WRITE(narc_slave_bank_select_w)
-	AM_RANGE(0x3c00, 0x3c00) AM_WRITE(MWA8_NOP)
-	AM_RANGE(0x4000, 0xffff) AM_WRITE(MWA8_ROM)
+/* ADPCM readmem/writemem structures */
+ADDRESS_MAP_START( williams_adpcm_map, ADDRESS_SPACE_PROGRAM, 8 )
+	AM_RANGE(0x0000, 0x1fff) AM_RAM
+	AM_RANGE(0x2000, 0x2000) AM_MIRROR(0x03ff) AM_WRITE(adpcm_bank_select_w)
+	AM_RANGE(0x2400, 0x2400) AM_MIRROR(0x03fe) AM_WRITE(YM2151_register_port_0_w)
+	AM_RANGE(0x2401, 0x2401) AM_MIRROR(0x03fe) AM_READWRITE(YM2151_status_port_0_r, YM2151_data_port_0_w)
+	AM_RANGE(0x2800, 0x2800) AM_MIRROR(0x03ff) AM_WRITE(DAC_0_data_w)
+	AM_RANGE(0x2c00, 0x2c00) AM_MIRROR(0x03ff) AM_READWRITE(OKIM6295_status_0_r, OKIM6295_data_0_w)
+	AM_RANGE(0x3000, 0x3000) AM_MIRROR(0x03ff) AM_READ(adpcm_command_r)
+	AM_RANGE(0x3400, 0x3400) AM_MIRROR(0x03ff) AM_WRITE(adpcm_6295_bank_select_w)
+	AM_RANGE(0x3c00, 0x3c00) AM_MIRROR(0x03ff) AM_WRITE(adpcm_talkback_w)
+	AM_RANGE(0x4000, 0xbfff) AM_ROMBANK(5)
+	AM_RANGE(0xc000, 0xffff) AM_ROMBANK(6)
 ADDRESS_MAP_END
 
 
@@ -175,7 +147,7 @@ ADDRESS_MAP_END
 static struct pia6821_interface cvsd_pia_intf =
 {
 	/*inputs : A/B,CA/B1,CA/B2 */ 0, 0, 0, 0, 0, 0,
-	/*outputs: A/B,CA/B2       */ DAC_0_data_w, 0, 0, 0,
+	/*outputs: A/B,CA/B2       */ DAC_0_data_w, cvsd_talkback_w, 0, 0,
 	/*irqs   : A/B             */ cvsd_irqa, cvsd_irqb
 };
 
@@ -206,117 +178,67 @@ static struct YM2151interface adpcm_ym2151_interface =
 
 MACHINE_DRIVER_START( williams_cvsd_sound )
 	MDRV_CPU_ADD_TAG("cvsd", M6809, 8000000/4)
-	/* audio CPU */
-	MDRV_CPU_PROGRAM_MAP(williams_cvsd_readmem,williams_cvsd_writemem)
+	MDRV_CPU_PROGRAM_MAP(williams_cvsd_map,0)
 
-	MDRV_SPEAKER_STANDARD_STEREO("left", "right")
+	MDRV_SPEAKER_STANDARD_MONO("mono")
 
 	MDRV_SOUND_ADD(YM2151, 3579580)
 	MDRV_SOUND_CONFIG(cvsd_ym2151_interface)
-	MDRV_SOUND_ROUTE(0, "left", 0.10)
-	MDRV_SOUND_ROUTE(1, "right", 0.10)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.10)
 
 	MDRV_SOUND_ADD(DAC, 0)
-	MDRV_SOUND_ROUTE(0, "left", 0.50)
-	MDRV_SOUND_ROUTE(0, "right", 0.50)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
 
 	MDRV_SOUND_ADD(HC55516, 0)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "left", 0.80)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "right", 0.80)
-MACHINE_DRIVER_END
-
-
-MACHINE_DRIVER_START( williams_adpcm_sound )
-	MDRV_CPU_ADD_TAG("adpcm", M6809, 8000000/4)
-	/* audio CPU */
-	MDRV_CPU_PROGRAM_MAP(williams_adpcm_readmem,williams_adpcm_writemem)
-
-	MDRV_SPEAKER_STANDARD_STEREO("left", "right")
-
-	MDRV_SOUND_ADD(YM2151, 3579580)
-	MDRV_SOUND_CONFIG(adpcm_ym2151_interface)
-	MDRV_SOUND_ROUTE(0, "left", 0.10)
-	MDRV_SOUND_ROUTE(1, "right", 0.10)
-
-	MDRV_SOUND_ADD(DAC, 0)
-	MDRV_SOUND_ROUTE(0, "left", 0.50)
-	MDRV_SOUND_ROUTE(0, "right", 0.50)
-
-	MDRV_SOUND_ADD(OKIM6295, 8000)
-	MDRV_SOUND_CONFIG(okim6295_interface_region_1)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "left", 0.50)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "right", 0.50)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.60)
 MACHINE_DRIVER_END
 
 
 MACHINE_DRIVER_START( williams_narc_sound )
 	MDRV_CPU_ADD_TAG("narc1", M6809, 8000000/4)
-	/* audio CPU */
-	MDRV_CPU_PROGRAM_MAP(williams_narc_master_readmem,williams_narc_master_writemem)
+	MDRV_CPU_PROGRAM_MAP(williams_narc_master_map,0)
 
 	MDRV_CPU_ADD_TAG("narc2", M6809, 8000000/4)
-	/* audio CPU */
-	MDRV_CPU_PROGRAM_MAP(williams_narc_slave_readmem,williams_narc_slave_writemem)
+	MDRV_CPU_PROGRAM_MAP(williams_narc_slave_map,0)
 
 	MDRV_SPEAKER_STANDARD_STEREO("left", "right")
 
 	MDRV_SOUND_ADD(YM2151, 3579580)
 	MDRV_SOUND_CONFIG(adpcm_ym2151_interface)
-	MDRV_SOUND_ROUTE(0, "left", 0.10)
-	MDRV_SOUND_ROUTE(1, "right", 0.10)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "left", 0.10)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "right", 0.10)
 
 	MDRV_SOUND_ADD(DAC, 0)
-	MDRV_SOUND_ROUTE(0, "left", 0.50)
-	MDRV_SOUND_ROUTE(0, "right", 0.50)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "left", 0.50)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "right", 0.50)
 
 	MDRV_SOUND_ADD(DAC, 0)
-	MDRV_SOUND_ROUTE(0, "left", 0.50)
-	MDRV_SOUND_ROUTE(0, "right", 0.50)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "left", 0.50)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "right", 0.50)
 
 	MDRV_SOUND_ADD(HC55516, 0)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "left", 0.80)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "right", 0.80)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "left", 0.60)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "right", 0.60)
 MACHINE_DRIVER_END
 
 
+MACHINE_DRIVER_START( williams_adpcm_sound )
+	MDRV_CPU_ADD_TAG("adpcm", M6809, 8000000/4)
+	MDRV_CPU_PROGRAM_MAP(williams_adpcm_map,0)
 
-/***************************************************************************
-    INLINES
-****************************************************************************/
+	MDRV_SPEAKER_STANDARD_MONO("mono")
 
-INLINE UINT8 *get_cvsd_bank_base(int data)
-{
-	UINT8 *RAM = memory_region(REGION_CPU1 + sound_cpunum);
-	int bank = data & 3;
-	int quarter = (data >> 2) & 3;
-	if (bank == 3) bank = 0;
-	return &RAM[0x10000 + (bank * 0x20000) + (quarter * 0x8000)];
-}
+	MDRV_SOUND_ADD(YM2151, 3579580)
+	MDRV_SOUND_CONFIG(adpcm_ym2151_interface)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.10)
 
+	MDRV_SOUND_ADD(DAC, 0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
 
-INLINE UINT8 *get_adpcm_bank_base(int data)
-{
-	UINT8 *RAM = memory_region(REGION_CPU1 + sound_cpunum);
-	int bank = data & 7;
-	return &RAM[0x10000 + (bank * 0x8000)];
-}
-
-
-INLINE UINT8 *get_narc_master_bank_base(int data)
-{
-	UINT8 *RAM = memory_region(REGION_CPU1 + sound_cpunum);
-	int bank = data & 3;
-	if (!(data & 4)) bank = 0;
-	return &RAM[0x10000 + (bank * 0x8000)];
-}
-
-
-INLINE UINT8 *get_narc_slave_bank_base(int data)
-{
-	UINT8 *RAM = memory_region(REGION_CPU1 + soundalt_cpunum);
-	int bank = data & 7;
-	return &RAM[0x10000 + (bank * 0x8000)];
-}
+	MDRV_SOUND_ADD(OKIM6295, 8000)
+	MDRV_SOUND_CONFIG(okim6295_interface_region_1)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
+MACHINE_DRIVER_END
 
 
 
@@ -324,8 +246,11 @@ INLINE UINT8 *get_narc_slave_bank_base(int data)
     INITIALIZATION
 ****************************************************************************/
 
-void williams_cvsd_init(int cpunum, int pianum)
+void williams_cvsd_init(int pianum)
 {
+	UINT8 *ROM;
+	int bank;
+
 	/* configure the CPU */
 	sound_cpunum = mame_find_cpu_index("cvsd");
 	soundalt_cpunum = -1;
@@ -334,68 +259,102 @@ void williams_cvsd_init(int cpunum, int pianum)
 	williams_pianum = pianum;
 	pia_config(pianum, PIA_STANDARD_ORDERING, &cvsd_pia_intf);
 
-	/* initialize the global variables */
-	init_audio_state();
-
-	/* reset the chip */
-	williams_cvsd_reset_w(1);
-	williams_cvsd_reset_w(0);
+	/* configure master CPU banks */
+	ROM = memory_region(REGION_CPU1 + sound_cpunum);
+	for (bank = 0; bank < 16; bank++)
+	{
+		/*
+            D0/D1 -> selects: 0=U4 1=U19 2=U20 3=n/c
+            D2 -> A15
+            D3 -> A16
+         */
+		offs_t offset = 0x8000 * ((bank >> 2) & 3) + 0x20000 * (bank & 3);
+		memory_configure_bank(5, bank, 1, &ROM[0x10000 + offset], 0);
+	}
 
 	/* reset the IRQ state */
 	pia_set_input_ca1(williams_pianum, 1);
 }
 
 
-void williams_adpcm_init(int cpunum)
+void williams_narc_init(void)
 {
-	UINT8 *RAM;
-	int i;
-
-	/* configure the CPU */
-	sound_cpunum = mame_find_cpu_index("adpcm");
-	soundalt_cpunum = -1;
-
-	/* install the fixed ROM */
-	RAM = memory_region(REGION_CPU1 + sound_cpunum);
-	memcpy(&RAM[0xc000], &RAM[0x4c000], 0x4000);
-
-	/* initialize the global variables */
-	init_audio_state();
-
-	/* reset the chip */
-	williams_adpcm_reset_w(1);
-	williams_adpcm_reset_w(0);
-
-	/* find the number of banks in the ADPCM space */
-	for (i = 0; i < MAX_SOUND; i++)
-		if (Machine->drv->sound[i].sound_type == SOUND_OKIM6295)
-		{
-			struct OKIM6295interface *intf = (struct OKIM6295interface *)Machine->drv->sound[i].config;
-			adpcm_bank_count = memory_region_length(intf->region) / 0x40000;
-		}
-}
-
-
-void williams_narc_init(int cpunum)
-{
-	UINT8 *RAM;
+	UINT8 *ROM;
+	int bank;
 
 	/* configure the CPU */
 	sound_cpunum = mame_find_cpu_index("narc1");
 	soundalt_cpunum = mame_find_cpu_index("narc2");
 
-	/* install the fixed ROM */
-	RAM = memory_region(REGION_CPU1 + sound_cpunum);
-	memcpy(&RAM[0xc000], &RAM[0x2c000], 0x4000);
-	RAM = memory_region(REGION_CPU1 + soundalt_cpunum);
-	memcpy(&RAM[0xc000], &RAM[0x4c000], 0x4000);
+	/* configure master CPU banks */
+	ROM = memory_region(REGION_CPU1 + sound_cpunum);
+	for (bank = 0; bank < 16; bank++)
+	{
+		/*
+            D0 -> A15
+            D1/D2 -> selects: 0=n/c 1=U3 2=U4 3=U5
+            D3 -> A16
+         */
+		offs_t offset = 0x8000 * (bank & 1) + 0x10000 * ((bank >> 3) & 1) + 0x20000 * ((bank >> 1) & 3);
+		memory_configure_bank(5, bank, 1, &ROM[0x10000 + offset], 0);
+	}
+	memory_set_bankptr(6, &ROM[0x10000 + 0x4000 + 0x8000 + 0x10000 + 0x20000 * 3]);
 
-	/* initialize the global variables */
-	init_audio_state();
+	/* configure slave CPU banks */
+	ROM = memory_region(REGION_CPU1 + soundalt_cpunum);
+	for (bank = 0; bank < 16; bank++)
+	{
+		/*
+            D0 -> A15
+            D1/D2 -> selects: 0=U35 1=U36 2=U37 3=U38
+            D3 -> A16
+        */
+		offs_t offset = 0x8000 * (bank & 1) + 0x10000 * ((bank >> 3) & 1) + 0x20000 * ((bank >> 1) & 3);
+		memory_configure_bank(7, bank, 1, &ROM[0x10000 + offset], 0);
+	}
+	memory_set_bankptr(8, &ROM[0x10000 + 0x4000 + 0x8000 + 0x10000 + 0x20000 * 3]);
 
-	/* reset the chip */
-	williams_narc_reset_w(1);
-	williams_narc_reset_w(0);
+	/* register for save states */
+	state_save_register_global(williams_sound_int_state);
+	state_save_register_global(audio_talkback);
+}
+
+
+void williams_adpcm_init(void)
+{
+	UINT8 *ROM;
+
+	/* configure the CPU */
+	sound_cpunum = mame_find_cpu_index("adpcm");
+	soundalt_cpunum = -1;
+
+	/* configure banks */
+	ROM = memory_region(REGION_CPU1 + sound_cpunum);
+	memory_configure_bank(5, 0, 8, &ROM[0x10000], 0x8000);
+	memory_set_bankptr(6, &ROM[0x10000 + 0x4000 + 7 * 0x8000]);
+
+	/* expand ADPCM data */
+	/* it is assumed that U12 is loaded @ 0x00000 and U13 is loaded @ 0x40000 */
+	ROM = memory_region(REGION_SOUND1);
+	memcpy(ROM + 0x1c0000, ROM + 0x080000, 0x20000);	/* expand individual banks */
+	memcpy(ROM + 0x180000, ROM + 0x0a0000, 0x20000);
+	memcpy(ROM + 0x140000, ROM + 0x0c0000, 0x20000);
+	memcpy(ROM + 0x100000, ROM + 0x0e0000, 0x20000);
+	memcpy(ROM + 0x0c0000, ROM + 0x000000, 0x20000);
+	memcpy(ROM + 0x000000, ROM + 0x040000, 0x20000);
+	memcpy(ROM + 0x080000, ROM + 0x020000, 0x20000);
+
+	memcpy(ROM + 0x1e0000, ROM + 0x060000, 0x20000);	/* copy common bank */
+	memcpy(ROM + 0x1a0000, ROM + 0x060000, 0x20000);
+	memcpy(ROM + 0x160000, ROM + 0x060000, 0x20000);
+	memcpy(ROM + 0x120000, ROM + 0x060000, 0x20000);
+	memcpy(ROM + 0x0e0000, ROM + 0x060000, 0x20000);
+	memcpy(ROM + 0x0a0000, ROM + 0x060000, 0x20000);
+	memcpy(ROM + 0x020000, ROM + 0x060000, 0x20000);
+
+	/* register for save states */
+	state_save_register_global(williams_sound_int_state);
+	state_save_register_global(audio_talkback);
 }
 
 
@@ -421,32 +380,6 @@ static void init_audio_state(void)
 }
 
 
-#if 0
-static void locate_audio_hotspot(UINT8 *base, UINT16 start)
-{
-	int i;
-
-	/* search for the loop that kills performance so we can optimize it */
-	for (i = start; i < 0x10000; i++)
-	{
-		if (base[i + 0] == 0x1a && base[i + 1] == 0x50 &&			/* 1A 50       ORCC  #$0050  */
-			base[i + 2] == 0x93 &&									/* 93 xx       SUBD  $xx     */
-			base[i + 4] == 0xe3 && base[i + 5] == 0x4c &&			/* E3 4C       ADDD  $000C,U */
-			base[i + 6] == 0x9e && base[i + 7] == base[i + 3] &&	/* 9E xx       LDX   $xx     */
-			base[i + 8] == 0xaf && base[i + 9] == 0x4c &&			/* AF 4C       STX   $000C,U */
-			base[i +10] == 0x1c && base[i +11] == 0xaf)				/* 1C AF       ANDCC #$00AF  */
-		{
-/*          counter.hotspot_start = i; */
-/*          counter.hotspot_stop = i + 12; */
-			logerror("Found hotspot @ %04X", i);
-			return;
-		}
-	}
-	logerror("Found no hotspot!");
-}
-#endif
-
-
 
 /***************************************************************************
     CVSD IRQ GENERATION CALLBACKS
@@ -483,68 +416,15 @@ static void adpcm_ym2151_irq(int state)
 
 
 /***************************************************************************
-    CVSD BANK SELECT
+    CVSD READ/WRITE HANDLERS
 ****************************************************************************/
 
 static WRITE8_HANDLER( cvsd_bank_select_w )
 {
-	memory_set_bankptr(6, get_cvsd_bank_base(data));
+	memory_set_bank(5, data & 0x0f);
 }
 
 
-
-/***************************************************************************
-    ADPCM BANK SELECT
-****************************************************************************/
-
-static WRITE8_HANDLER( adpcm_bank_select_w )
-{
-	memory_set_bankptr(6, get_adpcm_bank_base(data));
-}
-
-
-static WRITE8_HANDLER( adpcm_6295_bank_select_w )
-{
-	if (adpcm_bank_count <= 3)
-	{
-		if (!(data & 0x04))
-			OKIM6295_set_bank_base(0, 0x00000);
-		else if (data & 0x01)
-			OKIM6295_set_bank_base(0, 0x40000);
-		else
-			OKIM6295_set_bank_base(0, 0x80000);
-	}
-	else
-	{
-		data &= 7;
-		if (data != 0)
-			OKIM6295_set_bank_base(0, (data - 1) * 0x40000);
-	}
-}
-
-
-
-/***************************************************************************
-    NARC BANK SELECT
-****************************************************************************/
-
-static WRITE8_HANDLER( narc_master_bank_select_w )
-{
-	memory_set_bankptr(6, get_narc_master_bank_base(data));
-}
-
-
-static WRITE8_HANDLER( narc_slave_bank_select_w )
-{
-	memory_set_bankptr(5, get_narc_slave_bank_base(data));
-}
-
-
-
-/***************************************************************************
-    PIA INTERFACES
-****************************************************************************/
-
 static READ8_HANDLER( cvsd_pia_r )
 {
 	return pia_read(williams_pianum, offset);
@@ -557,6 +437,13 @@ static WRITE8_HANDLER( cvsd_pia_w )
 }
 
 
+static WRITE8_HANDLER( cvsd_talkback_w )
+{
+	audio_talkback = data;
+	logerror("CVSD Talkback = %02X\n", data);
+}
+
+
 
 /***************************************************************************
     CVSD COMMUNICATIONS
@@ -593,10 +480,22 @@ void williams_cvsd_reset_w(int state)
 
 
 /***************************************************************************
-    ADPCM COMMUNICATIONS
+    NARC READ/WRITE HANDLERS
 ****************************************************************************/
 
-static READ8_HANDLER( adpcm_command_r )
+static WRITE8_HANDLER( narc_master_bank_select_w )
+{
+	memory_set_bank(5, data & 0x0f);
+}
+
+
+static WRITE8_HANDLER( narc_slave_bank_select_w )
+{
+	memory_set_bank(7, data & 0x0f);
+}
+
+
+static READ8_HANDLER( narc_command_r )
 {
 	cpunum_set_input_line(sound_cpunum, M6809_IRQ_LINE, CLEAR_LINE);
 	williams_sound_int_state = 0;
@@ -604,29 +503,42 @@ static READ8_HANDLER( adpcm_command_r )
 }
 
 
-void williams_adpcm_data_w(int data)
+static WRITE8_HANDLER( narc_command2_w )
 {
-	soundlatch_w(0, data & 0xff);
-	if (!(data & 0x200))
-	{
-		cpunum_set_input_line(sound_cpunum, M6809_IRQ_LINE, ASSERT_LINE);
-		williams_sound_int_state = 1;
-	}
+	soundlatch2_w(0, data & 0xff);
+	cpunum_set_input_line(soundalt_cpunum, M6809_FIRQ_LINE, ASSERT_LINE);
 }
 
 
-void williams_adpcm_reset_w(int state)
+static READ8_HANDLER( narc_command2_r )
 {
-	/* going high halts the CPU */
-	if (state)
-	{
-		adpcm_bank_select_w(0, 0);
-		init_audio_state();
-		cpunum_set_input_line(sound_cpunum, INPUT_LINE_RESET, ASSERT_LINE);
-	}
-	/* going low resets and reactivates the CPU */
-	else
-		cpunum_set_input_line(sound_cpunum, INPUT_LINE_RESET, CLEAR_LINE);
+	cpunum_set_input_line(soundalt_cpunum, M6809_FIRQ_LINE, CLEAR_LINE);
+	return soundlatch2_r(0);
+}
+
+
+static WRITE8_HANDLER( narc_master_talkback_w )
+{
+	audio_talkback = data;
+	logerror("Master Talkback = %02X\n", data);
+}
+
+
+static WRITE8_HANDLER( narc_master_sync_w )
+{
+	logerror("Master sync = %02X\n", data);
+}
+
+
+static WRITE8_HANDLER( narc_slave_talkback_w )
+{
+	logerror("Slave Talkback = %02X\n", data);
+}
+
+
+static WRITE8_HANDLER( narc_slave_sync_w )
+{
+	logerror("Slave sync = %02X\n", data);
 }
 
 
@@ -635,20 +547,10 @@ void williams_adpcm_reset_w(int state)
     NARC COMMUNICATIONS
 ****************************************************************************/
 
-static READ8_HANDLER( narc_command_r )
-{
-	cpunum_set_input_line(sound_cpunum, INPUT_LINE_NMI, CLEAR_LINE);
-	cpunum_set_input_line(sound_cpunum, M6809_IRQ_LINE, CLEAR_LINE);
-	williams_sound_int_state = 0;
-	return soundlatch_r(0);
-}
-
-
 void williams_narc_data_w(int data)
 {
 	soundlatch_w(0, data & 0xff);
-	if (!(data & 0x100))
-		cpunum_set_input_line(sound_cpunum, INPUT_LINE_NMI, ASSERT_LINE);
+	cpunum_set_input_line(sound_cpunum, INPUT_LINE_NMI, (data & 0x100) ? CLEAR_LINE : ASSERT_LINE);
 	if (!(data & 0x200))
 	{
 		cpunum_set_input_line(sound_cpunum, M6809_IRQ_LINE, ASSERT_LINE);
@@ -677,15 +579,64 @@ void williams_narc_reset_w(int state)
 }
 
 
-static READ8_HANDLER( narc_command2_r )
+
+/***************************************************************************
+    ADPCM READ/WRITE HANDLERS
+****************************************************************************/
+
+static WRITE8_HANDLER( adpcm_bank_select_w )
 {
-	cpunum_set_input_line(soundalt_cpunum, M6809_FIRQ_LINE, CLEAR_LINE);
-	return soundlatch2_r(0);
+	memory_set_bank(5, data & 0x07);
 }
 
 
-static WRITE8_HANDLER( narc_command2_w )
+static WRITE8_HANDLER( adpcm_6295_bank_select_w )
 {
-	soundlatch2_w(0, data & 0xff);
-	cpunum_set_input_line(soundalt_cpunum, M6809_FIRQ_LINE, ASSERT_LINE);
+	OKIM6295_set_bank_base(0, (data & 7) * 0x40000);
+}
+
+
+static READ8_HANDLER( adpcm_command_r )
+{
+	cpunum_set_input_line(sound_cpunum, M6809_IRQ_LINE, CLEAR_LINE);
+	williams_sound_int_state = 0;
+	return soundlatch_r(0);
+}
+
+
+static WRITE8_HANDLER( adpcm_talkback_w )
+{
+	audio_talkback = data;
+	logerror("ADPCM Talkback = %02X\n", data);
+}
+
+
+
+/***************************************************************************
+    ADPCM COMMUNICATIONS
+****************************************************************************/
+
+void williams_adpcm_data_w(int data)
+{
+	soundlatch_w(0, data & 0xff);
+	if (!(data & 0x200))
+	{
+		cpunum_set_input_line(sound_cpunum, M6809_IRQ_LINE, ASSERT_LINE);
+		williams_sound_int_state = 1;
+	}
+}
+
+
+void williams_adpcm_reset_w(int state)
+{
+	/* going high halts the CPU */
+	if (state)
+	{
+		adpcm_bank_select_w(0, 0);
+		init_audio_state();
+		cpunum_set_input_line(sound_cpunum, INPUT_LINE_RESET, ASSERT_LINE);
+	}
+	/* going low resets and reactivates the CPU */
+	else
+		cpunum_set_input_line(sound_cpunum, INPUT_LINE_RESET, CLEAR_LINE);
 }
