@@ -1,8 +1,8 @@
 #include "blit.h"
 
-#define FUNC_NAME(name) name##_15_15_direct
-#define SRC_DEPTH  15
-#define DEST_DEPTH 15
+#define FUNC_NAME(name) name##_16_32
+#define SRC_DEPTH  16
+#define DEST_DEPTH 32
 #include "blit_defs.h"
 #include "blit_normal.h"
 #ifndef DISABLE_EFFECTS
@@ -12,5 +12,5 @@
 #include "advance/xq2x.h"
 #define HQ2X
 #include "advance/xq2x.h"
-#endif
 #include "blit_undefs.h"
+#endif
