@@ -7,7 +7,6 @@
 ***************************************************************************/
 
 #include "driver.h"
-#include "vidhrdw/generic.h"
 #include "vidhrdw/konamiic.h"
 #include "cpu/z80/z80.h"
 
@@ -15,7 +14,7 @@
 #define ZOOMROM0_MEM_REGION REGION_GFX2
 #define ZOOMROM1_MEM_REGION REGION_GFX3
 
-int sprite_colorbase,zoom_colorbase[2];
+static int sprite_colorbase,zoom_colorbase[2];
 
 /***************************************************************************
 
@@ -51,33 +50,24 @@ static void zoom_callback_1(int *code,int *color)
 
 /***************************************************************************
 
-	Start the video hardware emulation.
+    Start the video hardware emulation.
 
 ***************************************************************************/
 
-int chqflag_vh_start( void )
+VIDEO_START( chqflag )
 {
 	sprite_colorbase = 0;
 	zoom_colorbase[0] = 0x10;
 	zoom_colorbase[1] = 0x02;
 
 	if (K051960_vh_start(SPRITEROM_MEM_REGION,NORMAL_PLANE_ORDER,sprite_callback))
-	{
 		return 1;
-	}
 
 	if (K051316_vh_start_0(ZOOMROM0_MEM_REGION,4,TILEMAP_TRANSPARENT,0,zoom_callback_0))
-	{
-		K051960_vh_stop();
 		return 1;
-	}
 
 	if (K051316_vh_start_1(ZOOMROM1_MEM_REGION,8,TILEMAP_SPLIT_PENBIT,0xc0,zoom_callback_1))
-	{
-		K051960_vh_stop();
-		K051316_vh_stop_0();
 		return 1;
-	}
 
 	K051316_set_offset(0,7,0);
 	K051316_wraparound_enable(1,1);
@@ -85,26 +75,19 @@ int chqflag_vh_start( void )
 	return 0;
 }
 
-void chqflag_vh_stop( void )
-{
-	K051960_vh_stop();
-	K051316_vh_stop_0();
-	K051316_vh_stop_1();
-}
-
 /***************************************************************************
 
-	Display Refresh
+    Display Refresh
 
 ***************************************************************************/
 
-void chqflag_vh_screenrefresh( struct mame_bitmap *bitmap, int fullrefresh )
+VIDEO_UPDATE( chqflag )
 {
-	fillbitmap(bitmap,Machine->pens[0],&Machine->visible_area);
+	fillbitmap(bitmap,Machine->pens[0],cliprect);
 
-	K051316_zoom_draw_1(bitmap,TILEMAP_BACK,0);
-	K051960_sprites_draw(bitmap,0,0);
-	K051316_zoom_draw_1(bitmap,TILEMAP_FRONT,0);
-	K051960_sprites_draw(bitmap,1,1);
-	K051316_zoom_draw_0(bitmap,0,0);
+	K051316_zoom_draw_1(bitmap,cliprect,TILEMAP_BACK,0);
+	K051960_sprites_draw(bitmap,cliprect,0,0);
+	K051316_zoom_draw_1(bitmap,cliprect,TILEMAP_FRONT,0);
+	K051960_sprites_draw(bitmap,cliprect,1,1);
+	K051316_zoom_draw_0(bitmap,cliprect,0,0);
 }
