@@ -7,11 +7,12 @@
 ***************************************************************************/
 
 #include "driver.h"
-#include "vidhrdw/generic.h"
 
-static int spritectrl[3];
+static UINT8 spritectrl[3];
 
-int crbaloon_collision;
+INT8 crbaloon_collision;
+
+static tilemap *bg_tilemap;
 
 /***************************************************************************
 
@@ -25,7 +26,7 @@ int crbaloon_collision;
   bit 0 RED
 
 ***************************************************************************/
-void crbaloon_vh_convert_color_prom(unsigned char *palette, unsigned short *colortable,const unsigned char *color_prom)
+PALETTE_INIT( crbaloon )
 {
 	int i;
 	#define TOTAL_COLORS(gfxn) (Machine->gfx[gfxn]->total_colors * Machine->gfx[gfxn]->color_granularity)
@@ -34,17 +35,18 @@ void crbaloon_vh_convert_color_prom(unsigned char *palette, unsigned short *colo
 
 	for (i = 0;i < Machine->drv->total_colors;i++)
 	{
-		int intensity;
+		int intensity,r,g,b;
 
 
 		intensity = (~i & 0x08) ? 0xff : 0x55;
 
 		/* red component */
-		*(palette++) = intensity * ((~i >> 0) & 1);
+		r = intensity * ((~i >> 0) & 1);
 		/* green component */
-		*(palette++) = intensity * ((~i >> 1) & 1);
+		g = intensity * ((~i >> 1) & 1);
 		/* blue component */
-		*(palette++) = intensity * ((~i >> 2) & 1);
+		b = intensity * ((~i >> 2) & 1);
+		palette_set_color(i,r,g,b);
 	}
 
 	for (i = 0;i < TOTAL_COLORS(0);i += 2)
@@ -54,75 +56,74 @@ void crbaloon_vh_convert_color_prom(unsigned char *palette, unsigned short *colo
 	}
 }
 
+WRITE8_HANDLER( crbaloon_videoram_w )
+{
+	if (videoram[offset] != data)
+	{
+		videoram[offset] = data;
+		tilemap_mark_tile_dirty(bg_tilemap, offset);
+	}
+}
 
+WRITE8_HANDLER( crbaloon_colorram_w )
+{
+	if (colorram[offset] != data)
+	{
+		colorram[offset] = data;
+		tilemap_mark_tile_dirty(bg_tilemap, offset);
+	}
+}
 
-WRITE_HANDLER( crbaloon_spritectrl_w )
+WRITE8_HANDLER( crbaloon_spritectrl_w )
 {
 	spritectrl[offset] = data;
 }
 
-
-
-WRITE_HANDLER( crbaloon_flipscreen_w )
+WRITE8_HANDLER( crbaloon_flipscreen_w )
 {
-	flip_screen_set(data & 1);
+	if (flip_screen != (data & 0x01))
+	{
+		flip_screen_set(data & 0x01);
+		tilemap_mark_all_tiles_dirty(ALL_TILEMAPS);
+	}
 }
 
-/***************************************************************************
-
-  Draw the game screen in the given mame_bitmap.
-  Do NOT call osd_update_display() from this function, it will be called by
-  the main emulation engine.
-
- ***************************************************************************/
-
-void crbaloon_vh_screenrefresh(struct mame_bitmap *bitmap,int full_refresh)
+static void get_bg_tile_info(int tile_index)
 {
-	int offs,x,y;
-	int bx,by;
+	int code = videoram[tile_index];
+	int color = colorram[tile_index] & 0x0f;
 
+	SET_TILE_INFO(0, code, color, 0)
+}
 
-	if (full_refresh)
-		memset(dirtybuffer,1,videoram_size);
+VIDEO_START( crbaloon )
+{
+	bg_tilemap = tilemap_create(get_bg_tile_info, tilemap_scan_rows_flip_xy,
+		TILEMAP_OPAQUE, 8, 8, 32, 32);
 
+	if ( !bg_tilemap )
+		return 1;
 
-	/* for every character in the Video RAM, check if it has been modified */
-	/* since last time and update it accordingly. */
-	for (offs = videoram_size - 1;offs >= 0;offs--)
-	{
-		if (dirtybuffer[offs])
-		{
-			int sx,sy;
+	if ((tmpbitmap = auto_bitmap_alloc(Machine->drv->screen_width,Machine->drv->screen_height)) == 0)
+		return 1;
 
+	state_save_register_global_array(spritectrl);
+	state_save_register_global(crbaloon_collision);
 
-			dirtybuffer[offs] = 0;
+	return 0;
+}
 
-			sx = offs % 32;
-			sy = offs / 32;
-			if (!flip_screen)
-			{
-				sx = 31 - sx;
-				sy = 31 - sy;
-			}
+static void crbaloon_draw_sprites( mame_bitmap *bitmap )
+{
+	int x,y;
 
-			drawgfx(tmpbitmap,Machine->gfx[0],
-					videoram[offs],
-					colorram[offs] & 0x0f,
-					flip_screen,flip_screen,
-					8*sx,8*sy,
-					&Machine->visible_area,TRANSPARENCY_NONE,0);
-		}
-	}
-
-	/* copy the character mapped graphics */
-	copybitmap(bitmap,tmpbitmap,0,0,0,0,&Machine->visible_area,TRANSPARENCY_NONE,0);
-
-
-    /* Check Collision - Draw balloon in background colour, if no */
+	/* Check Collision - Draw balloon in background colour, if no */
     /* collision occured, bitmap will be same as tmpbitmap        */
 
-	bx = spritectrl[1];
-	by = spritectrl[2] - 32;
+	int bx = spritectrl[1];
+	int by = spritectrl[2] - 32;
+
+	tilemap_draw(tmpbitmap, 0, bg_tilemap, 0, 0);
 
 	if (flip_screen)
 	{
@@ -168,3 +169,9 @@ void crbaloon_vh_screenrefresh(struct mame_bitmap *bitmap,int full_refresh)
 			bx,by,
 			&Machine->visible_area,TRANSPARENCY_PEN,0);
 }
+
+VIDEO_UPDATE( crbaloon )
+{
+	tilemap_draw(bitmap, &Machine->visible_area, bg_tilemap, 0, 0);
+	crbaloon_draw_sprites(bitmap);
+}
