@@ -6,8 +6,9 @@
 
 ***************************************************************************/
 
-#include "vidhrdw/generic.h"
+#include "driver.h"
 #include "vidhrdw/s2636.h"
+#include "cpu/s2650/s2650.h"
 
 #define MAX_STARS        250
 #define STARS_COLOR_BASE 16
@@ -36,34 +37,33 @@ struct star
 static struct star stars[MAX_STARS];
 static int    total_stars;
 static int    scroll[8];
-static int    CollisionRegister=0;
 static int    stars_on=0;
 static int 	  character_mode=0;
 static int    character_page=0;
 static int    scroll_reg = 0;
 static int    stars_scroll=0;
 
-int  s2650_get_flag(void);
-
-unsigned char *dirty_character;
-unsigned char *character_1_ram;
-unsigned char *character_2_ram;
-unsigned char *character_3_ram;
+static unsigned char *dirty_character;
+static unsigned char *character_1_ram;
+static unsigned char *character_2_ram;
+static unsigned char *character_3_ram;
 unsigned char *bullet_ram;
 unsigned char *s2636_1_ram;
 unsigned char *s2636_2_ram;
 unsigned char *s2636_3_ram;
 
-struct mame_bitmap *s2636_1_bitmap;
-struct mame_bitmap *s2636_2_bitmap;
-struct mame_bitmap *s2636_3_bitmap;
-struct mame_bitmap *collision_bitmap;
-struct mame_bitmap *collision_background;
-struct mame_bitmap *scrolled_background;
+mame_bitmap *s2636_1_bitmap;
+mame_bitmap *s2636_2_bitmap;
+mame_bitmap *s2636_3_bitmap;
+mame_bitmap *collision_bitmap;
+mame_bitmap *collision_background;
+static mame_bitmap *scrolled_background;
 
-static unsigned char s2636_1_dirty[4];
-static unsigned char s2636_2_dirty[4];
-static unsigned char s2636_3_dirty[4];
+unsigned char s2636_1_dirty[4];
+unsigned char s2636_2_dirty[4];
+unsigned char s2636_3_dirty[4];
+
+int CollisionRegister=0;
 
 static int ModeOffset[4] = {223,191,255,127};
 
@@ -76,7 +76,7 @@ static int ModeOffset[4] = {223,191,255,127};
  * colours are taken from SRAM and are programmable   *
  ******************************************************/
 
-void cvs_vh_convert_color_prom(unsigned char *palette, unsigned short *colortable,const unsigned char *color_prom)
+PALETTE_INIT( cvs )
 {
 	int attr,col,map;
 
@@ -115,6 +115,10 @@ void cvs_vh_convert_color_prom(unsigned char *palette, unsigned short *colortabl
     }
 
     /* Initialise Dirty Character Array */
+	dirty_character = auto_malloc(0x100);
+	character_1_ram = auto_malloc(0x2000);
+	character_2_ram = character_1_ram + 0x800;
+	character_3_ram = character_2_ram + 0x800;
 
 	memset(dirty_character, 0, 256);
     memset(character_1_ram, 0, 1024);
@@ -133,7 +137,7 @@ void cvs_vh_convert_color_prom(unsigned char *palette, unsigned short *colortabl
     scroll[7]=0;
 }
 
-WRITE_HANDLER( cvs_video_fx_w )
+WRITE8_HANDLER( cvs_video_fx_w )
 {
 	logerror("%4x : Data Port = %2x\n",activecpu_get_pc(),data);
 
@@ -152,7 +156,7 @@ WRITE_HANDLER( cvs_video_fx_w )
     set_led_status(2,data & 32);	/* Lamp 2 */
 }
 
-READ_HANDLER( cvs_character_mode_r )
+READ8_HANDLER( cvs_character_mode_r )
 {
 	/* Really a write - uses address info */
 
@@ -170,18 +174,18 @@ READ_HANDLER( cvs_character_mode_r )
     return 0;
 }
 
-READ_HANDLER( cvs_collision_r )
+READ8_HANDLER( cvs_collision_r )
 {
 	return CollisionRegister;
 }
 
-READ_HANDLER( cvs_collision_clear )
+READ8_HANDLER( cvs_collision_clear )
 {
 	CollisionRegister=0;
     return 0;
 }
 
-WRITE_HANDLER( cvs_scroll_w )
+WRITE8_HANDLER( cvs_scroll_w )
 {
 	scroll_reg = 255 - data;
 
@@ -192,9 +196,9 @@ WRITE_HANDLER( cvs_scroll_w )
     scroll[5]=scroll_reg;
 }
 
-WRITE_HANDLER( cvs_videoram_w )
+WRITE8_HANDLER( cvs_videoram_w )
 {
-	if(!s2650_get_flag())
+	if(!activecpu_get_reg(S2650_FO))
     {
     	/* Colour Map */
 
@@ -208,9 +212,9 @@ WRITE_HANDLER( cvs_videoram_w )
     }
 }
 
-READ_HANDLER( cvs_videoram_r )
+READ8_HANDLER( cvs_videoram_r )
 {
-	if(!s2650_get_flag())
+	if(!activecpu_get_reg(S2650_FO))
     {
     	/* Colour Map */
 
@@ -224,9 +228,9 @@ READ_HANDLER( cvs_videoram_r )
     }
 }
 
-WRITE_HANDLER( cvs_bullet_w )
+WRITE8_HANDLER( cvs_bullet_w )
 {
-	if(!s2650_get_flag())
+	if(!activecpu_get_reg(S2650_FO))
     {
     	/* Bullet Ram */
 
@@ -235,14 +239,17 @@ WRITE_HANDLER( cvs_bullet_w )
     else
     {
     	/* Pallette Ram - Inverted ? */
+		offset &= 0x0f;
+		data ^= 0xff;
 
-		paletteram_BBBGGGRR_w((offset & 0x0f),(data ^ 0xff));
+		paletteram[offset] = data;
+		palette_set_color(offset, pal2bit(data >> 0), pal3bit(data >> 2), pal3bit(data >> 5));
     }
 }
 
-READ_HANDLER( cvs_bullet_r )
+READ8_HANDLER( cvs_bullet_r )
 {
-	if(!s2650_get_flag())
+	if(!activecpu_get_reg(S2650_FO))
     {
     	/* Bullet Ram */
 
@@ -256,9 +263,9 @@ READ_HANDLER( cvs_bullet_r )
     }
 }
 
-WRITE_HANDLER( cvs_2636_1_w )
+WRITE8_HANDLER( cvs_2636_1_w )
 {
-	if(!s2650_get_flag())
+	if(!activecpu_get_reg(S2650_FO))
     {
     	/* First 2636 */
 
@@ -276,9 +283,9 @@ WRITE_HANDLER( cvs_2636_1_w )
 	}
 }
 
-READ_HANDLER( cvs_2636_1_r )
+READ8_HANDLER( cvs_2636_1_r )
 {
-	if(!s2650_get_flag())
+	if(!activecpu_get_reg(S2650_FO))
     {
     	/* First 2636 */
 
@@ -292,9 +299,9 @@ READ_HANDLER( cvs_2636_1_r )
     }
 }
 
-WRITE_HANDLER( cvs_2636_2_w )
+WRITE8_HANDLER( cvs_2636_2_w )
 {
-	if(!s2650_get_flag())
+	if(!activecpu_get_reg(S2650_FO))
     {
     	/* Second 2636 */
 
@@ -312,9 +319,9 @@ WRITE_HANDLER( cvs_2636_2_w )
     }
 }
 
-READ_HANDLER( cvs_2636_2_r )
+READ8_HANDLER( cvs_2636_2_r )
 {
-	if(!s2650_get_flag())
+	if(!activecpu_get_reg(S2650_FO))
     {
     	/* Second 2636 */
 
@@ -328,9 +335,9 @@ READ_HANDLER( cvs_2636_2_r )
     }
 }
 
-WRITE_HANDLER( cvs_2636_3_w )
+WRITE8_HANDLER( cvs_2636_3_w )
 {
-	if(!s2650_get_flag())
+	if(!activecpu_get_reg(S2650_FO))
     {
     	/* Third 2636 */
 
@@ -348,9 +355,9 @@ WRITE_HANDLER( cvs_2636_3_w )
     }
 }
 
-READ_HANDLER( cvs_2636_3_r )
+READ8_HANDLER( cvs_2636_3_r )
 {
-	if(!s2650_get_flag())
+	if(!activecpu_get_reg(S2650_FO))
     {
     	/* Third 2636 */
 
@@ -364,12 +371,15 @@ READ_HANDLER( cvs_2636_3_r )
     }
 }
 
-int cvs_vh_start(void)
+VIDEO_START( cvs )
 {
 	int generator = 0;
     int x,y;
 
-	generic_vh_start();
+	colorram = auto_malloc(0x400);
+	paletteram = auto_malloc(0x100);
+
+	video_start_generic();
 
 	/* precalculate the star background */
 
@@ -406,90 +416,38 @@ int cvs_vh_start(void)
 
     /* Need 3 bitmaps for 2636 chips */
 
-	if ((s2636_1_bitmap = bitmap_alloc_depth(Machine->drv->screen_width,Machine->drv->screen_height,8)) == 0)
-	{
-		bitmap_free(tmpbitmap);
-		free(dirtybuffer);
+	if ((s2636_1_bitmap = auto_bitmap_alloc_depth(Machine->drv->screen_width,Machine->drv->screen_height,8)) == 0)
 		return 1;
-	}
 
-	if ((s2636_2_bitmap = bitmap_alloc_depth(Machine->drv->screen_width,Machine->drv->screen_height,8)) == 0)
-	{
-		bitmap_free(s2636_1_bitmap);
-		bitmap_free(tmpbitmap);
-		free(dirtybuffer);
+	if ((s2636_2_bitmap = auto_bitmap_alloc_depth(Machine->drv->screen_width,Machine->drv->screen_height,8)) == 0)
 		return 1;
-	}
 
-	if ((s2636_3_bitmap = bitmap_alloc_depth(Machine->drv->screen_width,Machine->drv->screen_height,8)) == 0)
-	{
-		bitmap_free(s2636_1_bitmap);
-		bitmap_free(s2636_2_bitmap);
-		bitmap_free(tmpbitmap);
-		free(dirtybuffer);
+	if ((s2636_3_bitmap = auto_bitmap_alloc_depth(Machine->drv->screen_width,Machine->drv->screen_height,8)) == 0)
 		return 1;
-	}
 
     /* 3 bitmaps for collision detection */
 
-	if ((collision_bitmap = bitmap_alloc_depth(Machine->drv->screen_width,Machine->drv->screen_height,8)) == 0)
-	{
-		bitmap_free(s2636_1_bitmap);
-		bitmap_free(s2636_2_bitmap);
-		bitmap_free(s2636_3_bitmap);
-		bitmap_free(tmpbitmap);
-		free(dirtybuffer);
+	if ((collision_bitmap = auto_bitmap_alloc_depth(Machine->drv->screen_width,Machine->drv->screen_height,8)) == 0)
 		return 1;
-	}
 
-	if ((collision_background = bitmap_alloc_depth(Machine->drv->screen_width,Machine->drv->screen_height,8)) == 0)
-	{
-    	bitmap_free(collision_bitmap);
-		bitmap_free(s2636_1_bitmap);
-		bitmap_free(s2636_2_bitmap);
-		bitmap_free(s2636_3_bitmap);
-		bitmap_free(tmpbitmap);
-		free(dirtybuffer);
+	if ((collision_background = auto_bitmap_alloc_depth(Machine->drv->screen_width,Machine->drv->screen_height,8)) == 0)
 		return 1;
-	}
 
-	if ((scrolled_background = bitmap_alloc_depth(Machine->drv->screen_width,Machine->drv->screen_height,8)) == 0)
-	{
-    	bitmap_free(collision_background);
-    	bitmap_free(collision_bitmap);
-		bitmap_free(s2636_1_bitmap);
-		bitmap_free(s2636_2_bitmap);
-		bitmap_free(s2636_3_bitmap);
-		bitmap_free(tmpbitmap);
-		free(dirtybuffer);
+	if ((scrolled_background = auto_bitmap_alloc_depth(Machine->drv->screen_width,Machine->drv->screen_height,8)) == 0)
 		return 1;
-	}
 
 	return 0;
 }
 
-void cvs_vh_stop(void)
-{
-	generic_vh_stop();
-	bitmap_free(s2636_1_bitmap);
-	bitmap_free(s2636_2_bitmap);
-	bitmap_free(s2636_3_bitmap);
-	bitmap_free(collision_bitmap);
-	bitmap_free(collision_background);
-    bitmap_free(scrolled_background);
-}
-
-int cvs_interrupt(void)
+INTERRUPT_GEN( cvs_interrupt )
 {
 	stars_scroll++;
 
-	cpu_irq_line_vector_w(0,0,0x03);
-	cpu_set_irq_line(0,0,PULSE_LINE);
-
-	return ignore_interrupt();
+	cpunum_set_input_line_vector(0,0,0x03);
+	cpunum_set_input_line(0,0,PULSE_LINE);
 }
 
-INLINE void plot_star(struct mame_bitmap *bitmap, int x, int y)
+INLINE void plot_star(mame_bitmap *bitmap, int x, int y)
 {
 	if (flip_screen_x)
 	{
@@ -506,11 +464,14 @@ INLINE void plot_star(struct mame_bitmap *bitmap, int x, int y)
 	}
 }
 
-void cvs_vh_screenrefresh(struct mame_bitmap *bitmap,int full_refresh)
+VIDEO_UPDATE( cvs )
 {
 	int offs,character;
 	int sx,sy;
 
+	if (get_vh_global_attribute_changed())
+		memset(dirtybuffer, 1, videoram_size);
+
 	/* for every character in the Video RAM, check if it has been modified */
 	/* since last time and update it accordingly. */
 
@@ -518,7 +479,7 @@ void cvs_vh_screenrefresh(struct mame_bitmap *bitmap,int full_refresh)
 	{
         character = videoram[offs];
 
-		if(dirtybuffer[offs] || full_refresh || dirty_character[character])
+		if(dirtybuffer[offs] || dirty_character[character])
 		{
             int character_bank;
             int forecolor;
