@@ -19,20 +19,20 @@ unsigned char *system1_scrollx_ram;
 size_t system1_videoram_size;
 size_t system1_backgroundram_size;
 
-static unsigned char *sprite_onscreen_map;
+static UINT8 *sprite_onscreen_map;
 static int background_scrollx=0,background_scrolly=0;
-static unsigned char *bg_dirtybuffer;
+static UINT8 *bg_dirtybuffer;
 
 static int scrollx_row[32];
 static mame_bitmap *tmp_bitmap;
 
 /*static int system1_pixel_mode = 0 */
-static int system1_background_memory,system1_video_mode=0;
+static UINT8 system1_background_memory,system1_video_mode=0;
 
 static const unsigned char *system1_color_prom;
 
-static unsigned char *wbml_paged_videoram;
-static unsigned char wbml_videoram_bank=0,wbml_videoram_bank_latch=0;
+static UINT8 *wbml_paged_videoram;
+static UINT8 wbml_videoram_bank=0,wbml_videoram_bank_latch=0;
 
 static int blockgal_kludgeoffset;
 
@@ -111,13 +111,35 @@ WRITE8_HANDLER( system1_paletteram_w )
 	palette_set_color(offset,r,g,b);
 }
 
-
+void system1_postload(void)
+{
+	memset(sprite_onscreen_map, 255, 256*256);
+	memset(bg_dirtybuffer, 1, 1024);
+}
 
 VIDEO_START( system1 )
 {
 	sprite_onscreen_map = auto_malloc(256*256);
 	memset(sprite_onscreen_map,255,256*256);
 
+	bg_dirtybuffer = auto_malloc(1024);
+	memset(bg_dirtybuffer,1,1024);
+
+	if ((tmp_bitmap = auto_bitmap_alloc(Machine->drv->screen_width,Machine->drv->screen_height)) == 0)
+		return 1;
+
+	state_save_register_func_postload(system1_postload);
+	state_save_register_global(system1_background_memory);
+	state_save_register_global(system1_video_mode);
+
+	return 0;
+}
+
+VIDEO_START( wbml )
+{
+	sprite_onscreen_map = auto_malloc(256*256);
+	memset(sprite_onscreen_map,255,256*256);
+
 	bg_dirtybuffer = auto_malloc(1024);
 	memset(bg_dirtybuffer,1,1024);
 	wbml_paged_videoram = auto_malloc(0x4000);	/* Allocate 16k for background banked ram */
@@ -126,6 +148,14 @@ VIDEO_START( system1 )
 	if ((tmp_bitmap = auto_bitmap_alloc(Machine->drv->screen_width,Machine->drv->screen_height)) == 0)
 		return 1;
 
+	state_save_register_func_postload(system1_postload);
+	state_save_register_global(system1_background_memory);
+	state_save_register_global(system1_video_mode);
+
+	state_save_register_global_pointer(wbml_paged_videoram, 0x4000);
+	state_save_register_global(wbml_videoram_bank);
+	state_save_register_global(wbml_videoram_bank_latch);
+
 	return 0;
 }
 
