@@ -204,9 +204,7 @@ Playfield tile info:
 ***************************************************************************/
 
 #include "driver.h"
-#include "vidhrdw/generic.h"
 #include "taito_f3.h"
-#include "state.h"
 
 #define DARIUSG_KLUDGE
 /*#define DEBUG_F3 1 */
@@ -229,7 +227,7 @@ UINT32 *f3_pf_data,*f3_pivot_ram;
 
 extern int f3_game;
 
-static int skip_this_frame;
+static int f3_skip_this_frame;
 
 /* Game specific data, some of this can be
 removed when the software values are figured out */
@@ -528,7 +526,7 @@ VIDEO_EOF( f3 )
 {
 	if (sprite_lag==2)
 	{
-		if (osd_skip_this_frame() == 0)
+		if (skip_this_frame() == 0)
 		{
 			get_sprite_info(spriteram32_buffered);
 		}
@@ -536,7 +534,7 @@ VIDEO_EOF( f3 )
 	}
 	else if (sprite_lag==1)
 	{
-		if (osd_skip_this_frame() == 0)
+		if (skip_this_frame() == 0)
 		{
 			get_sprite_info(spriteram32);
 		}
@@ -628,15 +626,15 @@ VIDEO_START( f3 )
 	memset(spriteram32_buffered,0,spriteram_size);
 	memset(spriteram32,0,spriteram_size);
 
-	state_save_register_UINT32("f3", 0, "vcontrol0", f3_control_0, 8);
-	state_save_register_UINT32("f3", 0, "vcontrol1", f3_control_1, 8);
+	state_save_register_global_array(f3_control_0);
+	state_save_register_global_array(f3_control_1);
 
 	for (tile = 0;tile < 256;tile++)
 		vram_dirty[tile]=1;
 	for (tile = 0;tile < 2048;tile++)
 		pivot_dirty[tile]=1;
 
-	skip_this_frame=0;
+	f3_skip_this_frame=0;
 
 	sprite_lag=f3_game_config->sprite_lag;
 
@@ -760,10 +758,10 @@ WRITE32_HANDLER( f3_lineram_w )
     the trashing of priority ram.  If anyone has information on what the real machine does,
     please let me know! */
 	if (f3_game==DARIUSG) {
-		if (skip_this_frame)
+		if (f3_skip_this_frame)
 			return;
 		if (offset==0xb000/4 && data==0x003f0000) {
-			skip_this_frame=1;
+			f3_skip_this_frame=1;
 			return;
 		}
 	}
@@ -3246,7 +3244,7 @@ VIDEO_UPDATE( f3 )
 	unsigned int sy_fix[5],sx_fix[5];
 	int tile;
 
-	skip_this_frame=0;
+	f3_skip_this_frame=0;
 	tilemap_set_flip(ALL_TILEMAPS,flipscreen ? (TILEMAP_FLIPY | TILEMAP_FLIPX) : 0);
 
 	/* Dynamically decode VRAM chars if dirty */
