@@ -9,15 +9,12 @@
 #include "driver.h"
 
 
-unsigned char *xevious_fg_videoram,*xevious_fg_colorram;
-unsigned char *xevious_bg_videoram,*xevious_bg_colorram;
-
-extern unsigned char *spriteram,*spriteram_2,*spriteram_3;
-extern size_t spriteram_size;
-
-static struct tilemap *fg_tilemap,*bg_tilemap;
-
+UINT8 *xevious_fg_videoram,*xevious_fg_colorram;
+UINT8 *xevious_bg_videoram,*xevious_bg_colorram;
+UINT8 *xevious_sr1,*xevious_sr2,*xevious_sr3;
 
+static tilemap *fg_tilemap,*bg_tilemap;
+static INT32 xevious_bs[2];
 
 /***************************************************************************
 
@@ -29,12 +26,12 @@ static struct tilemap *fg_tilemap,*bg_tilemap;
   The palette PROMs are connected to the RGB output this way:
 
   bit 3 -- 220 ohm resistor  -- RED/GREEN/BLUE
-		-- 470 ohm resistor  -- RED/GREEN/BLUE
-		-- 1  kohm resistor  -- RED/GREEN/BLUE
+        -- 470 ohm resistor  -- RED/GREEN/BLUE
+        -- 1  kohm resistor  -- RED/GREEN/BLUE
   bit 0 -- 2.2kohm resistor  -- RED/GREEN/BLUE
 
 ***************************************************************************/
-void xevious_vh_convert_color_prom(unsigned char *palette, unsigned short *colortable,const unsigned char *color_prom)
+PALETTE_INIT( xevious )
 {
 	int i;
 	#define TOTAL_COLORS(gfxn) (Machine->gfx[gfxn]->total_colors * Machine->gfx[gfxn]->color_granularity)
@@ -43,7 +40,7 @@ void xevious_vh_convert_color_prom(unsigned char *palette, unsigned short *color
 
 	for (i = 0;i < 128;i++)
 	{
-		int bit0,bit1,bit2,bit3;
+		int bit0,bit1,bit2,bit3,r,g,b;
 
 
 		/* red component */
@@ -51,27 +48,26 @@ void xevious_vh_convert_color_prom(unsigned char *palette, unsigned short *color
 		bit1 = (color_prom[0] >> 1) & 0x01;
 		bit2 = (color_prom[0] >> 2) & 0x01;
 		bit3 = (color_prom[0] >> 3) & 0x01;
-		*(palette++) = 0x0e * bit0 + 0x1f * bit1 + 0x43 * bit2 + 0x8f * bit3;
+		r = 0x0e * bit0 + 0x1f * bit1 + 0x43 * bit2 + 0x8f * bit3;
 		/* green component */
 		bit0 = (color_prom[256] >> 0) & 0x01;
 		bit1 = (color_prom[256] >> 1) & 0x01;
 		bit2 = (color_prom[256] >> 2) & 0x01;
 		bit3 = (color_prom[256] >> 3) & 0x01;
-		*(palette++) = 0x0e * bit0 + 0x1f * bit1 + 0x43 * bit2 + 0x8f * bit3;
+		g = 0x0e * bit0 + 0x1f * bit1 + 0x43 * bit2 + 0x8f * bit3;
 		/* blue component */
 		bit0 = (color_prom[2*256] >> 0) & 0x01;
 		bit1 = (color_prom[2*256] >> 1) & 0x01;
 		bit2 = (color_prom[2*256] >> 2) & 0x01;
 		bit3 = (color_prom[2*256] >> 3) & 0x01;
-		*(palette++) = 0x0e * bit0 + 0x1f * bit1 + 0x43 * bit2 + 0x8f * bit3;
+		b = 0x0e * bit0 + 0x1f * bit1 + 0x43 * bit2 + 0x8f * bit3;
 
+		palette_set_color(i,r,g,b);
 		color_prom++;
 	}
 
 	/* color 0x80 is used by sprites to mark transparency */
-	*(palette++) = 0;
-	*(palette++) = 0;
-	*(palette++) = 0;
+	palette_set_color(0x80,0,0,0);
 
 	color_prom += 128;  /* the bottom part of the PROM is unused */
 	color_prom += 2*256;
@@ -108,6 +104,78 @@ void xevious_vh_convert_color_prom(unsigned char *palette, unsigned short *color
 
 
 
+PALETTE_INIT( battles )
+{
+	int i;
+	#define TOTAL_COLORS(gfxn) (Machine->gfx[gfxn]->total_colors * Machine->gfx[gfxn]->color_granularity)
+	#define COLOR(gfxn,offs) (colortable[Machine->drv->gfxdecodeinfo[gfxn].color_codes_start + offs])
+
+
+	for (i = 0;i < 128;i++)
+	{
+		int bit0,bit1,bit2,bit3,r,g,b;
+
+
+		/* red component */
+		bit0 = (color_prom[0] >> 0) & 0x01;
+		bit1 = (color_prom[0] >> 1) & 0x01;
+		bit2 = (color_prom[0] >> 2) & 0x01;
+		bit3 = (color_prom[0] >> 3) & 0x01;
+		r = 0x0e * bit0 + 0x1f * bit1 + 0x43 * bit2 + 0x8f * bit3;
+		/* green component */
+		bit0 = (color_prom[256] >> 0) & 0x01;
+		bit1 = (color_prom[256] >> 1) & 0x01;
+		bit2 = (color_prom[256] >> 2) & 0x01;
+		bit3 = (color_prom[256] >> 3) & 0x01;
+		g = 0x0e * bit0 + 0x1f * bit1 + 0x43 * bit2 + 0x8f * bit3;
+		/* blue component */
+		bit0 = (color_prom[2*256] >> 0) & 0x01;
+		bit1 = (color_prom[2*256] >> 1) & 0x01;
+		bit2 = (color_prom[2*256] >> 2) & 0x01;
+		bit3 = (color_prom[2*256] >> 3) & 0x01;
+		b = 0x0e * bit0 + 0x1f * bit1 + 0x43 * bit2 + 0x8f * bit3;
+
+		palette_set_color(i,r,g,b);
+		color_prom++;
+	}
+
+	/* color 0x80 is used by sprites to mark transparency */
+	palette_set_color(0x80,0,0,0);
+
+	color_prom += 128;  /* the bottom part of the PROM is unused */
+	color_prom += 2*256;
+	/* color_prom now points to the beginning of the lookup table */
+
+	/* background tiles */
+	for (i = 0;i < TOTAL_COLORS(1);i++)
+	{
+		COLOR(1,i) = (color_prom[0] & 0x0f) | ((color_prom[0x400] & 0x0f) << 4);
+
+		color_prom++;
+	}
+	color_prom += 0x600;
+
+	/* sprites */
+	for (i = 0;i < TOTAL_COLORS(2);i++)
+	{
+		int c = (color_prom[0] & 0x0f) | ((color_prom[0x400] & 0x0f) << 4);
+
+		if (c & 0x80) COLOR(2,i) = c & 0x7f;
+		else COLOR(2,i) = 0x80; /* transparent */
+
+		color_prom++;
+	}
+
+	/* foreground characters */
+	for (i = 0;i < TOTAL_COLORS(0);i++)
+	{
+		if (i % 2 == 0) COLOR(0,i) = 0x80;  /* transparent */
+		else COLOR(0,i) = i / 2;
+	}
+}
+
+
+
 /***************************************************************************
 
   Callbacks for the TileMap code
@@ -117,11 +185,17 @@ void xevious_vh_convert_color_prom(unsigned char *palette, unsigned short *color
 static void get_fg_tile_info(int tile_index)
 {
 	unsigned char attr = xevious_fg_colorram[tile_index];
+
+	/* the hardware has two character sets, one normal and one x-flipped. When
+       screen is flipped, character y flip is done by the hardware inverting the
+       timing signals, while x flip is done by selecting the 2nd character set.
+       We reproduce this here, but since the tilemap system automatically flips
+       characters when screen is flipped, we have to flip them back. */
 	SET_TILE_INFO(
 			0,
-			xevious_fg_videoram[tile_index],
+			xevious_fg_videoram[tile_index] | (flip_screen ? 0x100 : 0),
 			((attr & 0x03) << 4) | ((attr & 0x3c) >> 2),
-			TILE_FLIPYX((attr & 0xc0) >> 6))
+			TILE_FLIPYX((attr & 0xc0) >> 6) ^ (flip_screen ? TILE_FLIPX : 0))
 }
 
 static void get_bg_tile_info(int tile_index)
@@ -143,7 +217,7 @@ static void get_bg_tile_info(int tile_index)
 
 ***************************************************************************/
 
-int xevious_vh_start(void)
+VIDEO_START( xevious )
 {
 	bg_tilemap = tilemap_create(get_bg_tile_info,tilemap_scan_rows,TILEMAP_OPAQUE,     8,8,64,32);
 	fg_tilemap = tilemap_create(get_fg_tile_info,tilemap_scan_rows,TILEMAP_TRANSPARENT,8,8,64,32);
@@ -151,10 +225,18 @@ int xevious_vh_start(void)
 	if (!bg_tilemap || !fg_tilemap)
 		return 1;
 
-	tilemap_set_scrolldx(fg_tilemap,0,-160);
-	tilemap_set_scrolldy(fg_tilemap,0,8);
+	tilemap_set_scrolldx(bg_tilemap,-20,288+27);
+	tilemap_set_scrolldy(bg_tilemap,-16,-16);
+	tilemap_set_scrolldx(fg_tilemap,-32,288+32);
+	tilemap_set_scrolldy(fg_tilemap,-18,-10);
 	tilemap_set_transparent_pen(fg_tilemap,0);
 
+	spriteram_2 = xevious_sr1 + 0x780;
+	spriteram_3 = xevious_sr2 + 0x780;
+	spriteram   = xevious_sr3 + 0x780;
+
+	state_save_register_global_array(xevious_bs);
+
 	return 0;
 }
 
@@ -166,7 +248,27 @@ int xevious_vh_start(void)
 
 ***************************************************************************/
 
-WRITE_HANDLER( xevious_fg_videoram_w )
+READ8_HANDLER( xevious_fg_videoram_r )
+{
+	return xevious_fg_videoram[offset];
+}
+
+READ8_HANDLER( xevious_fg_colorram_r )
+{
+	return xevious_fg_colorram[offset];
+}
+
+READ8_HANDLER( xevious_bg_videoram_r )
+{
+	return xevious_bg_videoram[offset];
+}
+
+READ8_HANDLER( xevious_bg_colorram_r )
+{
+	return xevious_bg_colorram[offset];
+}
+
+WRITE8_HANDLER( xevious_fg_videoram_w )
 {
 	if (xevious_fg_videoram[offset] != data)
 	{
@@ -175,7 +277,7 @@ WRITE_HANDLER( xevious_fg_videoram_w )
 	}
 }
 
-WRITE_HANDLER( xevious_fg_colorram_w )
+WRITE8_HANDLER( xevious_fg_colorram_w )
 {
 	if (xevious_fg_colorram[offset] != data)
 	{
@@ -184,7 +286,7 @@ WRITE_HANDLER( xevious_fg_colorram_w )
 	}
 }
 
-WRITE_HANDLER( xevious_bg_videoram_w )
+WRITE8_HANDLER( xevious_bg_videoram_w )
 {
 	if (xevious_bg_videoram[offset] != data)
 	{
@@ -193,7 +295,7 @@ WRITE_HANDLER( xevious_bg_videoram_w )
 	}
 }
 
-WRITE_HANDLER( xevious_bg_colorram_w )
+WRITE8_HANDLER( xevious_bg_colorram_w )
 {
 	if (xevious_bg_colorram[offset] != data)
 	{
@@ -202,7 +304,7 @@ WRITE_HANDLER( xevious_bg_colorram_w )
 	}
 }
 
-WRITE_HANDLER( xevious_vh_latch_w )
+WRITE8_HANDLER( xevious_vh_latch_w )
 {
 	int reg;
 	int scroll = data + ((offset&0x01)<<8);   /* A0 -> D8 */
@@ -212,19 +314,16 @@ WRITE_HANDLER( xevious_vh_latch_w )
 	switch (reg)
 	{
 	case 0:
-		if (flip_screen)
-			tilemap_set_scrollx(bg_tilemap,0,scroll-312);
-		else
-			tilemap_set_scrollx(bg_tilemap,0,scroll+20);
+		tilemap_set_scrollx(bg_tilemap,0,scroll);
 		break;
 	case 1:
-		tilemap_set_scrollx(fg_tilemap,0,scroll+32);
+		tilemap_set_scrollx(fg_tilemap,0,scroll);
 		break;
 	case 2:
-		tilemap_set_scrolly(bg_tilemap,0,scroll+16);
+		tilemap_set_scrolly(bg_tilemap,0,scroll);
 		break;
 	case 3:
-		tilemap_set_scrolly(fg_tilemap,0,scroll+18);
+		tilemap_set_scrolly(fg_tilemap,0,scroll);
 		break;
 	case 7:
 		flip_screen_set(scroll & 1);
@@ -236,6 +335,55 @@ WRITE_HANDLER( xevious_vh_latch_w )
 }
 
 
+/* emulation for schematic 9B */
+WRITE8_HANDLER( xevious_bs_w )
+{
+	xevious_bs[offset & 1] = data;
+}
+
+READ8_HANDLER( xevious_bb_r )
+{
+	UINT8 *rom2a = memory_region(REGION_GFX4);
+	UINT8 *rom2b = memory_region(REGION_GFX4)+0x1000;
+	UINT8 *rom2c = memory_region(REGION_GFX4)+0x3000;
+	int adr_2b,adr_2c;
+	int dat1,dat2;
+
+	/* get BS to 12 bit data from 2A,2B */
+	adr_2b = ((xevious_bs[1] & 0x7e) << 6) | ((xevious_bs[0] & 0xfe) >> 1);
+
+	if (adr_2b & 1)
+	{
+		/* high bits select */
+		dat1 = ((rom2a[adr_2b >> 1] & 0xf0) << 4) | rom2b[adr_2b];
+	}
+	else
+	{
+	    /* low bits select */
+	    dat1 = ((rom2a[adr_2b >> 1] & 0x0f) << 8) | rom2b[adr_2b];
+	}
+
+	adr_2c = ((dat1 & 0x1ff) << 2) | ((xevious_bs[1] & 1) << 1) | (xevious_bs[0] & 1);
+	if (dat1 & 0x400) adr_2c ^= 1;
+	if (dat1 & 0x200) adr_2c ^= 2;
+
+	if (offset & 1)
+	{
+		/* return BB1 */
+		dat2 = rom2c[adr_2c | 0x800];
+	}
+	else
+	{
+		/* return BB0 */
+		dat2 = rom2c[adr_2c];
+		/* swap bit 6 & 7 */
+		dat2 = BITSWAP8(dat2, 6,7,5,4,3,2,1,0);
+		/* flip x & y */
+		if (dat1 & 0x400) dat2 ^= 0x40;
+		if (dat1 & 0x200) dat2 ^= 0x80;
+	}
+	return dat2;
+}
 
 
 /*
@@ -243,44 +391,42 @@ background pattern data
 
 colorram mapping
 b000-bfff background attribute
-		  bit 0-1 COL:palette set select
-		  bit 2-5 AN :color select
-		  bit 6   AFF:Y flip
-		  bit 7   PFF:X flip
+          bit 0-1 COL:palette set select
+          bit 2-5 AN :color select
+          bit 6   AFF:Y flip
+          bit 7   PFF:X flip
 c000-cfff background pattern name
-		  bit 0-7 PP0-7
+          bit 0-7 PP0-7
 
 seet 8A
-										2	  +-------+
-COL0,1 --------------------------------------->|backg. |
-										1	  |color  |
-PP7------------------------------------------->|replace|
-										4	  | ROM   |  6
-AN0-3 ---------------------------------------->|  4H   |-----> color code 6 bit
-		1  +-----------+	  +--------+	   |  4F   |
-COL0  ---->|B8   ROM 3C| 16   |custom  |  2	|	   |
-		8  |		   |----->|shifter |------>|	   |
-PP0-7 ---->|B0-7 ROM 3D|	  |16->2*8 |	   |	   |
-		   +-----------+	  +--------+	   +-------+
+                                        2     +-------+
+COL0,1 -------------------------------------->|backg. |
+                                        1     |color  |
+PP7------------------------------------------>|replace|
+                                        4     | ROM   |  6
+AN0-3 --------------------------------------->|  4H   |-----> color code 6 bit
+        1  +-----------+      +--------+      |  4F   |
+COL0  ---->|B8   ROM 3C| 16   |custom  |  2   |       |
+        8  |           |----->|shifter |----->|       |
+PP0-7 ---->|B0-7 ROM 3D|      |16->2*8 |      |       |
+           +-----------+      +--------+      +-------+
 
 font rom controller
-	   1  +--------+	 +--------+
-ANF   --->| ROM	|  8  |shift   |  1
-	   8  | 3B	 |---->|reg	 |-----> font data
-PP0-7 --->|		|	 |8->1*8  |
-		  +--------+	 +--------+
+       1  +-----+     +--------+
+ANF   --->| ROM |  8  |shift   |  1
+       8  | 3B  |---->|reg     |-----> font data
+PP0-7 --->|     |     |8->1*8  |
+          +-----+     +--------+
 
 font color ( not use color map )
-		2  |
+        2  |
 COL0-1 --->|  color code 6 bit
-		4  |
+        4  |
 AN0-3  --->|
 
 sprite
 
-ROM 3M,3L color reprace table for sprite
-
-
+ROM 3M,3L color replace table for sprite
 
 */
 
@@ -293,12 +439,12 @@ ROM 3M,3L color reprace table for sprite
 
 ***************************************************************************/
 
-static void draw_sprites(struct mame_bitmap *bitmap)
+static void draw_sprites(mame_bitmap *bitmap,const rectangle *cliprect)
 {
 	int offs,sx,sy;
 
 
-	for (offs = 0;offs < spriteram_size;offs += 2)
+	for (offs = 0;offs < 0x80;offs += 2)
 	{
 		if ((spriteram[offs + 1] & 0x40) == 0)  /* I'm not sure about this one */
 		{
@@ -307,13 +453,13 @@ static void draw_sprites(struct mame_bitmap *bitmap)
 
 			if (spriteram_3[offs] & 0x80)
 			{
-				bank = 4;
-				code = spriteram[offs] & 0x3f;
+				bank = 2;
+				code = (spriteram[offs] & 0x3f) + 0x100;
 			}
 			else
 			{
-				bank = 2 + ((spriteram[offs] & 0x80) >> 7);
-				code = spriteram[offs] & 0x7f;
+				bank = 2;
+				code = spriteram[offs];
 			}
 
 			color = spriteram[offs + 1] & 0x7f;
@@ -330,52 +476,52 @@ static void draw_sprites(struct mame_bitmap *bitmap)
 			{
 				if (spriteram_3[offs] & 1)  /* double width, double height */
 				{
-					code &= 0x7c;
+					code &= ~3;
 					drawgfx(bitmap,Machine->gfx[bank],
 							code+3,color,flipx,flipy,
 							flipx ? sx : sx+16,flipy ? sy-16 : sy,
-							&Machine->visible_area,TRANSPARENCY_COLOR,0x80);
+							cliprect,TRANSPARENCY_COLOR,0x80);
 					drawgfx(bitmap,Machine->gfx[bank],
 							code+1,color,flipx,flipy,
 							flipx ? sx : sx+16,flipy ? sy : sy-16,
-							&Machine->visible_area,TRANSPARENCY_COLOR,0x80);
+							cliprect,TRANSPARENCY_COLOR,0x80);
 				}
-				code &= 0x7d;
+				code &= ~2;
 				drawgfx(bitmap,Machine->gfx[bank],
 						code+2,color,flipx,flipy,
 						flipx ? sx+16 : sx,flipy ? sy-16 : sy,
-						&Machine->visible_area,TRANSPARENCY_COLOR,0x80);
+						cliprect,TRANSPARENCY_COLOR,0x80);
 				drawgfx(bitmap,Machine->gfx[bank],
 						code,color,flipx,flipy,
 						flipx ? sx+16 : sx,flipy ? sy : sy-16,
-						&Machine->visible_area,TRANSPARENCY_COLOR,0x80);
+						cliprect,TRANSPARENCY_COLOR,0x80);
 			}
 			else if (spriteram_3[offs] & 1) /* double width */
 			{
-				code &= 0x7e;
+				code &= ~1;
 				drawgfx(bitmap,Machine->gfx[bank],
 						code,color,flipx,flipy,
 						flipx ? sx+16 : sx,flipy ? sy-16 : sy,
-						&Machine->visible_area,TRANSPARENCY_COLOR,0x80);
+						cliprect,TRANSPARENCY_COLOR,0x80);
 				drawgfx(bitmap,Machine->gfx[bank],
 						code+1,color,flipx,flipy,
 						flipx ? sx : sx+16,flipy ? sy-16 : sy,
-						&Machine->visible_area,TRANSPARENCY_COLOR,0x80);
+						cliprect,TRANSPARENCY_COLOR,0x80);
 			}
 			else	/* normal */
 			{
 				drawgfx(bitmap,Machine->gfx[bank],
 						code,color,flipx,flipy,sx,sy,
-						&Machine->visible_area,TRANSPARENCY_COLOR,0x80);
+						cliprect,TRANSPARENCY_COLOR,0x80);
 			}
 		}
 	}
 }
 
 
-void xevious_vh_screenrefresh(struct mame_bitmap *bitmap,int full_refresh)
+VIDEO_UPDATE( xevious )
 {
-	tilemap_draw(bitmap,bg_tilemap,0,0);
-	draw_sprites(bitmap);
-	tilemap_draw(bitmap,fg_tilemap,0,0);
+	tilemap_draw(bitmap,cliprect,bg_tilemap,0,0);
+	draw_sprites(bitmap,cliprect);
+	tilemap_draw(bitmap,cliprect,fg_tilemap,0,0);
 }
