@@ -14,10 +14,12 @@
 #ifndef __X86DRC_H__
 #define __X86DRC_H__
 
+#include "mamecore.h"
 
-/*###################################################################################################
-**  TYPE DEFINITIONS
-**#################################################################################################*/
+
+/***************************************************************************
+    TYPE DEFINITIONS
+***************************************************************************/
 
 /* PC and pointer pair */
 struct _pc_ptr_pair
@@ -107,9 +109,9 @@ typedef struct _link_info link_info;
 
 
 
-/*###################################################################################################
-**  HELPER MACROS
-**#################################################################################################*/
+/***************************************************************************
+    HELPER MACROS
+***************************************************************************/
 
 /* useful macros for accessing hi/lo portions of 64-bit values */
 #define LO(x)		(&(((UINT32 *)(UINT32)(x))[0]))
@@ -118,9 +120,9 @@ typedef struct _link_info link_info;
 extern const UINT8 scale_lookup[];
 
 
-/*###################################################################################################
-**  CONSTANTS
-**#################################################################################################*/
+/***************************************************************************
+    CONSTANTS
+***************************************************************************/
 
 /* architectural defines */
 #define REG_EAX		0
@@ -208,9 +210,9 @@ extern const UINT8 scale_lookup[];
 
 
 
-/*###################################################################################################
-**  LOW-LEVEL OPCODE EMITTERS
-**#################################################################################################*/
+/***************************************************************************
+    LOW-LEVEL OPCODE EMITTERS
+***************************************************************************/
 
 /* lowest-level opcode emitters */
 #define OP1(x)		do { *drc->cache_top++ = (UINT8)(x); } while (0)
@@ -219,9 +221,9 @@ extern const UINT8 scale_lookup[];
 
 
 
-/*###################################################################################################
-**  MODRM EMITTERS
-**#################################################################################################*/
+/***************************************************************************
+    MODRM EMITTERS
+***************************************************************************/
 
 /* op  reg,reg */
 #define MODRM_REG(reg, rm) 		\
@@ -295,9 +297,9 @@ do {														\
 
 
 
-/*###################################################################################################
-**  SIMPLE OPCODE EMITTERS
-**#################################################################################################*/
+/***************************************************************************
+    SIMPLE OPCODE EMITTERS
+***************************************************************************/
 
 #define _pushad() \
 do { OP1(0x60); } while (0)
@@ -352,9 +354,9 @@ do { if (interrupt == 3) { OP1(0xcc); } else { OP1(0xcd); OP1(interrupt); } } wh
 
 
 
-/*###################################################################################################
-**  MOVE EMITTERS
-**#################################################################################################*/
+/***************************************************************************
+    MOVE EMITTERS
+***************************************************************************/
 
 #define _mov_r8_imm(dreg, imm) \
 do { OP1(0xb0 + (dreg)); OP1(imm); } while (0)
@@ -573,9 +575,9 @@ do { OP1(0x8d); MODRM_MBISD(dest, base, indx, scale, disp); } while (0)
 
 
 
-/*###################################################################################################
-**  SHIFT EMITTERS
-**#################################################################################################*/
+/***************************************************************************
+    SHIFT EMITTERS
+***************************************************************************/
 
 #define _sar_r32_cl(dreg) \
 do { OP1(0xd3); MODRM_REG(7, dreg); } while (0)
@@ -655,9 +657,9 @@ do { OP1(0x0f); OP1(0xbd); MODRM_REG(dreg, sreg); } while (0)
 
 
 
-/*###################################################################################################
-**  UNARY ARITHMETIC EMITTERS
-**#################################################################################################*/
+/***************************************************************************
+    UNARY ARITHMETIC EMITTERS
+***************************************************************************/
 
 #define _neg_r32(reg) \
 do { OP1(0xf7); MODRM_REG(3, reg); } while (0)
@@ -667,9 +669,9 @@ do { OP1(0xf7); MODRM_REG(2, reg); } while (0)
 
 
 
-/*###################################################################################################
-**  32-BIT ARITHMETIC EMITTERS
-**#################################################################################################*/
+/***************************************************************************
+    32-BIT ARITHMETIC EMITTERS
+***************************************************************************/
 
 #define _add_r32_r32(r1, r2) \
 do { OP1(0x01); MODRM_REG(r2, r1); } while (0)
@@ -747,6 +749,9 @@ do { OP1(0x1b); MODRM_MBD(dreg, base, disp); } while (0)
 #define _xor_r32_m32bd(dreg, base, disp) \
 do { OP1(0x33); MODRM_MBD(dreg, base, disp); } while (0)
 
+#define _imul_r32_m32bd(dreg, base, disp) \
+do { OP1(0x0f); OP1(0xaf); MODRM_MBD(dreg, base, disp); } while (0)
+
 
 
 #define _add_m32abs_r32(addr, sreg) \
@@ -938,9 +943,9 @@ do { OP1(0xd3);	OP1(0xd8 | ((reg) & 7)); } while(0)
 
 
 
-/*###################################################################################################
-**  16-BIT AND 8-BIT ARITHMETIC EMITTERS
-**#################################################################################################*/
+/***************************************************************************
+    16-BIT AND 8-BIT ARITHMETIC EMITTERS
+***************************************************************************/
 
 #define _or_r8_r8(r1, r2) \
 do { OP1(0x08); MODRM_REG(r2, r1); } while (0)
@@ -1079,9 +1084,9 @@ do { OP1(0xd2);	OP1(0xd8 | ((reg) & 7)); } while(0)
 
 
 
-/*###################################################################################################
-**  FLOATING POINT EMITTERS
-**#################################################################################################*/
+/***************************************************************************
+    FLOATING POINT EMITTERS
+***************************************************************************/
 
 #define _fnclex() \
 do { OP1(0xdb); OP1(0xe2); } while (0)
@@ -1163,9 +1168,9 @@ do { OP1(0xdd); MODRM_MABS(3, addr); } while (0)
 
 
 
-/*###################################################################################################
-**  BRANCH EMITTERS
-**#################################################################################################*/
+/***************************************************************************
+    BRANCH EMITTERS
+***************************************************************************/
 
 #define _setcc_r8(cond, dreg) \
 do { OP1(0x0f); OP1(0x90 + cond); MODRM_REG(0, dreg); } while (0)
@@ -1243,9 +1248,9 @@ do {												\
 
 
 
-/*###################################################################################################
-**  SSE EMITTERS
-**#################################################################################################*/
+/***************************************************************************
+    SSE EMITTERS
+***************************************************************************/
 
 #define _ldmxcsr_m32abs(addr) \
 do { OP1(0x0f); OP1(0xae); MODRM_MABS(2, addr); } while (0)
@@ -1685,9 +1690,9 @@ do { OP1(0x0f); OP1(0x18); MODRM_MBD(type, base, disp); } while (0)
 
 
 
-/*###################################################################################################
-**  FUNCTION PROTOTYPES
-**#################################################################################################*/
+/***************************************************************************
+    FUNCTION PROTOTYPES
+***************************************************************************/
 
 /* init/shutdown */
 drc_core *drc_init(UINT8 cpunum, drc_config *config);
